@@ -26,17 +26,19 @@ die()
 }
 
 _positionals=()
-_arg_feature_path=('' )
 _arg_image_tag_prefix=
-
+_arg_tags_to_exclude=
+_arg_parallel_processes=3
 
 print_help()
 {
   printf '%s\n' "Runs the provided behave tests in a containerized environment"
   printf 'Usage: %s [--image-tag-prefix <arg>] [-h|--help] <minifi_version> <feature_path-1> [<feature_path-2>] ... [<feature_path-n>] ...\n' "$0"
   printf '\t%s\n' "<minifi_version>: the version of minifi"
-  printf '\t%s\n' "<feature_path>: feature files to run"
+  printf '\t%s\n' "<tags_to_run>: include these tags"
+  printf '\t%s\n' "--tags_to_exclude: optional tags that should be skipped (no default)"
   printf '\t%s\n' "--image-tag-prefix: optional prefix to the docker tag (no default)"
+  printf '\t%s\n' "--parallel_processes: optional argument that specifies the number of parallel processes that can be executed simultaneously. (default: 3)"
   printf '\t%s\n' "-h, --help: Prints help"
 }
 
@@ -56,6 +58,22 @@ parse_commandline()
       --image-tag-prefix=*)
         _arg_image_tag_prefix="${_key##--image-tag-prefix=}"
         ;;
+      --tags_to_exclude)
+        test $# -lt 2 && die "Missing value for the optional argument '$_key'." 1
+        _arg_tags_to_exclude="$2"
+        shift
+        ;;
+      --tags_to_exclude=*)
+        _arg_tags_to_exclude="${_key##--tags_to_exclude=}"
+        ;;
+      --parallel_processes)
+        test $# -lt 2 && die "Missing value for the optional argument '$_key'." 1
+        _arg_parallel_processes="$2"
+        shift
+        ;;
+      --parallel_processes=*)
+        _arg_parallel_processes="${_key##--parallel_processes=}"
+        ;;
       -h|--help)
         print_help
         exit 0
@@ -77,7 +95,7 @@ parse_commandline()
 
 handle_passed_args_count()
 {
-  local _required_args_string="'minifi_version' and 'feature_path'"
+  local _required_args_string="'minifi_version' and 'tags_to_run'"
   test "${_positionals_count}" -ge 2 || _PRINT_HELP=yes die "FATAL ERROR: Not enough positional arguments - we require at least 2 (namely: $_required_args_string), but got only ${_positionals_count}." 1
 }
 
@@ -85,12 +103,7 @@ handle_passed_args_count()
 assign_positional_args()
 {
   local _positional_name _shift_for=$1
-  _positional_names="_arg_minifi_version _arg_feature_path "
-  _our_args=$((${#_positionals[@]} - 2))
-  for ((ii = 0; ii < _our_args; ii++))
-  do
-    _positional_names="$_positional_names _arg_feature_path[$((ii + 1))]"
-  done
+  _positional_names="_arg_minifi_version _arg_tags_to_run "
 
   shift "$_shift_for"
   for _positional_name in ${_positional_names}
@@ -156,11 +169,19 @@ TEST_DIRECTORY="${docker_dir}/test/integration"
 export TEST_DIRECTORY
 
 # Add --no-logcapture to see logs interleaved with the test output
-BEHAVE_OPTS=(-f pretty --logging-level INFO --logging-clear-handlers)
+BEHAVE_OPTS=(--logging-level INFO --parallel-processes "${_arg_parallel_processes}" --parallel-scheme feature -o "${PWD}/behavex_output" -t "${_arg_tags_to_run}")
+if ! test -z "${_arg_tags_to_exclude}"
+then
+  IFS=','
+  read -ra splits <<< "${_arg_tags_to_exclude}"
+  for split in "${splits[@]}"
+  do
+      BEHAVE_OPTS=("${BEHAVE_OPTS[@]}" -t "~${split}")
+  done
+fi
+
+echo "${BEHAVE_OPTS[@]}"
 
-# Specify feature or scenario to run a specific test e.g.:
-# behave "${BEHAVE_OPTS[@]}" "features/file_system_operations.feature"
-# behave "${BEHAVE_OPTS[@]}" "features/file_system_operations.feature" -n "Get and put operations run in a simple flow"
 cd "${docker_dir}/test/integration"
 exec
-  behave "${BEHAVE_OPTS[@]}" "${_arg_feature_path[@]}"
+  behavex "${BEHAVE_OPTS[@]}"
