@@ -1,3 +1,19 @@
+# Licensed to the Apache Software Foundation (ASF) under one or more
+# contributor license agreements.  See the NOTICE file distributed with
+# this work for additional information regarding copyright ownership.
+# The ASF licenses this file to You under the Apache License, Version 2.0
+# (the "License"); you may not use this file except in compliance with
+# the License.  You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+
 import uuid
 
 import xml.etree.cElementTree as elementTree
@@ -8,7 +24,16 @@ from ..core.InputPort import InputPort
 
 
 class Nifi_flow_xml_serializer:
-    def serialize(self, connectable, nifi_version=None, root=None, visited=None):
+    def serialize(self, start_nodes, nifi_version=None):
+        res = None
+        visited = None
+
+        for node in start_nodes:
+            res, visited = self.serialize_node(node, nifi_version, res, visited)
+
+        return ('<?xml version="1.0" encoding="UTF-8" standalone="no"?>' + "\n" + elementTree.tostring(res, encoding='utf-8').decode('utf-8'))
+
+    def serialize_node(self, connectable, nifi_version=None, root=None, visited=None):
         if visited is None:
             visited = []
 
@@ -111,7 +136,7 @@ class Nifi_flow_xml_serializer:
             conn_destination.append(proc_bundle)
 
             proc_max_concurrent_tasks = Element('maxConcurrentTasks')
-            proc_max_concurrent_tasks.text = '1'
+            proc_max_concurrent_tasks.text = str(connectable.max_concurrent_tasks)
             conn_destination.append(proc_max_concurrent_tasks)
 
             proc_scheduling_period = Element('schedulingPeriod')
@@ -158,7 +183,7 @@ class Nifi_flow_xml_serializer:
                     continue
                 proc_property.append(proc_property_name)
                 proc_property_value = Element('value')
-                proc_property_value.text = property_value
+                proc_property_value.text = str(property_value)
                 proc_property.append(proc_property_value)
                 conn_destination.append(proc_property)
 
@@ -235,7 +260,7 @@ class Nifi_flow_xml_serializer:
                     """ res.iterfind('rootGroup').next().append(connection) """
 
                     if conn_destination not in visited:
-                        self.serialize(conn_destination, nifi_version, res, visited)
+                        self.serialize_node(conn_destination, nifi_version, res, visited)
             else:
                 connection = self.build_nifi_flow_xml_connection_element(
                     res,
@@ -249,10 +274,9 @@ class Nifi_flow_xml_serializer:
                 """ res.iterfind('rootGroup').next().append(connection) """
 
                 if conn_destinations not in visited:
-                    self.serialize(conn_destinations, nifi_version, res, visited)
+                    self.serialize_node(conn_destinations, nifi_version, res, visited)
 
-        if root is None:
-            return ('<?xml version="1.0" encoding="UTF-8" standalone="no"?>' + "\n" + elementTree.tostring(res, encoding='utf-8').decode('utf-8'))
+        return (res, visited)
 
     def build_nifi_flow_xml_connection_element(self, res, bend_points, conn_name, connectable, label_index, destination, z_index):
         connection = Element('connection')
