@@ -16,12 +16,10 @@
  */
 #pragma once
 
-#include <istream>
 #include <string>
 #include <vector>
 
-#include "utils/EncryptionUtils.h"
-#include "utils/OptionalUtils.h"
+#include "utils/crypto/EncryptionUtils.h"
 #include "properties/PropertiesFile.h"
 
 namespace org {
@@ -34,13 +32,10 @@ class ConfigFile : public PropertiesFile {
  public:
   using PropertiesFile::PropertiesFile;
 
-  std::vector<std::string> getSensitiveProperties() const;
+  [[nodiscard]] std::vector<std::string> getSensitiveProperties() const;
 
  private:
-  friend class ConfigFileTestAccessor;
   friend bool operator==(const ConfigFile&, const ConfigFile&);
-  static std::vector<std::string> mergeProperties(std::vector<std::string> properties,
-                                                  const std::vector<std::string>& additional_properties);
 };
 
 }  // namespace encrypt_config
