@@ -26,7 +26,9 @@
 #include <utility>
 #include <tuple>
 
+#include "PropertyDefinition.h"
 #include "core/Property.h"
+#include "core/PropertyDefinitionBuilder.h"
 #include "core/Processor.h"
 #include "core/logging/Logger.h"
 #include "storage/AzureStorageCredentials.h"
@@ -35,8 +37,10 @@ namespace org::apache::nifi::minifi::azure::processors {
 
 class AzureStorageProcessorBase : public core::Processor {
  public:
-  EXTENSIONAPI static const core::Property AzureStorageCredentialsService;
-  static auto properties() { return std::array{AzureStorageCredentialsService}; }
+  EXTENSIONAPI static constexpr auto AzureStorageCredentialsService = core::PropertyDefinitionBuilder<>::createProperty("Azure Storage Credentials Service")
+      .withDescription("Name of the Azure Storage Credentials Service used to retrieve the connection string from.")
+      .build();
+  EXTENSIONAPI static constexpr auto Properties = std::array<core::PropertyReference, 1>{AzureStorageCredentialsService};
 
   AzureStorageProcessorBase(std::string name, const minifi::utils::Identifier& uuid, const std::shared_ptr<core::logging::Logger>& logger)
     : core::Processor(std::move(name), uuid),
