@@ -40,7 +40,7 @@ class ExpressionContextBuilder : public core::ProcessContextBuilder {
 
   virtual ~ExpressionContextBuilder();
 
-  static auto properties() { return std::array<core::Property, 0>{}; }
+  EXTENSIONAPI static constexpr auto Properties = std::array<core::PropertyReference, 0>{};
   EXTENSIONAPI static constexpr bool SupportsDynamicProperties = false;
   EXTENSIONAPI static constexpr bool SupportsDynamicRelationships = false;
 
