@@ -39,6 +39,7 @@
 #include "utils/gsl.h"
 #include "TestBase.h"
 #include "Catch.h"
+#include "catch2/catch_approx.hpp"
 #include "unit/ProvenanceTestHelper.h"
 #include "date/tz.h"
 #include "Utils.h"
@@ -208,18 +209,18 @@ TEST_CASE("GetFile PutFile dynamic attribute", "[expressionLanguageTestGetFilePu
 
   // Build MiNiFi processing graph
   auto get_file = plan->addProcessor("GetFile", "GetFile");
-  plan->setProperty(get_file, minifi::processors::GetFile::Directory.getName(), in_dir.string());
-  plan->setProperty(get_file, minifi::processors::GetFile::KeepSourceFile.getName(), "false");
+  plan->setProperty(get_file, minifi::processors::GetFile::Directory, in_dir.string());
+  plan->setProperty(get_file, minifi::processors::GetFile::KeepSourceFile, "false");
   auto update = plan->addProcessor("UpdateAttribute", "UpdateAttribute", core::Relationship("success", "description"), true);
   update->setDynamicProperty("prop_attr", "${'nifi.my.own.property'}_added");
   plan->addProcessor("LogAttribute", "LogAttribute", core::Relationship("success", "description"), true);
   auto extract_text = plan->addProcessor("ExtractText", "ExtractText", core::Relationship("success", "description"), true);
-  plan->setProperty(extract_text, minifi::processors::ExtractText::Attribute.getName(), "extracted_attr_name");
+  plan->setProperty(extract_text, minifi::processors::ExtractText::Attribute, "extracted_attr_name");
   plan->addProcessor("LogAttribute", "LogAttribute", core::Relationship("success", "description"), true);
   auto put_file = plan->addProcessor("PutFile", "PutFile", core::Relationship("success", "description"), true);
-  plan->setProperty(put_file, minifi::processors::PutFile::Directory.getName(), (out_dir / "${extracted_attr_name}").string());
-  plan->setProperty(put_file, minifi::processors::PutFile::ConflictResolution.getName(), minifi::processors::PutFile::CONFLICT_RESOLUTION_STRATEGY_REPLACE);
-  plan->setProperty(put_file, minifi::processors::PutFile::CreateDirs.getName(), "true");
+  plan->setProperty(put_file, minifi::processors::PutFile::Directory, (out_dir / "${extracted_attr_name}").string());
+  plan->setProperty(put_file, minifi::processors::PutFile::ConflictResolution, minifi::processors::PutFile::CONFLICT_RESOLUTION_STRATEGY_REPLACE);
+  plan->setProperty(put_file, minifi::processors::PutFile::CreateDirs, "true");
 
   // Write test input
   {
@@ -626,7 +627,7 @@ TEST_CASE("Plus Exponent 2", "[expressionLanguagePlusExponent2]") {
 
   auto flow_file_a = std::make_shared<core::FlowFile>();
   flow_file_a->addAttribute("attr", "11.345678901234");
-  REQUIRE(10000011.345678901234 == Approx(expr(expression::Parameters{ flow_file_a }).asLongDouble()));
+  REQUIRE(10000011.345678901234 == Catch::Approx(expr(expression::Parameters{ flow_file_a }).asLongDouble()));
 }
 
 TEST_CASE("Minus Integer", "[expressionLanguageMinusInteger]") {
@@ -658,7 +659,7 @@ TEST_CASE("Multiply Decimal", "[expressionLanguageMultiplyDecimal]") {
 
   auto flow_file_a = std::make_shared<core::FlowFile>();
   flow_file_a->addAttribute("attr", "11.1");
-  REQUIRE(-148.136937 == Approx(expr(expression::Parameters{ flow_file_a }).asLongDouble()));
+  REQUIRE(-148.136937 == Catch::Approx(expr(expression::Parameters{ flow_file_a }).asLongDouble()));
 }
 
 TEST_CASE("Divide Integer", "[expressionLanguageDivideInteger]") {
@@ -908,6 +909,44 @@ TEST_CASE("GT3", "[expressionGT3]") {
   REQUIRE("false" == expr(expression::Parameters{ flow_file_a }).asString());
 }
 
+// using :gt() to test string to integer parsing code
+TEST_CASE("GT4 Value parsing errors", "[expressionGT4][outofrange]") {
+  const char* test_str = nullptr;
+  const char* expected_substr = nullptr;
+  SECTION("integer out of range") {
+    // 2 ^ 64, the smallest positive integer that's not representable even in uint64_t
+    test_str = "18446744073709551616";
+    expected_substr = "out of range";
+  }
+  SECTION("integer invalid") {
+    test_str = "banana1337";
+    expected_substr = "invalid argument";
+  }
+  SECTION("floating point out of range") {
+    // largest IEEE754 quad precision float normal number times 10 (bumped the exponent by one)
+    test_str = "1.1897314953572317650857593266280070162e+4933";
+    expected_substr = "out of range";
+  }
+  SECTION("floating point invalid") {
+    test_str = "app.le+1337";
+    expected_substr = "invalid argument";
+  }
+  REQUIRE(test_str);
+  REQUIRE(expected_substr);
+  const auto expr = expression::compile("${attr1:gt(13.37)}");
+  auto flow_file = std::make_shared<core::FlowFile>();
+  flow_file->addAttribute("attr1", test_str);
+  try {
+    const auto result = expr(expression::Parameters{flow_file}).asString();
+    REQUIRE(false);
+  } catch (const std::exception& ex) {
+    const std::string message = ex.what();
+    // The exception message should be helpful enough to contain the problem description, and the problematic value
+    CHECK(message.find(expected_substr) != std::string::npos);
+    CHECK(message.find(test_str) != std::string::npos);
+  }
+}
+
 TEST_CASE("GE", "[expressionGE]") {
   auto expr = expression::compile("${attr:plus(5):ge(6)}");
 
@@ -1226,22 +1265,48 @@ TEST_CASE("Parse Date", "[expressionParseDate]") {
 #ifdef WIN32
   expression::dateSetInstall(TZ_DATA_DIR);
 #endif
-  auto expr = expression::compile("${message:toDate('%Y/%m/%d', 'America/Los_Angeles')}");
-
   auto flow_file_a = std::make_shared<core::FlowFile>();
   flow_file_a->addAttribute("message", "2014/04/30");
-  REQUIRE("1398841200000" == expr(expression::Parameters{ flow_file_a }).asString());
+  CHECK("1398841200000" == expression::compile("${message:toDate('%Y/%m/%d', 'America/Los_Angeles')}")(expression::Parameters{ flow_file_a }).asString());
+
+  flow_file_a->addAttribute("trillion_utc", "2001/09/09 01:46:40.000Z");
+  flow_file_a->addAttribute("trillion_paris", "2001/09/09 03:46:40.000Z");
+  flow_file_a->addAttribute("trillion_la", "2001/09/08 18:46:40.000Z");
+  CHECK("1000000000000" == expression::compile("${trillion_utc:toDate('%Y/%m/%d %H:%M:%SZ', 'UTC')}")(expression::Parameters{ flow_file_a }).asString());
+  CHECK("1000000000000" == expression::compile("${trillion_paris:toDate('%Y/%m/%d %H:%M:%SZ', 'Europe/Paris')}")(expression::Parameters{ flow_file_a }).asString());
+  CHECK("1000000000000" == expression::compile("${trillion_la:toDate('%Y/%m/%d %H:%M:%SZ', 'America/Los_Angeles')}")(expression::Parameters{ flow_file_a }).asString());
+
+  flow_file_a->addAttribute("timestamp_with_zone_info_00_00", "2023-03-02T03:49:55.190+08:45");
+  flow_file_a->addAttribute("timestamp_with_zone_info_08_45", "2023-03-02T03:49:55.190+08:45");
+
+  CHECK("1677697495190" == expression::compile("${timestamp_with_zone_info_00_00:toDate('%FT%T%Ez', 'UTC')}")(expression::Parameters{ flow_file_a }).asString());
+  CHECK("1677697495190" == expression::compile("${timestamp_with_zone_info_08_45:toDate('%FT%T%Ez', 'UTC')}")(expression::Parameters{ flow_file_a }).asString());
+
+  flow_file_a->addAttribute("invalid_timestamp_1", " 2023-03-02T03:49:55.190+08:45");
+  flow_file_a->addAttribute("invalid_timestamp_2", "2023-03-02T03:49:55.190+08:45 ");
+  flow_file_a->addAttribute("invalid_timestamp_3", "2023-03-02 03:49:55.190+08:45 ");
+
+  REQUIRE_THROWS_AS(expression::compile("${invalid_timestamp_1:toDate('%FT%T%Ez', 'UTC')}")(expression::Parameters{ flow_file_a }), std::runtime_error);
+  REQUIRE_THROWS_AS(expression::compile("${invalid_timestamp_2:toDate('%FT%T%Ez', 'UTC')}")(expression::Parameters{ flow_file_a }), std::runtime_error);
+  REQUIRE_THROWS_AS(expression::compile("${invalid_timestamp_3:toDate('%FT%T%Ez', 'UTC')}")(expression::Parameters{ flow_file_a }), std::runtime_error);
 }
 
 TEST_CASE("Reformat Date", "[expressionReformatDate]") {
 #ifdef WIN32
   expression::dateSetInstall(TZ_DATA_DIR);
 #endif
-  auto expr = expression::compile("${message:toDate('%Y/%m/%d', 'GMT'):format('%m-%d-%Y', 'America/New_York')}");
-
   auto flow_file_a = std::make_shared<core::FlowFile>();
   flow_file_a->addAttribute("message", "2014/03/14");
-  REQUIRE("03-13-2014" == expr(expression::Parameters{ flow_file_a }).asString());
+  flow_file_a->addAttribute("blue", "20130917162643");
+
+  CHECK("03-13-2014" == expression::compile("${message:toDate('%Y/%m/%d', 'UTC'):format('%m-%d-%Y', 'America/New_York')}")(expression::Parameters{ flow_file_a }).asString());
+
+  auto blue_utc_expr = expression::compile("${blue:toDate('%Y%m%d%H%M%S', 'UTC'):format('%Y/%m/%d %H:%M:%SZ', 'UTC')}");
+  auto blue_paris_expr = expression::compile("${blue:toDate('%Y%m%d%H%M%S', 'UTC'):format('%Y/%m/%d %H:%M:%SZ', 'Europe/Paris')}");
+  auto blue_la_expr = expression::compile("${blue:toDate('%Y%m%d%H%M%S', 'UTC'):format('%Y/%m/%d %H:%M:%SZ', 'America/Los_Angeles')}");
+  CHECK("2013/09/17 16:26:43.000Z" == blue_utc_expr(expression::Parameters{ flow_file_a }).asString());
+  CHECK("2013/09/17 18:26:43.000Z" == blue_paris_expr(expression::Parameters{ flow_file_a }).asString());
+  CHECK("2013/09/17 09:26:43.000Z" == blue_la_expr(expression::Parameters{ flow_file_a }).asString());
 }
 
 TEST_CASE("Now Date", "[expressionNowDate]") {
@@ -1249,22 +1314,77 @@ TEST_CASE("Now Date", "[expressionNowDate]") {
   expression::dateSetInstall(TZ_DATA_DIR);
 #endif
   auto expr = expression::compile("${now():format('%Y')}");
+  auto current_year = date::year_month_day{std::chrono::floor<std::chrono::days>(std::chrono::system_clock::now())}.year().operator int();
 
-  auto flow_file_a = std::make_shared<core::FlowFile>();
-  flow_file_a->addAttribute("message", "2014/03/14");
-  date::year_month_day date{std::chrono::floor<std::chrono::days>(std::chrono::system_clock::now())};
+  CHECK(current_year == expr(expression::Parameters{ }).asSignedLong());
+}
 
-  REQUIRE(date.year().operator int() == expr(expression::Parameters{ flow_file_a }).asSignedLong());
+TEST_CASE("Parse RFC3339 with Expression Language toDate") {
+  using date::sys_days;
+  using org::apache::nifi::minifi::utils::timeutils::parseRfc3339;
+  using namespace date::literals;
+  using namespace std::literals::chrono_literals;
+  using std::chrono::milliseconds;
+
+  milliseconds expected_second = std::chrono::floor<milliseconds>((sys_days(2023_y / 03 / 01) + 19h + 04min + 55s).time_since_epoch());
+  milliseconds expected_tenth_second = std::chrono::floor<milliseconds>((sys_days(2023_y / 03 / 01) + 19h + 04min + 55s + 100ms).time_since_epoch());
+  milliseconds expected_milli_second = std::chrono::floor<milliseconds>((sys_days(2023_y / 03 / 01) + 19h + 04min + 55s + 190ms).time_since_epoch());
+
+  CHECK(expression::compile("${literal('2023-03-01T19:04:55Z'):toDate()}")(expression::Parameters()).asSignedLong() == expected_second.count());
+  CHECK(expression::compile("${literal('2023-03-01T19:04:55.1Z'):toDate()}")(expression::Parameters()).asSignedLong() == expected_tenth_second.count());
+  CHECK(expression::compile("${literal('2023-03-01T19:04:55.19Z'):toDate()}")(expression::Parameters()).asSignedLong() == expected_milli_second.count());
+  CHECK(expression::compile("${literal('2023-03-01T19:04:55.190Z'):toDate()}")(expression::Parameters()).asSignedLong() == expected_milli_second.count());
+  CHECK(expression::compile("${literal('2023-03-01T19:04:55.190999Z'):toDate()}")(expression::Parameters()).asSignedLong() == expected_milli_second.count());
+  CHECK(expression::compile("${literal('2023-03-01t19:04:55z'):toDate()}")(expression::Parameters()).asSignedLong() == expected_second.count());
+  CHECK(expression::compile("${literal('2023-03-01t19:04:55.190z'):toDate()}")(expression::Parameters()).asSignedLong() == expected_milli_second.count());
+  CHECK(expression::compile("${literal('2023-03-01T20:04:55+01:00'):toDate()}")(expression::Parameters()).asSignedLong() == expected_second.count());
+  CHECK(expression::compile("${literal('2023-03-01T20:04:55.190+01:00'):toDate()}")(expression::Parameters()).asSignedLong() == expected_milli_second.count());
+  CHECK(expression::compile("${literal('2023-03-01T20:04:55.190999+01:00'):toDate()}")(expression::Parameters()).asSignedLong() == expected_milli_second.count());
+  CHECK(expression::compile("${literal('2023-03-01 20:04:55+01:00'):toDate()}")(expression::Parameters()).asSignedLong() == expected_second.count());
+  CHECK(expression::compile("${literal('2023-03-01 20:04:55.1+01:00'):toDate()}")(expression::Parameters()).asSignedLong() == expected_tenth_second.count());
+  CHECK(expression::compile("${literal('2023-03-01 20:04:55.19+01:00'):toDate()}")(expression::Parameters()).asSignedLong() == expected_milli_second.count());
+  CHECK(expression::compile("${literal('2023-03-01 20:04:55.190+01:00'):toDate()}")(expression::Parameters()).asSignedLong() == expected_milli_second.count());
+  CHECK(expression::compile("${literal('2023-03-01 20:04:55.190999+01:00'):toDate()}")(expression::Parameters()).asSignedLong() == expected_milli_second.count());
+  CHECK(expression::compile("${literal('2023-03-01 19:04:55Z'):toDate()}")(expression::Parameters()).asSignedLong() == expected_second.count());
+  CHECK(expression::compile("${literal('2023-03-01_19:04:55Z'):toDate()}")(expression::Parameters()).asSignedLong() == expected_second.count());
+  CHECK(expression::compile("${literal('2023-03-01 19:04:55z'):toDate()}")(expression::Parameters()).asSignedLong() == expected_second.count());
+  CHECK(expression::compile("${literal('2023-03-01_19:04:55z'):toDate()}")(expression::Parameters()).asSignedLong() == expected_second.count());
+  CHECK(expression::compile("${literal('2023-03-01 19:04:55.1Z'):toDate()}")(expression::Parameters()).asSignedLong() == expected_tenth_second.count());
+  CHECK(expression::compile("${literal('2023-03-01 19:04:55.19Z'):toDate()}")(expression::Parameters()).asSignedLong() == expected_milli_second.count());
+  CHECK(expression::compile("${literal('2023-03-01 19:04:55.190Z'):toDate()}")(expression::Parameters()).asSignedLong() == expected_milli_second.count());
+  CHECK(expression::compile("${literal('2023-03-01_19:04:55.190Z'):toDate()}")(expression::Parameters()).asSignedLong() == expected_milli_second.count());
+  CHECK(expression::compile("${literal('2023-03-01 19:04:55.190999Z'):toDate()}")(expression::Parameters()).asSignedLong() == expected_milli_second.count());
+  CHECK(expression::compile("${literal('2023-03-01_19:04:55.190999Z'):toDate()}")(expression::Parameters()).asSignedLong() == expected_milli_second.count());
+  CHECK(expression::compile("${literal('2023-03-01 19:04:55.190z'):toDate()}")(expression::Parameters()).asSignedLong() == expected_milli_second.count());
+  CHECK(expression::compile("${literal('2023-03-01_19:04:55.190z'):toDate()}")(expression::Parameters()).asSignedLong() == expected_milli_second.count());
+  CHECK(expression::compile("${literal('2023-03-01 19:04:55.190999z'):toDate()}")(expression::Parameters()).asSignedLong() == expected_milli_second.count());
+  CHECK(expression::compile("${literal('2023-03-01_19:04:55.190999z'):toDate()}")(expression::Parameters()).asSignedLong() == expected_milli_second.count());
+  CHECK(expression::compile("${literal('2023-03-01 19:04:55-00:00'):toDate()}")(expression::Parameters()).asSignedLong() == expected_second.count());
+  CHECK(expression::compile("${literal('2023-03-01 19:04:55.190-00:00'):toDate()}")(expression::Parameters()).asSignedLong() == expected_milli_second.count());
+  CHECK(expression::compile("${literal('2023-03-01T19:04:55-00:00'):toDate()}")(expression::Parameters()).asSignedLong() == expected_second.count());
+  CHECK(expression::compile("${literal('2023-03-01T19:04:55.190-00:00'):toDate()}")(expression::Parameters()).asSignedLong() == expected_milli_second.count());
+  CHECK(expression::compile("${literal('2023-03-02T03:49:55+08:45'):toDate()}")(expression::Parameters()).asSignedLong() == expected_second.count());
+  CHECK(expression::compile("${literal('2023-03-01T19:04:55+00:00'):toDate()}")(expression::Parameters()).asSignedLong() == expected_second.count());
+  CHECK(expression::compile("${literal('2023-03-01T19:04:55.190+00:00'):toDate()}")(expression::Parameters()).asSignedLong() == expected_milli_second.count());
+  CHECK(expression::compile("${literal('2023-03-01T18:04:55-01:00'):toDate()}")(expression::Parameters()).asSignedLong() == expected_second.count());
+
+  REQUIRE_THROWS_AS(expression::compile("${literal('2023-03-01T19:04:55Zbanana'):toDate()}")(expression::Parameters()), std::runtime_error);
+  REQUIRE_THROWS_AS(expression::compile("${literal('2023-03-01T19:04:55'):toDate()}")(expression::Parameters()), std::runtime_error);
+  REQUIRE_THROWS_AS(expression::compile("${literal('2023-03-01T19:04:55T'):toDate()}")(expression::Parameters()), std::runtime_error);
+  REQUIRE_THROWS_AS(expression::compile("${literal('2023-03-01T19:04:55Z '):toDate()}")(expression::Parameters()), std::runtime_error);
+  REQUIRE_THROWS_AS(expression::compile("${literal(' 2023-03-01T19:04:55Z'):toDate()}")(expression::Parameters()), std::runtime_error);
+  REQUIRE_THROWS_AS(expression::compile("${literal('2023-03-01'):toDate()}")(expression::Parameters()), std::runtime_error);
 }
 
 TEST_CASE("Format Date", "[expressionFormatDate]") {
-  auto expr_gmt = expression::compile("${message:format('%m-%d-%Y', 'GMT')}");
-  auto expr_utc = expression::compile("${message:format('%m-%d-%Y', 'UTC')}");
-
+#ifdef WIN32
+  expression::dateSetInstall(TZ_DATA_DIR);
+#endif
   auto flow_file_a = std::make_shared<core::FlowFile>();
-  flow_file_a->addAttribute("message", "1394755200000");
-  REQUIRE("03-14-2014" == expr_gmt(expression::Parameters{ flow_file_a }).asString());
-  REQUIRE("03-14-2014" == expr_utc(expression::Parameters{ flow_file_a }).asString());
+  flow_file_a->addAttribute("trillion_milliseconds", "1000000000000");
+  CHECK(expression::compile("${trillion_milliseconds:format('%Y/%m/%d %H:%M:%SZ', 'UTC')}")(expression::Parameters{ flow_file_a }).asString() == "2001/09/09 01:46:40.000Z");
+  CHECK(expression::compile("${trillion_milliseconds:format('%Y/%m/%d %H:%M:%SZ', 'Europe/Paris')}")(expression::Parameters{ flow_file_a }).asString() == "2001/09/09 03:46:40.000Z");
+  CHECK(expression::compile("${trillion_milliseconds:format('%Y/%m/%d %H:%M:%SZ', 'America/Los_Angeles')}")(expression::Parameters{ flow_file_a }).asString() == "2001/09/08 18:46:40.000Z");
 }
 
 TEST_CASE("IP", "[expressionIP]") {
@@ -1286,16 +1406,24 @@ TEST_CASE("Reverse DNS lookup with valid ip", "[ExpressionLanguage][reverseDnsLo
 
   auto flow_file_a = std::make_shared<core::FlowFile>();
   std::string expected_hostname;
+
+  SECTION("dns.google IPv6") {
+    if (minifi::test::utils::isIPv6Disabled())
+      SKIP("IPv6 is disabled");
+    flow_file_a->addAttribute("ip_addr", "2001:4860:4860::8888");
+    expected_hostname = "dns.google";
+  }
+
   SECTION("dns.google IPv4") {
     flow_file_a->addAttribute("ip_addr", "8.8.8.8");
     expected_hostname = "dns.google";
   }
 
-  SECTION("dns.google IPv6") {
+  SECTION("Unresolvable address IPv6") {
     if (minifi::test::utils::isIPv6Disabled())
-      return;
-    flow_file_a->addAttribute("ip_addr", "2001:4860:4860::8888");
-    expected_hostname = "dns.google";
+      SKIP("IPv6 is disabled");
+    flow_file_a->addAttribute("ip_addr", "2001:db8::");
+    expected_hostname = "2001:db8::";
   }
 
   SECTION("Unresolvable address IPv4") {
@@ -1303,13 +1431,6 @@ TEST_CASE("Reverse DNS lookup with valid ip", "[ExpressionLanguage][reverseDnsLo
     expected_hostname = "192.0.2.0";
   }
 
-  SECTION("Unresolvable address IPv6") {
-    if (minifi::test::utils::isIPv6Disabled())
-      return;
-    flow_file_a->addAttribute("ip_addr", "2001:db8::");
-    expected_hostname = "2001:db8::";
-  }
-
   REQUIRE(expr(expression::Parameters{ flow_file_a }).asString() ==  expected_hostname);
 }
 
@@ -1340,15 +1461,9 @@ TEST_CASE("Reverse DNS lookup with valid timeout parameter", "[ExpressionLanguag
   std::string expected_hostname;
   flow_file_a->addAttribute("ip_addr", "8.8.8.8");
 
-  SECTION("Should timeout") {
-    auto reverse_lookup_expr_0ms = expression::compile("${reverseDnsLookup(${ip_addr}, 0)}");
-    REQUIRE_NOTHROW(reverse_lookup_expr_0ms(expression::Parameters{flow_file_a}).asString() == "8.8.8.8");
-    CHECK(LogTestController::getInstance().contains("reverseDnsLookup timed out"));
-  }
-
   SECTION("Shouldn't timeout") {
     auto reverse_lookup_expr_500ms = expression::compile("${reverseDnsLookup(${ip_addr}, 500)}");
-    REQUIRE_NOTHROW(reverse_lookup_expr_500ms(expression::Parameters{flow_file_a}).asString() == "dns.google");
+    CHECK(reverse_lookup_expr_500ms(expression::Parameters{flow_file_a}).asString() == "dns.google");
     CHECK_FALSE(LogTestController::getInstance().contains("reverseDnsLookup timed out", 0ms));
   }
 }
