@@ -33,39 +33,25 @@
 
 #include "core/ProcessContext.h"
 #include "core/ProcessSession.h"
-#include "core/PropertyBuilder.h"
-#include "core/PropertyValidation.h"
 #include "core/Resource.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace processors {
-
-const core::Relationship GetGPS::Success("success", "All files are routed to success");
-
-const core::Property GetGPS::GPSDHost(core::PropertyBuilder::createProperty("GPSD Host")->withDescription("The host running the GPSD daemon")->withDefaultValue<std::string>("localhost")->build());
-const core::Property GetGPS::GPSDPort(
-    core::PropertyBuilder::createProperty("GPSD Port")->withDescription("The GPSD daemon port")->withDefaultValue<int64_t>(2947, core::StandardValidators::get().PORT_VALIDATOR)->build());
-const core::Property GetGPS::GPSDWaitTime(
-    core::PropertyBuilder::createProperty("GPSD Wait Time")->withDescription("Timeout value for waiting for data from the GPSD instance")->withDefaultValue<uint64_t>(50000000)->build());
+namespace org::apache::nifi::minifi::processors {
 
 void GetGPS::initialize() {
-  setSupportedProperties(properties());
-  setSupportedRelationships(relationships());
+  setSupportedProperties(Properties);
+  setSupportedRelationships(Relationships);
 }
 
 void GetGPS::onSchedule(const std::shared_ptr<core::ProcessContext> &context, const std::shared_ptr<core::ProcessSessionFactory>& /*sessionFactory*/) {
   std::string value;
 
-  if (context->getProperty(GPSDHost.getName(), value)) {
+  if (context->getProperty(GPSDHost, value)) {
     gpsdHost_ = value;
   }
-  if (context->getProperty(GPSDPort.getName(), value)) {
+  if (context->getProperty(GPSDPort, value)) {
     gpsdPort_ = value;
   }
-  if (context->getProperty(GPSDWaitTime.getName(), value)) {
+  if (context->getProperty(GPSDWaitTime, value)) {
     core::Property::StringToInt(value, gpsdWaitTime_);
   }
   logger_->log_trace("GPSD client scheduled");
@@ -83,7 +69,7 @@ void GetGPS::onTrigger(const std::shared_ptr<core::ProcessContext>& /*context*/,
   try {
     gpsmm gps_rec(gpsdHost_.c_str(), gpsdPort_.c_str());
 
-    if (gps_rec.stream(WATCH_ENABLE | WATCH_JSON) == NULL) {
+    if (gps_rec.stream(WATCH_ENABLE | WATCH_JSON) == nullptr) {
       logger_->log_error("No GPSD running.");
       return;
     }
@@ -94,7 +80,7 @@ void GetGPS::onTrigger(const std::shared_ptr<core::ProcessContext>& /*context*/,
       if (!gps_rec.waiting(gpsdWaitTime_))
         continue;
 
-      if ((gpsdata = gps_rec.read()) == NULL) {
+      if ((gpsdata = gps_rec.read()) == nullptr) {
         logger_->log_error("Read error");
         return;
       } else {
@@ -146,8 +132,4 @@ void GetGPS::onTrigger(const std::shared_ptr<core::ProcessContext>& /*context*/,
 
 REGISTER_RESOURCE(GetGPS, Processor);
 
-} /* namespace processors */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::processors
