@@ -30,6 +30,8 @@
 #include "utils/RegexUtils.h"
 #include "range/v3/algorithm/all_of.hpp"
 #include "range/v3/action/transform.hpp"
+#include "utils/HTTPUtils.h"
+#include "utils/Literals.h"
 
 using namespace std::literals::chrono_literals;
 
@@ -42,8 +44,8 @@ HTTPClient::HTTPClient(std::string url, std::shared_ptr<minifi::controllers::SSL
   http_session_.reset(curl_easy_init());
 }
 
-HTTPClient::HTTPClient(std::string name, const utils::Identifier& uuid)
-    : core::Connectable(std::move(name), uuid) {
+HTTPClient::HTTPClient(std::string_view name, const utils::Identifier& uuid)
+    : core::Connectable(name, uuid) {
   http_session_.reset(curl_easy_init());
 }
 
@@ -123,7 +125,11 @@ void HTTPClient::initialize(std::string method, std::string url, std::shared_ptr
 }
 
 void HTTPClient::setPeerVerification(bool peer_verification) {
-  logger_->log_debug("%s peer verification", peer_verification ? "Enabling" : "Disabling");
+  if (peer_verification) {
+    logger_->log_debug("Enabling peer verification");
+  } else {
+    logger_->log_warn("Disabling peer verification: the authenticity of https servers will not be verified!");
+  }
   curl_easy_setopt(http_session_.get(), CURLOPT_SSL_VERIFYPEER, peer_verification);
 }
 
@@ -143,6 +149,34 @@ void HTTPClient::clearBasicAuth() {
 }
 
 bool HTTPClient::setSpecificSSLVersion(utils::SSLVersion specific_version) {
+#ifdef OPENSSL_SUPPORT
+  if (ssl_context_service_) {
+    switch (specific_version) {
+      case utils::SSLVersion::TLSv1_0: {
+        ssl_context_service_->setMinTlsVersion(TLS1_VERSION);
+        ssl_context_service_->setMaxTlsVersion(TLS1_VERSION);
+        break;
+      }
+      case utils::SSLVersion::TLSv1_1: {
+        ssl_context_service_->setMinTlsVersion(TLS1_1_VERSION);
+        ssl_context_service_->setMaxTlsVersion(TLS1_1_VERSION);
+        break;
+      }
+      case utils::SSLVersion::TLSv1_2: {
+        ssl_context_service_->setMinTlsVersion(TLS1_2_VERSION);
+        ssl_context_service_->setMaxTlsVersion(TLS1_2_VERSION);
+        break;
+      }
+      case utils::SSLVersion::TLSv1_3: {
+        ssl_context_service_->setMinTlsVersion(TLS1_3_VERSION);
+        ssl_context_service_->setMaxTlsVersion(TLS1_3_VERSION);
+        break;
+      }
+      default: break;
+    }
+  }
+#endif
+
 #if CURL_AT_LEAST_VERSION(7, 54, 0)
   // bitwise or of different enum types is deprecated in C++20, but the curl api explicitly supports ORing one of CURL_SSLVERSION and one of CURL_SSLVERSION_MAX
   switch (specific_version) {
@@ -152,6 +186,8 @@ bool HTTPClient::setSpecificSSLVersion(utils::SSLVersion specific_version) {
       return CURLE_OK == curl_easy_setopt(http_session_.get(), CURLOPT_SSLVERSION, static_cast<int>(CURL_SSLVERSION_TLSv1_1) | static_cast<int>(CURL_SSLVERSION_MAX_TLSv1_1));
     case utils::SSLVersion::TLSv1_2:
       return CURLE_OK == curl_easy_setopt(http_session_.get(), CURLOPT_SSLVERSION, static_cast<int>(CURL_SSLVERSION_TLSv1_2) | static_cast<int>(CURL_SSLVERSION_MAX_TLSv1_2));
+    case utils::SSLVersion::TLSv1_3:
+      return CURLE_OK == curl_easy_setopt(http_session_.get(), CURLOPT_SSLVERSION, static_cast<int>(CURL_SSLVERSION_TLSv1_3) | static_cast<int>(CURL_SSLVERSION_MAX_TLSv1_3));
     default: return false;
   }
 #else
@@ -161,6 +197,30 @@ bool HTTPClient::setSpecificSSLVersion(utils::SSLVersion specific_version) {
 
 // If not set, the default will be TLS 1.0, see https://curl.haxx.se/libcurl/c/CURLOPT_SSLVERSION.html
 bool HTTPClient::setMinimumSSLVersion(utils::SSLVersion minimum_version) {
+#ifdef OPENSSL_SUPPORT
+  if (ssl_context_service_) {
+    switch (minimum_version) {
+      case utils::SSLVersion::TLSv1_0: {
+        ssl_context_service_->setMinTlsVersion(TLS1_VERSION);
+        break;
+      }
+      case utils::SSLVersion::TLSv1_1: {
+        ssl_context_service_->setMinTlsVersion(TLS1_1_VERSION);
+        break;
+      }
+      case utils::SSLVersion::TLSv1_2: {
+        ssl_context_service_->setMinTlsVersion(TLS1_2_VERSION);
+        break;
+      }
+      case utils::SSLVersion::TLSv1_3: {
+        ssl_context_service_->setMinTlsVersion(TLS1_3_VERSION);
+        break;
+      }
+      default: break;
+    }
+  }
+#endif
+
   CURLcode ret = CURLE_UNKNOWN_OPTION;
   switch (minimum_version) {
     case utils::SSLVersion::TLSv1_0:
@@ -172,6 +232,9 @@ bool HTTPClient::setMinimumSSLVersion(utils::SSLVersion minimum_version) {
     case utils::SSLVersion::TLSv1_2:
       ret = curl_easy_setopt(http_session_.get(), CURLOPT_SSLVERSION, CURL_SSLVERSION_TLSv1_2);
       break;
+    case utils::SSLVersion::TLSv1_3:
+      ret = curl_easy_setopt(http_session_.get(), CURLOPT_SSLVERSION, CURL_SSLVERSION_TLSv1_3);
+      break;
   }
 
   return ret == CURLE_OK;
@@ -233,12 +296,16 @@ std::string HTTPClient::escape(std::string string_to_escape) {
 }
 
 void HTTPClient::setPostFields(const std::string& input) {
-  curl_easy_setopt(http_session_.get(), CURLOPT_POSTFIELDSIZE, input.length());
+  setPostSize(input.length());
   curl_easy_setopt(http_session_.get(), CURLOPT_COPYPOSTFIELDS, input.c_str());
 }
 
 void HTTPClient::setPostSize(size_t size) {
-  curl_easy_setopt(http_session_.get(), CURLOPT_POSTFIELDSIZE, size);
+  if (size > 2_GB) {
+    curl_easy_setopt(http_session_.get(), CURLOPT_POSTFIELDSIZE_LARGE, size);
+  } else {
+    curl_easy_setopt(http_session_.get(), CURLOPT_POSTFIELDSIZE, size);
+  }
 }
 
 void HTTPClient::setHTTPProxy(const utils::HTTPProxy &proxy) {
@@ -409,26 +476,22 @@ int HTTPClient::onProgress(void *clientp, curl_off_t /*dltotal*/, curl_off_t dln
 void HTTPClient::configure_secure_connection() {
 #ifdef OPENSSL_SUPPORT
   if (ssl_context_service_) {
-    logger_->log_debug("Using certificate file \"%s\"", ssl_context_service_->getCertificateFile().string());
-    logger_->log_debug("Using private key file \"%s\"", ssl_context_service_->getPrivateKeyFile().string());
-    logger_->log_debug("Using CA certificate file \"%s\"", ssl_context_service_->getCACertificate().string());
-
     curl_easy_setopt(http_session_.get(), CURLOPT_SSL_CTX_FUNCTION, &configure_ssl_context);
     curl_easy_setopt(http_session_.get(), CURLOPT_SSL_CTX_DATA, static_cast<void *>(ssl_context_service_.get()));
     curl_easy_setopt(http_session_.get(), CURLOPT_CAINFO, nullptr);
     curl_easy_setopt(http_session_.get(), CURLOPT_CAPATH, nullptr);
   } else {
-    static const auto default_ca_path = getDefaultCAPath();
+    static const auto default_ca_file = utils::getDefaultCAFile();
 
-    if (default_ca_path)
-      logger_->log_debug("Using CA certificate file \"%s\"", default_ca_path->string());
+    if (default_ca_file)
+      logger_->log_debug("Using CA certificate file \"%s\"", std::string(*default_ca_file));
     else
       logger_->log_error("Could not find valid CA certificate file");
 
     curl_easy_setopt(http_session_.get(), CURLOPT_SSL_CTX_FUNCTION, nullptr);
     curl_easy_setopt(http_session_.get(), CURLOPT_SSL_CTX_DATA, nullptr);
-    if (default_ca_path)
-      curl_easy_setopt(http_session_.get(), CURLOPT_CAINFO, default_ca_path->string().c_str());
+    if (default_ca_file)
+      curl_easy_setopt(http_session_.get(), CURLOPT_CAINFO, std::string(*default_ca_file).c_str());
     else
       curl_easy_setopt(http_session_.get(), CURLOPT_CAINFO, nullptr);
     curl_easy_setopt(http_session_.get(), CURLOPT_CAPATH, nullptr);
@@ -469,25 +532,6 @@ std::string HTTPClient::replaceInvalidCharactersInHttpHeaderFieldName(std::strin
   return field_name;
 }
 
-std::optional<std::filesystem::path> HTTPClient::getDefaultCAPath() {
-#ifndef WIN32
-  const std::vector<std::filesystem::path> possible_ca_paths = {
-      "/etc/ssl/certs/ca-certificates.crt",
-      "/etc/pki/tls/certs/ca-bundle.crt",
-      "/usr/share/ssl/certs/ca-bundle.crt",
-      "/usr/local/share/certs/ca-root-nss.crt",
-      "/etc/ssl/cert.pem"
-  };
-
-  for (const auto& possible_ca_path : possible_ca_paths) {
-    if (std::filesystem::exists(possible_ca_path)) {
-      return possible_ca_path;
-    }
-  }
-#endif
-  return std::nullopt;
-}
-
 void HTTPClient::CurlEasyCleanup::operator()(CURL* curl) const {
   curl_easy_cleanup(curl);
 }
