@@ -51,7 +51,7 @@ class HttpSiteToSiteClient : public sitetosite::SiteToSiteClient {
   }
   ~HttpSiteToSiteClient() override = default;
 
-  static auto properties() { return std::array<core::Property, 0>{}; }
+  EXTENSIONAPI static constexpr auto Properties = std::array<core::PropertyReference, 0>{};
   EXTENSIONAPI static constexpr bool SupportsDynamicProperties = false;
   EXTENSIONAPI static constexpr bool SupportsDynamicRelationships = false;
 
