@@ -46,7 +46,7 @@ class VerifyInvokeHTTPRedirectResponse : public VerifyInvokeHTTP {
  public:
   void setupFlow(const std::optional<std::filesystem::path>& flow_yml_path) override {
     VerifyInvokeHTTP::setupFlow(flow_yml_path);
-    setProperty(minifi::processors::InvokeHTTP::FollowRedirects.getName(), "false");
+    setProperty(minifi::processors::InvokeHTTP::FollowRedirects, "false");
   }
 
   void runAssertions() override {
