@@ -18,20 +18,16 @@
 
 #include "JniProcessSession.h"
 
-#include <string>
 #include <memory>
+#include <string>
 #include <algorithm>
-#include <iterator>
 #include <set>
-#include "core/Property.h"
-#include "io/validation.h"
+#include <utility>
 #include "utils/StringUtils.h"
 #include "utils/file/FileUtils.h"
-#include "properties/Configure.h"
 #include "JVMLoader.h"
 #include "JniReferenceObjects.h"
 
-#include "core/Processor.h"
 #include "JniFlowFile.h"
 #include "../JavaException.h"
 
@@ -39,6 +35,8 @@
 extern "C" {
 #endif
 
+namespace minifi = org::apache::nifi::minifi;
+
 JNIEXPORT jobject JNICALL Java_org_apache_nifi_processor_JniProcessSession_create(JNIEnv *env, jobject obj) {
   if (obj == nullptr) {
     return nullptr;
@@ -73,21 +71,15 @@ JNIEXPORT jobject JNICALL Java_org_apache_nifi_processor_JniProcessSession_readF
   minifi::jni::JniFlowFile *ptr = minifi::jni::JVMLoader::getInstance()->getReference<minifi::jni::JniFlowFile>(env, ff);
   if (ptr->get()) {
     auto jincls = minifi::jni::JVMLoader::getInstance()->load_class("org/apache/nifi/processor/JniInputStream", env);
-
     auto jin = jincls.newInstance(env);
-
     minifi::jni::ThrowIf(env);
 
-    std::unique_ptr<minifi::jni::JniByteInputStream> callback = std::unique_ptr<minifi::jni::JniByteInputStream>(new minifi::jni::JniByteInputStream(4096));
-
-    session->getSession()->read(ptr->get(), callback.get());
-
+    auto callback = std::make_unique<minifi::jni::JniByteInputStream>(4096);
+    session->getSession()->read(ptr->get(), std::ref(*callback));
     auto jniInpuStream = std::make_shared<minifi::jni::JniInputStream>(std::move(callback), jin, session->getServicer());
-
     session->addInputStream(jniInpuStream);
 
     minifi::jni::JVMLoader::getInstance()->setReference(jin, env, jniInpuStream.get());
-
     return jin;
   }
 
@@ -100,7 +92,7 @@ JNIEXPORT jint JNICALL Java_org_apache_nifi_processor_JniInputStream_read(JNIEnv
     // this technically can't happen per JNI specs
     return -1;
   }
-  char value = 0;
+  uint8_t value = 0;
   if (jin->read(value) > 0)
     return value;
   else
@@ -113,7 +105,7 @@ JNIEXPORT jint JNICALL  Java_org_apache_nifi_processor_JniInputStream_readWithOf
     // this technically can't happen per JNI specs
     return -1;
   }
-  return jin->read(env, arr, (int) offset, (int) length);
+  return jin->read(env, arr, static_cast<int>(offset), static_cast<int>(length));
 }
 
 JNIEXPORT jboolean JNICALL Java_org_apache_nifi_processor_JniProcessSession_write(JNIEnv *env, jobject obj, jobject ff, jbyteArray byteArray) {
@@ -130,8 +122,9 @@ JNIEXPORT jboolean JNICALL Java_org_apache_nifi_processor_JniProcessSession_writ
     jbyte* buffer = env->GetByteArrayElements(byteArray, 0);
     jsize length = env->GetArrayLength(byteArray);
 
-    minifi::jni::JniByteOutStream outStream(buffer, (size_t) length);
-    session->getSession()->write(ptr->get(), &outStream);
+    if (length > 0) {
+      session->getSession()->writeBuffer(ptr->get(), gsl::make_span(reinterpret_cast<std::byte*>(buffer), gsl::narrow<size_t>(length)));
+    }
 
     env->ReleaseByteArrayElements(byteArray, buffer, 0);
 
@@ -241,7 +234,7 @@ JNIEXPORT void JNICALL Java_org_apache_nifi_processor_JniProcessSession_transfer
   THROW_IF_NULL(ff, env, NO_FF_OBJECT);
   minifi::jni::JniSession *session = minifi::jni::JVMLoader::getPtr<minifi::jni::JniSession>(env, obj);
   minifi::jni::JniFlowFile *ptr = minifi::jni::JVMLoader::getInstance()->getReference<minifi::jni::JniFlowFile>(env, ff);
-  core::Relationship rel(JniStringToUTF(env, relationship), "description");
+  minifi::core::Relationship rel(JniStringToUTF(env, relationship), "description");
   session->getSession()->transfer(ptr->get(), rel);
 }
 
@@ -250,11 +243,11 @@ jstring Java_org_apache_nifi_processor_JniProcessSession_getPropertyValue(JNIEnv
   if (obj == nullptr) {
     return env->NewStringUTF(value.c_str());
   }
-  core::ProcessContext *context = minifi::jni::JVMLoader::getPtr<core::ProcessContext>(env, obj);
+  minifi::core::ProcessContext *context = minifi::jni::JVMLoader::getPtr<minifi::core::ProcessContext>(env, obj);
   std::string keystr = JniStringToUTF(env, propertyName);
   if (!context->getProperty(keystr, value)) {
     context->getDynamicProperty(keystr, value);
-  };
+  }
   return env->NewStringUTF(value.c_str());
 }
 
@@ -433,16 +426,15 @@ JNIEXPORT jboolean JNICALL Java_org_apache_nifi_processor_JniProcessSession_appe
     return false;
   }
   THROW_IF((ff == nullptr || byteArray == nullptr), env, NO_FF_OBJECT);
-  minifi::jni::JniSession *session = minifi::jni::JVMLoader::getPtr<minifi::jni::JniSession>(env, obj);
-  minifi::jni::JniFlowFile *ptr = minifi::jni::JVMLoader::getInstance()->getReference<minifi::jni::JniFlowFile>(env, ff);
+  auto *session = minifi::jni::JVMLoader::getPtr<minifi::jni::JniSession>(env, obj);
+  auto *ptr = minifi::jni::JVMLoader::getInstance()->getReference<minifi::jni::JniFlowFile>(env, ff);
 
   if (ptr->get()) {
     jbyte* buffer = env->GetByteArrayElements(byteArray, 0);
     jsize length = env->GetArrayLength(byteArray);
 
     if (length > 0) {
-      minifi::jni::JniByteOutStream outStream(buffer, (size_t) length);
-      session->getSession()->append(ptr->get(), &outStream);
+      session->getSession()->appendBuffer(ptr->get(), gsl::make_span(reinterpret_cast<std::byte*>(buffer), gsl::narrow<size_t>(length)));
     }
 
     env->ReleaseByteArrayElements(byteArray, buffer, 0);
