@@ -32,8 +32,8 @@
 namespace org::apache::nifi::minifi::processors {
 
 void MergeContent::initialize() {
-  setSupportedProperties(properties());
-  setSupportedRelationships(relationships());
+  setSupportedProperties(Properties);
+  setSupportedRelationships(Relationships);
 }
 
 std::string MergeContent::readContent(const std::string& path) {
@@ -52,15 +52,15 @@ std::string MergeContent::readContent(const std::string& path) {
 void MergeContent::onSchedule(core::ProcessContext *context, core::ProcessSessionFactory *sessionFactory) {
   BinFiles::onSchedule(context, sessionFactory);
 
-  context->getProperty(MergeStrategy.getName(), mergeStrategy_);
-  context->getProperty(MergeFormat.getName(), mergeFormat_);
-  context->getProperty(CorrelationAttributeName.getName(), correlationAttributeName_);
-  context->getProperty(DelimiterStrategy.getName(), delimiterStrategy_);
-  context->getProperty(Header.getName(), header_);
-  context->getProperty(Footer.getName(), footer_);
-  context->getProperty(Demarcator.getName(), demarcator_);
-  context->getProperty(KeepPath.getName(), keepPath_);
-  context->getProperty(AttributeStrategy.getName(), attributeStrategy_);
+  context->getProperty(MergeStrategy, mergeStrategy_);
+  context->getProperty(MergeFormat, mergeFormat_);
+  context->getProperty(CorrelationAttributeName, correlationAttributeName_);
+  context->getProperty(DelimiterStrategy, delimiterStrategy_);
+  context->getProperty(Header, header_);
+  context->getProperty(Footer, footer_);
+  context->getProperty(Demarcator, demarcator_);
+  context->getProperty(KeepPath, keepPath_);
+  context->getProperty(AttributeStrategy, attributeStrategy_);
 
   validatePropertyOptions();
 
@@ -128,7 +128,7 @@ void MergeContent::validatePropertyOptions() {
   }
 }
 
-std::string MergeContent::getGroupId(core::ProcessContext*, const std::shared_ptr<core::FlowFile>& flow) {
+std::string MergeContent::getGroupId(const std::shared_ptr<core::FlowFile>& flow) {
   std::string groupId;
   std::string value;
   if (!correlationAttributeName_.empty()) {
@@ -191,7 +191,7 @@ void MergeContent::onTrigger(core::ProcessContext *context, core::ProcessSession
   BinFiles::onTrigger(context, session);
 }
 
-bool MergeContent::processBin(core::ProcessContext *context, core::ProcessSession *session, std::unique_ptr<Bin> &bin) {
+bool MergeContent::processBin(core::ProcessSession &session, std::unique_ptr<Bin> &bin) {
   if (mergeStrategy_ != merge_content_options::MERGE_STRATEGY_DEFRAGMENT && mergeStrategy_ != merge_content_options::MERGE_STRATEGY_BIN_PACK)
     return false;
 
@@ -213,7 +213,12 @@ bool MergeContent::processBin(core::ProcessContext *context, core::ProcessSessio
         });
   }
 
-  std::shared_ptr<core::FlowFile> merge_flow = std::static_pointer_cast<FlowFileRecord>(session->create());
+  std::shared_ptr<core::FlowFile> merge_flow = std::static_pointer_cast<FlowFileRecord>(session.create());
+  auto removeMergeFlow = gsl::finally([&](){
+    if (!session.hasBeenTransferred(*merge_flow)) {
+      session.remove(merge_flow);
+    }
+  });
   if (attributeStrategy_ == merge_content_options::ATTRIBUTE_STRATEGY_KEEP_COMMON) {
     KeepOnlyCommonAttributesMerger(bin->getFlowFile()).mergeAttributes(session, merge_flow);
   } else if (attributeStrategy_ == merge_content_options::ATTRIBUTE_STRATEGY_KEEP_ALL_UNIQUE) {
@@ -224,7 +229,7 @@ bool MergeContent::processBin(core::ProcessContext *context, core::ProcessSessio
   }
 
   auto flowFileReader = [&] (const std::shared_ptr<core::FlowFile>& ff, const io::InputStreamCallback& cb) {
-    return session->read(ff, cb);
+    return session.read(ff, cb);
   };
 
   const char* mimeType;
@@ -249,10 +254,9 @@ bool MergeContent::processBin(core::ProcessContext *context, core::ProcessSessio
     return false;
   }
 
-  std::shared_ptr<core::FlowFile> mergeFlow;
   try {
-    mergeBin->merge(context, session, bin->getFlowFile(), *serializer, merge_flow);
-    session->putAttribute(merge_flow, core::SpecialFlowAttribute::MIME_TYPE, mimeType);
+    mergeBin->merge(session, bin->getFlowFile(), *serializer, merge_flow);
+    session.putAttribute(merge_flow, core::SpecialFlowAttribute::MIME_TYPE, mimeType);
   } catch (const std::exception& ex) {
     logger_->log_error("Merge Content merge catch exception, type: %s, what: %s", typeid(ex).name(), ex.what());
     return false;
@@ -260,13 +264,13 @@ bool MergeContent::processBin(core::ProcessContext *context, core::ProcessSessio
     logger_->log_error("Merge Content merge catch exception, type: %s", getCurrentExceptionTypeName());
     return false;
   }
-  session->putAttribute(merge_flow, BinFiles::FRAGMENT_COUNT_ATTRIBUTE, std::to_string(bin->getSize()));
+  session.putAttribute(merge_flow, BinFiles::FRAGMENT_COUNT_ATTRIBUTE, std::to_string(bin->getSize()));
 
   // we successfully merge the flow
-  session->transfer(merge_flow, Merge);
+  session.transfer(merge_flow, Merge);
   std::deque<std::shared_ptr<core::FlowFile>> &flows = bin->getFlowFile();
   for (const auto& flow : flows) {
-    session->transfer(flow, Original);
+    session.transfer(flow, Original);
   }
   logger_->log_info("Merge FlowFile record UUID %s, payload length %d", merge_flow->getUUIDStr(), merge_flow->getSize());
 
@@ -278,9 +282,9 @@ BinaryConcatenationMerge::BinaryConcatenationMerge(std::string header, std::stri
     footer_(std::move(footer)),
     demarcator_(std::move(demarcator)) {}
 
-void BinaryConcatenationMerge::merge(core::ProcessContext* /*context*/, core::ProcessSession *session,
+void BinaryConcatenationMerge::merge(core::ProcessSession &session,
     std::deque<std::shared_ptr<core::FlowFile>> &flows, FlowFileSerializer& serializer, const std::shared_ptr<core::FlowFile>& merge_flow) {
-  session->write(merge_flow, BinaryConcatenationMerge::WriteCallback{header_, footer_, demarcator_, flows, serializer});
+  session.write(merge_flow, BinaryConcatenationMerge::WriteCallback{header_, footer_, demarcator_, flows, serializer});
   std::string fileName;
   if (flows.size() == 1) {
     flows.front()->getAttribute(core::SpecialFlowAttribute::FILENAME, fileName);
@@ -288,12 +292,12 @@ void BinaryConcatenationMerge::merge(core::ProcessContext* /*context*/, core::Pr
     flows.front()->getAttribute(BinFiles::SEGMENT_ORIGINAL_FILENAME, fileName);
   }
   if (!fileName.empty())
-    session->putAttribute(merge_flow, core::SpecialFlowAttribute::FILENAME, fileName);
+    session.putAttribute(merge_flow, core::SpecialFlowAttribute::FILENAME, fileName);
 }
 
-void TarMerge::merge(core::ProcessContext* /*context*/, core::ProcessSession *session,
+void TarMerge::merge(core::ProcessSession &session,
     std::deque<std::shared_ptr<core::FlowFile>> &flows, FlowFileSerializer& serializer, const std::shared_ptr<core::FlowFile>& merge_flow) {
-  session->write(merge_flow, ArchiveMerge::WriteCallback{merge_content_options::MERGE_FORMAT_TAR_VALUE, flows, serializer});
+  session.write(merge_flow, ArchiveMerge::WriteCallback{merge_content_options::MERGE_FORMAT_TAR_VALUE, flows, serializer});
   std::string fileName;
   merge_flow->getAttribute(core::SpecialFlowAttribute::FILENAME, fileName);
   if (flows.size() == 1) {
@@ -303,13 +307,13 @@ void TarMerge::merge(core::ProcessContext* /*context*/, core::ProcessSession *se
   }
   if (!fileName.empty()) {
     fileName += ".tar";
-    session->putAttribute(merge_flow, core::SpecialFlowAttribute::FILENAME, fileName);
+    session.putAttribute(merge_flow, core::SpecialFlowAttribute::FILENAME, fileName);
   }
 }
 
-void ZipMerge::merge(core::ProcessContext* /*context*/, core::ProcessSession *session,
+void ZipMerge::merge(core::ProcessSession &session,
     std::deque<std::shared_ptr<core::FlowFile>> &flows, FlowFileSerializer& serializer, const std::shared_ptr<core::FlowFile>& merge_flow) {
-  session->write(merge_flow, ArchiveMerge::WriteCallback{merge_content_options::MERGE_FORMAT_ZIP_VALUE, flows, serializer});
+  session.write(merge_flow, ArchiveMerge::WriteCallback{merge_content_options::MERGE_FORMAT_ZIP_VALUE, flows, serializer});
   std::string fileName;
   merge_flow->getAttribute(core::SpecialFlowAttribute::FILENAME, fileName);
   if (flows.size() == 1) {
@@ -319,13 +323,13 @@ void ZipMerge::merge(core::ProcessContext* /*context*/, core::ProcessSession *se
   }
   if (!fileName.empty()) {
     fileName += ".zip";
-    session->putAttribute(merge_flow, core::SpecialFlowAttribute::FILENAME, fileName);
+    session.putAttribute(merge_flow, core::SpecialFlowAttribute::FILENAME, fileName);
   }
 }
 
-void AttributeMerger::mergeAttributes(core::ProcessSession *session, const std::shared_ptr<core::FlowFile> &merge_flow) {
+void AttributeMerger::mergeAttributes(core::ProcessSession &session, const std::shared_ptr<core::FlowFile> &merge_flow) {
   for (const auto& pair : getMergedAttributes()) {
-    session->putAttribute(merge_flow, pair.first, pair.second);
+    session.putAttribute(merge_flow, pair.first, pair.second);
   }
 }
 
@@ -363,4 +367,6 @@ void KeepAllUniqueAttributesMerger::processFlowFile(const std::shared_ptr<core::
   }
 }
 
+REGISTER_RESOURCE(MergeContent, Processor);
+
 }  // namespace org::apache::nifi::minifi::processors
