@@ -31,12 +31,12 @@ void AbstractMQTTProcessor::onSchedule(const std::shared_ptr<core::ProcessContex
   }
   logger_->log_debug("AbstractMQTTProcessor: BrokerURI [%s]", uri_);
 
-  mqtt_version_ = utils::parseEnumProperty<MqttVersions>(*context, MqttVersion);
-  logger_->log_debug("AbstractMQTTProcessor: MQTT Specification Version: %s", mqtt_version_.toString());
+  mqtt_version_ = utils::parseEnumProperty<mqtt::MqttVersions>(*context, MqttVersion);
+  logger_->log_debug("AbstractMQTTProcessor: MQTT Specification Version: %s", std::string{magic_enum::enum_name(mqtt_version_)});
 
   if (auto value = context->getProperty(ClientID)) {
     clientID_ = std::move(*value);
-  } else if (mqtt_version_ == MqttVersions::V_3_1_0) {
+  } else if (mqtt_version_ == mqtt::MqttVersions::V_3_1_0) {
     throw minifi::Exception(ExceptionType::PROCESS_SCHEDULE_EXCEPTION, "MQTT 3.1.0 specification does not support empty client IDs");
   }
   logger_->log_debug("AbstractMQTTProcessor: ClientID [%s]", clientID_);
@@ -51,18 +51,18 @@ void AbstractMQTTProcessor::onSchedule(const std::shared_ptr<core::ProcessContex
   }
   logger_->log_debug("AbstractMQTTProcessor: Password [%s]", password_);
 
-  if (const auto keep_alive_interval = context->getProperty<core::TimePeriodValue>(KeepAliveInterval)) {
+  if (const auto keep_alive_interval = context->getProperty(KeepAliveInterval) | utils::flatMap(&core::TimePeriodValue::fromString)) {
     keep_alive_interval_ = std::chrono::duration_cast<std::chrono::seconds>(keep_alive_interval->getMilliseconds());
   }
   logger_->log_debug("AbstractMQTTProcessor: KeepAliveInterval [%" PRId64 "] s", int64_t{keep_alive_interval_.count()});
 
-  if (const auto connection_timeout = context->getProperty<core::TimePeriodValue>(ConnectionTimeout)) {
+  if (const auto connection_timeout = context->getProperty(ConnectionTimeout) | utils::flatMap(&core::TimePeriodValue::fromString)) {
     connection_timeout_ = std::chrono::duration_cast<std::chrono::seconds>(connection_timeout->getMilliseconds());
   }
   logger_->log_debug("AbstractMQTTProcessor: ConnectionTimeout [%" PRId64 "] s", int64_t{connection_timeout_.count()});
 
-  qos_ = utils::parseEnumProperty<MqttQoS>(*context, QoS);
-  logger_->log_debug("AbstractMQTTProcessor: QoS [%d]", qos_.value());
+  qos_ = utils::parseEnumProperty<mqtt::MqttQoS>(*context, QoS);
+  logger_->log_debug("AbstractMQTTProcessor: QoS [%u]", static_cast<uint8_t>(qos_));
 
   if (const auto security_protocol = context->getProperty(SecurityProtocol)) {
     if (*security_protocol == MQTT_SECURITY_PROTOCOL_SSL) {
@@ -103,11 +103,11 @@ void AbstractMQTTProcessor::onSchedule(const std::shared_ptr<core::ProcessContex
       last_will_->message = last_will_message_.c_str();
     }
 
-    last_will_qos_ = utils::parseEnumProperty<MqttQoS>(*context, LastWillQoS);
-    logger_->log_debug("AbstractMQTTProcessor: Last Will QoS [%d]", last_will_qos_.value());
-    last_will_->qos = last_will_qos_.value();
+    last_will_qos_ = utils::parseEnumProperty<mqtt::MqttQoS>(*context, LastWillQoS);
+    logger_->log_debug("AbstractMQTTProcessor: Last Will QoS [%u]", static_cast<uint8_t>(last_will_qos_));
+    last_will_->qos = static_cast<int>(last_will_qos_);
 
-    if (const auto value = context->getProperty<bool>(LastWillRetain)) {
+    if (const auto value = context->getProperty(LastWillRetain) | utils::flatMap(&utils::StringUtils::toBool)) {
       logger_->log_debug("AbstractMQTTProcessor: Last Will Retain [%d]", *value);
       last_will_retain_ = {*value};
       last_will_->retained = last_will_retain_;
@@ -130,7 +130,7 @@ void AbstractMQTTProcessor::initializeClient() {
 
   if (!client_) {
     MQTTAsync_createOptions options = MQTTAsync_createOptions_initializer;
-    if (mqtt_version_.value() == MqttVersions::V_5_0) {
+    if (mqtt_version_ == mqtt::MqttVersions::V_5_0) {
       options.MQTTVersion = MQTTVERSION_5;
     }
     if (MQTTAsync_createWithOptions(&client_, uri_.c_str(), clientID_.c_str(), MQTTCLIENT_PERSISTENCE_NONE, nullptr, &options) != MQTTASYNC_SUCCESS) {
@@ -184,7 +184,7 @@ void AbstractMQTTProcessor::reconnect() {
 
 MQTTAsync_connectOptions AbstractMQTTProcessor::createConnectOptions(MQTTProperties& connect_properties, MQTTProperties& will_properties, ConnectFinishedTask& connect_finished_task) {
   MQTTAsync_connectOptions connect_options = [this, &connect_properties, &will_properties] {
-    if (mqtt_version_.value() == MqttVersions::V_5_0) {
+    if (mqtt_version_ == mqtt::MqttVersions::V_5_0) {
       return createMqtt5ConnectOptions(connect_properties, will_properties);
     } else {
       return createMqtt3ConnectOptions();
@@ -214,9 +214,9 @@ MQTTAsync_connectOptions AbstractMQTTProcessor::createMqtt3ConnectOptions() cons
   connect_options.onFailure = connectionFailure;
   connect_options.cleansession = getCleanSession();
 
-  if (mqtt_version_.value() == MqttVersions::V_3_1_0) {
+  if (mqtt_version_ == mqtt::MqttVersions::V_3_1_0) {
     connect_options.MQTTVersion = MQTTVERSION_3_1;
-  } else if (mqtt_version_.value() == MqttVersions::V_3_1_1) {
+  } else if (mqtt_version_ == mqtt::MqttVersions::V_3_1_1) {
     connect_options.MQTTVersion = MQTTVERSION_3_1_1;
   }
 
@@ -296,7 +296,7 @@ void AbstractMQTTProcessor::disconnect() {
           });
   disconnect_options.context = &disconnect_finished_task;
 
-  if (mqtt_version_.value() == MqttVersions::V_5_0) {
+  if (mqtt_version_ == mqtt::MqttVersions::V_5_0) {
     disconnect_options.onSuccess5 = connectionSuccess5;
     disconnect_options.onFailure5 = connectionFailure5;
   } else {
@@ -351,9 +351,9 @@ void AbstractMQTTProcessor::checkBrokerLimits() {
       throw minifi::Exception(ExceptionType::PROCESS_SCHEDULE_EXCEPTION, os.str());
     }
 
-    if (maximum_qos_.has_value() && qos_.value() > maximum_qos_) {
+    if (maximum_qos_.has_value() && static_cast<uint8_t>(qos_) > maximum_qos_) {
       std::ostringstream os;
-      os << "Set QoS (" << qos_.value() << ") is higher than the maximum supported by the broker (" << *maximum_qos_ << ")";
+      os << "Set QoS (" << static_cast<uint8_t>(qos_) << ") is higher than the maximum supported by the broker (" << *maximum_qos_ << ")";
       throw minifi::Exception(ExceptionType::PROCESS_SCHEDULE_EXCEPTION, os.str());
     }
 
