@@ -23,6 +23,7 @@
 #include <vector>
 
 #include "utils/StringUtils.h"
+#include "utils/ValueParser.h"
 #include "core/ProcessContext.h"
 #include "core/ProcessSession.h"
 #include "core/Resource.h"
@@ -30,8 +31,8 @@
 namespace org::apache::nifi::minifi::processors {
 
 void ConsumeMQTT::initialize() {
-  setSupportedProperties(properties());
-  setSupportedRelationships(relationships());
+  setSupportedProperties(Properties);
+  setSupportedRelationships(Relationships);
 }
 
 void ConsumeMQTT::enqueueReceivedMQTTMsg(SmartMessage message) {
@@ -50,22 +51,22 @@ void ConsumeMQTT::readProperties(const std::shared_ptr<core::ProcessContext>& co
   }
   logger_->log_debug("ConsumeMQTT: Topic [%s]", topic_);
 
-  if (const auto value = context->getProperty<bool>(CleanSession)) {
+  if (const auto value = context->getProperty(CleanSession) | utils::flatMap(&utils::StringUtils::toBool)) {
     clean_session_ = *value;
   }
   logger_->log_debug("ConsumeMQTT: CleanSession [%d]", clean_session_);
 
-  if (const auto value = context->getProperty<bool>(CleanStart)) {
+  if (const auto value = context->getProperty(CleanStart) | utils::flatMap(&utils::StringUtils::toBool)) {
     clean_start_ = *value;
   }
   logger_->log_debug("ConsumeMQTT: CleanStart [%d]", clean_start_);
 
-  if (const auto session_expiry_interval = context->getProperty<core::TimePeriodValue>(SessionExpiryInterval)) {
+  if (const auto session_expiry_interval = context->getProperty(SessionExpiryInterval) | utils::flatMap(&core::TimePeriodValue::fromString)) {
     session_expiry_interval_ = std::chrono::duration_cast<std::chrono::seconds>(session_expiry_interval->getMilliseconds());
   }
   logger_->log_debug("ConsumeMQTT: SessionExpiryInterval [%" PRId64 "] s", int64_t{session_expiry_interval_.count()});
 
-  if (const auto value = context->getProperty<uint64_t>(QueueBufferMaxMessage)) {
+  if (const auto value = context->getProperty(QueueBufferMaxMessage) | utils::flatMap(&utils::toNumber<uint64_t>)) {
     max_queue_size_ = *value;
   }
   logger_->log_debug("ConsumeMQTT: Queue Max Message [%" PRIu64 "]", max_queue_size_);
@@ -75,12 +76,12 @@ void ConsumeMQTT::readProperties(const std::shared_ptr<core::ProcessContext>& co
   }
   logger_->log_debug("ConsumeMQTT: Attribute From Content Type [%s]", attribute_from_content_type_);
 
-  if (const auto topic_alias_maximum = context->getProperty<uint32_t>(TopicAliasMaximum)) {
+  if (const auto topic_alias_maximum = context->getProperty(TopicAliasMaximum) | utils::flatMap(&utils::toNumber<uint32_t>)) {
     topic_alias_maximum_ = gsl::narrow<uint16_t>(*topic_alias_maximum);
   }
   logger_->log_debug("ConsumeMQTT: Topic Alias Maximum [%" PRIu16 "]", topic_alias_maximum_);
 
-  if (const auto receive_maximum = context->getProperty<uint32_t>(ReceiveMaximum)) {
+  if (const auto receive_maximum = context->getProperty(ReceiveMaximum) | utils::flatMap(&utils::toNumber<uint32_t>)) {
     receive_maximum_ = gsl::narrow<uint16_t>(*receive_maximum);
   }
   logger_->log_debug("ConsumeMQTT: Receive Maximum [%" PRIu16 "]", receive_maximum_);
@@ -102,8 +103,8 @@ void ConsumeMQTT::onTriggerImpl(const std::shared_ptr<core::ProcessContext>& /*c
       session->remove(flow_file);
     } else {
       putUserPropertiesAsAttributes(message, flow_file, session);
-      session->putAttribute(flow_file, MQTT_BROKER_ATTRIBUTE, uri_);
-      session->putAttribute(flow_file, MQTT_TOPIC_ATTRIBUTE, message.topic);
+      session->putAttribute(flow_file, BrokerOutputAttribute.name, uri_);
+      session->putAttribute(flow_file, TopicOutputAttribute.name, message.topic);
       fillAttributeFromContentType(message, flow_file, session);
       logger_->log_debug("ConsumeMQTT processing success for the flow with UUID %s topic %s", flow_file->getUUIDStr(), message.topic);
       session->transfer(flow_file, Success);
@@ -139,7 +140,7 @@ int64_t ConsumeMQTT::WriteCallback::operator() (const std::shared_ptr<io::Output
 }
 
 void ConsumeMQTT::putUserPropertiesAsAttributes(const SmartMessage& message, const std::shared_ptr<core::FlowFile>& flow_file, const std::shared_ptr<core::ProcessSession>& session) const {
-  if (mqtt_version_.value() != MqttVersions::V_5_0) {
+  if (mqtt_version_ != mqtt::MqttVersions::V_5_0) {
     return;
   }
 
@@ -153,7 +154,7 @@ void ConsumeMQTT::putUserPropertiesAsAttributes(const SmartMessage& message, con
 }
 
 void ConsumeMQTT::fillAttributeFromContentType(const SmartMessage& message, const std::shared_ptr<core::FlowFile>& flow_file, const std::shared_ptr<core::ProcessSession>& session) const {
-  if (mqtt_version_.value() != MqttVersions::V_5_0 || attribute_from_content_type_.empty()) {
+  if (mqtt_version_ != mqtt::MqttVersions::V_5_0 || attribute_from_content_type_.empty()) {
     return;
   }
 
@@ -170,7 +171,7 @@ void ConsumeMQTT::startupClient() {
   MQTTAsync_responseOptions response_options = MQTTAsync_responseOptions_initializer;
   response_options.context = this;
 
-  if (mqtt_version_.value() == MqttVersions::V_5_0) {
+  if (mqtt_version_ == mqtt::MqttVersions::V_5_0) {
     response_options.onSuccess5 = subscriptionSuccess5;
     response_options.onFailure5 = subscriptionFailure5;
   } else {
@@ -178,7 +179,7 @@ void ConsumeMQTT::startupClient() {
     response_options.onFailure = subscriptionFailure;
   }
 
-  const int ret = MQTTAsync_subscribe(client_, topic_.c_str(), gsl::narrow<int>(qos_.value()), &response_options);
+  const int ret = MQTTAsync_subscribe(client_, topic_.c_str(), gsl::narrow<int>(qos_), &response_options);
   if (ret != MQTTASYNC_SUCCESS) {
     logger_->log_error("Failed to subscribe to MQTT topic %s (%d)", topic_, ret);
     return;
@@ -187,7 +188,7 @@ void ConsumeMQTT::startupClient() {
 }
 
 void ConsumeMQTT::onMessageReceived(SmartMessage smart_message) {
-  if (mqtt_version_ == MqttVersions::V_5_0) {
+  if (mqtt_version_ == mqtt::MqttVersions::V_5_0) {
     resolveTopicFromAlias(smart_message);
   }
 
@@ -232,7 +233,7 @@ void ConsumeMQTT::resolveTopicFromAlias(SmartMessage& smart_message) {
 }
 
 void ConsumeMQTT::checkProperties() {
-  if (mqtt_version_ == MqttVersions::V_3_1_0 || mqtt_version_ == MqttVersions::V_3_1_1 || mqtt_version_ == MqttVersions::V_3X_AUTO) {
+  if (mqtt_version_ == mqtt::MqttVersions::V_3_1_0 || mqtt_version_ == mqtt::MqttVersions::V_3_1_1 || mqtt_version_ == mqtt::MqttVersions::V_3X_AUTO) {
     if (isPropertyExplicitlySet(CleanStart)) {
       logger_->log_warn("MQTT 3.x specification does not support Clean Start. Property is not used.");
     }
@@ -250,12 +251,12 @@ void ConsumeMQTT::checkProperties() {
     }
   }
 
-  if (mqtt_version_.value() == MqttVersions::V_5_0 && isPropertyExplicitlySet(CleanSession)) {
+  if (mqtt_version_ == mqtt::MqttVersions::V_5_0 && isPropertyExplicitlySet(CleanSession)) {
     logger_->log_warn("MQTT 5.0 specification does not support Clean Session. Property is not used.");
   }
 
   if (clientID_.empty()) {
-    if (mqtt_version_.value() == MqttVersions::V_5_0) {
+    if (mqtt_version_ == mqtt::MqttVersions::V_5_0) {
       if (session_expiry_interval_ > std::chrono::seconds(0)) {
         throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Processor must have a Client ID for durable (Session Expiry Interval > 0) sessions");
       }
@@ -264,8 +265,8 @@ void ConsumeMQTT::checkProperties() {
     }
   }
 
-  if (qos_ == MqttQoS::LEVEL_0) {
-    if (mqtt_version_.value() == MqttVersions::V_5_0) {
+  if (qos_ == mqtt::MqttQoS::LEVEL_0) {
+    if (mqtt_version_ == mqtt::MqttVersions::V_5_0) {
       if (session_expiry_interval_ > std::chrono::seconds(0)) {
         logger_->log_warn("Messages are not preserved during client disconnection "
                           "by the broker when QoS is less than 1 for durable (Session Expiry Interval > 0) sessions. Only subscriptions are preserved.");
@@ -295,7 +296,7 @@ void ConsumeMQTT::checkBrokerLimitsImpl() {
   }
 
   if (utils::StringUtils::startsWith(topic_, "$share/")) {
-    if (mqtt_version_.value() == MqttVersions::V_5_0) {
+    if (mqtt_version_ == mqtt::MqttVersions::V_5_0) {
       // shared topic are supported on MQTT 5, unless explicitly denied by broker
       if (shared_subscription_available_ == false) {
         std::ostringstream os;
@@ -363,4 +364,6 @@ void ConsumeMQTT::onSubscriptionFailure5(MQTTAsync_failureData5* response) {
   logger_->log_error("Reason code for subscription failure: %d: %s", response->reasonCode, MQTTReasonCode_toString(response->reasonCode));
 }
 
+REGISTER_RESOURCE(ConsumeMQTT, Processor);
+
 }  // namespace org::apache::nifi::minifi::processors
