@@ -38,8 +38,8 @@ namespace org::apache::nifi::minifi::processors {
 using SendFinishedTask = std::packaged_task<bool(bool, std::optional<int>, std::optional<MQTTReasonCodes>)>;
 
 void PublishMQTT::initialize() {
-  setSupportedProperties(properties());
-  setSupportedRelationships(relationships());
+  setSupportedProperties(Properties);
+  setSupportedRelationships(Relationships);
 }
 
 void PublishMQTT::readProperties(const std::shared_ptr<core::ProcessContext>& context) {
@@ -47,17 +47,17 @@ void PublishMQTT::readProperties(const std::shared_ptr<core::ProcessContext>& co
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, "PublishMQTT: Topic is required");
   }
 
-  if (const auto retain_opt = context->getProperty<bool>(Retain)) {
+  if (const auto retain_opt = context->getProperty(Retain) | utils::flatMap(&utils::StringUtils::toBool)) {
     retain_ = *retain_opt;
   }
   logger_->log_debug("PublishMQTT: Retain [%d]", retain_);
 
-  if (const auto message_expiry_interval = context->getProperty<core::TimePeriodValue>(MessageExpiryInterval)) {
+  if (const auto message_expiry_interval = context->getProperty(MessageExpiryInterval) | utils::flatMap(&core::TimePeriodValue::fromString)) {
     message_expiry_interval_ = std::chrono::duration_cast<std::chrono::seconds>(message_expiry_interval->getMilliseconds());
     logger_->log_debug("PublishMQTT: MessageExpiryInterval [%" PRId64 "] s", int64_t{message_expiry_interval_->count()});
   }
 
-  in_flight_message_counter_.setEnabled(mqtt_version_ == MqttVersions::V_5_0 && qos_ != MqttQoS::LEVEL_0);
+  in_flight_message_counter_.setEnabled(mqtt_version_ == mqtt::MqttVersions::V_5_0 && qos_ != mqtt::MqttQoS::LEVEL_0);
 }
 
 void PublishMQTT::onTriggerImpl(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSession>& session) {
@@ -103,13 +103,13 @@ bool PublishMQTT::sendMessage(const std::vector<std::byte>& buffer, const std::s
   MQTTAsync_message message_to_publish = MQTTAsync_message_initializer;
   message_to_publish.payload = const_cast<std::byte*>(buffer.data());
   message_to_publish.payloadlen = buffer.size();
-  message_to_publish.qos = qos_.value();
+  message_to_publish.qos = static_cast<int>(qos_);
   message_to_publish.retained = retain_;
 
   setMqtt5Properties(message_to_publish, content_type, flow_file);
 
   MQTTAsync_responseOptions response_options = MQTTAsync_responseOptions_initializer;
-  if (mqtt_version_ == MqttVersions::V_5_0) {
+  if (mqtt_version_ == mqtt::MqttVersions::V_5_0) {
     response_options.onSuccess5 = sendSuccess5;
     response_options.onFailure5 = sendFailure5;
   } else {
@@ -138,7 +138,7 @@ bool PublishMQTT::sendMessage(const std::vector<std::byte>& buffer, const std::s
 }
 
 void PublishMQTT::checkProperties() {
-  if ((mqtt_version_ == MqttVersions::V_3_1_0 || mqtt_version_ == MqttVersions::V_3_1_1 || mqtt_version_ == MqttVersions::V_3X_AUTO)) {
+  if ((mqtt_version_ == mqtt::MqttVersions::V_3_1_0 || mqtt_version_ == mqtt::MqttVersions::V_3_1_1 || mqtt_version_ == mqtt::MqttVersions::V_3X_AUTO)) {
     if (isPropertyExplicitlySet(MessageExpiryInterval)) {
       logger_->log_warn("MQTT 3.x specification does not support Message Expiry Intervals. Property is not used.");
     }
@@ -209,7 +209,7 @@ std::string PublishMQTT::getContentType(const std::shared_ptr<core::ProcessConte
 }
 
 void PublishMQTT::setMqtt5Properties(MQTTAsync_message& message, const std::string& content_type, const std::shared_ptr<core::FlowFile>& flow_file) const {
-  if (mqtt_version_ != MqttVersions::V_5_0) {
+  if (mqtt_version_ != mqtt::MqttVersions::V_5_0) {
     return;
   }
 
@@ -289,4 +289,33 @@ void PublishMQTT::InFlightMessageCounter::decrease() {
   cv_.notify_one();
 }
 
+uint16_t PublishMQTT::InFlightMessageCounter::getCounter() const {
+  std::lock_guard lock{mutex_};
+  return counter_;
+}
+
+PublishMQTT::PublishMQTTMetrics::PublishMQTTMetrics(const core::Processor& source_processor, const InFlightMessageCounter& in_flight_message_counter)
+  : core::ProcessorMetrics(source_processor),
+    in_flight_message_counter_(&in_flight_message_counter) {
+}
+
+std::vector<state::response::SerializedResponseNode> PublishMQTT::PublishMQTTMetrics::serialize() {
+  auto metrics_vector = core::ProcessorMetrics::serialize();
+  gsl_Expects(!metrics_vector.empty());
+  auto& metrics = metrics_vector[0];
+
+  state::response::SerializedResponseNode in_flight_message_count_node{"InFlightMessageCount", static_cast<uint32_t>(in_flight_message_counter_->getCounter())};
+  metrics.children.push_back(in_flight_message_count_node);
+
+  return metrics_vector;
+}
+
+std::vector<state::PublishedMetric> PublishMQTT::PublishMQTTMetrics::calculateMetrics() {
+  auto metrics = core::ProcessorMetrics::calculateMetrics();
+  metrics.push_back({"in_flight_message_count", static_cast<double>(in_flight_message_counter_->getCounter()), getCommonLabels()});
+  return metrics;
+}
+
+REGISTER_RESOURCE(PublishMQTT, Processor);
+
 }  // namespace org::apache::nifi::minifi::processors
