@@ -24,8 +24,11 @@
 #include <vector>
 
 #include "FlowFileRecord.h"
+#include "RelationshipDefinition.h"
 #include "core/Processor.h"
+#include "RelationshipDefinition.h"
 #include "core/ProcessSession.h"
+#include "core/PropertyDefinitionBuilder.h"
 #include "core/Core.h"
 #include "core/Property.h"
 #include "core/logging/LoggerConfiguration.h"
@@ -38,28 +41,39 @@ namespace org::apache::nifi::minifi::processors {
 class PublishMQTT : public processors::AbstractMQTTProcessor {
  public:
   explicit PublishMQTT(std::string name, const utils::Identifier& uuid = {})
-      : processors::AbstractMQTTProcessor(std::move(name), uuid) {
+      : processors::AbstractMQTTProcessor(std::move(name), uuid, std::make_shared<PublishMQTTMetrics>(*this, in_flight_message_counter_)) {
   }
 
   EXTENSIONAPI static constexpr const char* Description = "PublishMQTT serializes FlowFile content as an MQTT payload, sending the message to the configured topic and broker.";
 
-  EXTENSIONAPI static const core::Property Topic;
-  EXTENSIONAPI static const core::Property Retain;
-  EXTENSIONAPI static const core::Property MessageExpiryInterval;
-  EXTENSIONAPI static const core::Property ContentType;
-
-  static auto properties() {
-    return utils::array_cat(AbstractMQTTProcessor::basicProperties(), std::array{
+  EXTENSIONAPI static constexpr auto Topic = core::PropertyDefinitionBuilder<>::createProperty("Topic")
+      .withDescription("The topic to publish to.")
+      .isRequired(true)
+      .supportsExpressionLanguage(true)
+      .build();
+  EXTENSIONAPI static constexpr auto Retain = core::PropertyDefinitionBuilder<>::createProperty("Retain")
+      .withDescription("Retain published message in broker")
+      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withDefaultValue("false")
+      .build();
+  EXTENSIONAPI static constexpr auto MessageExpiryInterval = core::PropertyDefinitionBuilder<>::createProperty("Message Expiry Interval")
+      .withDescription("Time while message is valid and will be forwarded by broker. MQTT 5.x only.")
+      .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+      .build();
+  EXTENSIONAPI static constexpr auto ContentType = core::PropertyDefinitionBuilder<>::createProperty("Content Type")
+      .withDescription("Content type of the message. MQTT 5.x only.")
+      .supportsExpressionLanguage(true)
+      .build();
+  EXTENSIONAPI static constexpr auto Properties = utils::array_cat(AbstractMQTTProcessor::BasicProperties, std::array<core::PropertyReference, 4>{
       Topic,
       Retain,
       MessageExpiryInterval,
       ContentType
-    }, AbstractMQTTProcessor::advancedProperties());
-  }
+  }, AbstractMQTTProcessor::AdvancedProperties);
 
-  EXTENSIONAPI static const core::Relationship Success;
-  EXTENSIONAPI static const core::Relationship Failure;
-  static auto relationships() { return std::array{Success, Failure}; }
+  EXTENSIONAPI static constexpr auto Success = core::RelationshipDefinition{"success", "FlowFiles that are sent successfully to the destination are transferred to this relationship"};
+  EXTENSIONAPI static constexpr auto Failure = core::RelationshipDefinition{"failure", "FlowFiles that failed to be sent to the destination are transferred to this relationship"};
+  EXTENSIONAPI static constexpr auto Relationships = std::array{Success, Failure};
 
   EXTENSIONAPI static constexpr bool SupportsDynamicProperties = false;
   EXTENSIONAPI static constexpr bool SupportsDynamicRelationships = false;
@@ -84,14 +98,26 @@ class PublishMQTT : public processors::AbstractMQTTProcessor {
     void increase();
     void decrease();
 
+    uint16_t getCounter() const;
+
    private:
     bool enabled_ = false;
-    std::mutex mutex_;
+    mutable std::mutex mutex_;
     std::condition_variable cv_;
     uint16_t counter_{0};
     uint16_t limit_{MQTT_MAX_RECEIVE_MAXIMUM};
   };
 
+  class PublishMQTTMetrics : public core::ProcessorMetrics {
+   public:
+    PublishMQTTMetrics(const core::Processor& source_processor, const InFlightMessageCounter& in_flight_message_counter);
+    std::vector<state::response::SerializedResponseNode> serialize() override;
+    std::vector<state::PublishedMetric> calculateMetrics() override;
+
+   private:
+    gsl::not_null<const InFlightMessageCounter*> in_flight_message_counter_;
+  };
+
   // MQTT static async callbacks, calling their notify with context being pointer to a packaged_task to notify()
   static void sendSuccess(void* context, MQTTAsync_successData* response);
   static void sendSuccess5(void* context, MQTTAsync_successData5* response);
