@@ -17,11 +17,11 @@
 #include "PrometheusMetricsPublisher.h"
 
 #include <utility>
+#include <stdexcept>
 
 #include "core/Resource.h"
 #include "utils/StringUtils.h"
 #include "utils/OsUtils.h"
-#include "PrometheusExposerWrapper.h"
 #include "utils/Id.h"
 
 namespace org::apache::nifi::minifi::extensions::prometheus {
@@ -33,18 +33,32 @@ PrometheusMetricsPublisher::PrometheusMetricsPublisher(const std::string &name,
 void PrometheusMetricsPublisher::initialize(const std::shared_ptr<Configure>& configuration, const std::shared_ptr<state::response::ResponseNodeLoader>& response_node_loader) {
   state::MetricsPublisher::initialize(configuration, response_node_loader);
   if (!exposer_) {
-    exposer_ = std::make_unique<PrometheusExposerWrapper>(readPort());
+    exposer_ = std::make_unique<PrometheusExposerWrapper>(readExposerConfig());
   }
   loadAgentIdentifier();
 }
 
-uint32_t PrometheusMetricsPublisher::readPort() {
+PrometheusExposerConfig PrometheusMetricsPublisher::readExposerConfig() const {
   gsl_Expects(configuration_);
+  PrometheusExposerConfig config;
   if (auto port = configuration_->get(Configuration::nifi_metrics_publisher_prometheus_metrics_publisher_port)) {
-    return std::stoul(*port);
+    try {
+      config.port = std::stoul(*port);
+    } catch(const std::exception&) {
+      throw Exception(GENERAL_EXCEPTION, "Port configured for Prometheus metrics publisher is invalid: '" + *port + "'");
+    }
+  } else {
+    throw Exception(GENERAL_EXCEPTION, "Port not configured for Prometheus metrics publisher!");
   }
 
-  throw Exception(GENERAL_EXCEPTION, "Port not configured for Prometheus metrics publisher!");
+  if (auto cert = configuration_->get(Configuration::nifi_metrics_publisher_prometheus_metrics_publisher_certificate)) {
+    config.certificate = *cert;
+  }
+
+  if (auto ca_cert = configuration_->get(Configuration::nifi_metrics_publisher_prometheus_metrics_publisher_ca_certificate)) {
+    config.ca_certificate = *ca_cert;
+  }
+  return config;
 }
 
 void PrometheusMetricsPublisher::clearMetricNodes() {
@@ -67,10 +81,14 @@ void PrometheusMetricsPublisher::loadMetricNodes() {
   }
 }
 
-std::vector<state::response::SharedResponseNode> PrometheusMetricsPublisher::getMetricNodes() {
+std::vector<state::response::SharedResponseNode> PrometheusMetricsPublisher::getMetricNodes() const {
   gsl_Expects(response_node_loader_ && configuration_);
   std::vector<state::response::SharedResponseNode> nodes;
-  if (auto metric_classes_str = configuration_->get(minifi::Configuration::nifi_metrics_publisher_metrics)) {
+  auto metric_classes_str = configuration_->get(minifi::Configuration::nifi_metrics_publisher_prometheus_metrics_publisher_metrics);
+  if (!metric_classes_str || metric_classes_str->empty()) {
+    metric_classes_str = configuration_->get(minifi::Configuration::nifi_metrics_publisher_metrics);
+  }
+  if (metric_classes_str && !metric_classes_str->empty()) {
     auto metric_classes = utils::StringUtils::split(*metric_classes_str, ",");
     for (const std::string& clazz : metric_classes) {
       auto response_nodes = response_node_loader_->loadResponseNodes(clazz);
