@@ -30,6 +30,7 @@
 #include "FlowFileRecord.h"
 #include "utils/gsl.h"
 #include "core/Resource.h"
+#include "utils/OptionalUtils.h"
 
 using namespace std::literals::chrono_literals;
 
@@ -41,104 +42,83 @@ void FlowFileRepository::flush() {
     return;
   }
   auto batch = opendb->createWriteBatch();
-  rocksdb::ReadOptions options;
 
-  std::vector<std::shared_ptr<FlowFile>> purgeList;
+  std::list<ExpiredFlowFileInfo> flow_files;
 
-  std::vector<rocksdb::Slice> keys;
-  std::list<std::string> keystrings;
-  std::vector<std::string> values;
-
-  while (keys_to_delete.size_approx() > 0) {
-    std::string key;
-    if (keys_to_delete.try_dequeue(key)) {
-      keystrings.push_back(std::move(key));  // rocksdb::Slice doesn't copy the string, only grabs ptrs. Hacky, but have to ensure the required lifetime of the strings.
-      keys.push_back(keystrings.back());
+  while (keys_to_delete_.size_approx() > 0) {
+    ExpiredFlowFileInfo info;
+    if (keys_to_delete_.try_dequeue(info)) {
+      flow_files.push_back(std::move(info));
     }
   }
-  auto multistatus = opendb->MultiGet(options, keys, &values);
 
-  for (size_t i = 0; i < keys.size() && i < values.size() && i < multistatus.size(); ++i) {
-    if (!multistatus[i].ok()) {
-      logger_->log_error("Failed to read key from rocksdb: %s! DB is most probably in an inconsistent state!", keys[i].data());
-      keystrings.remove(keys[i].data());
-      continue;
-    }
+  deserializeFlowFilesWithNoContentClaim(opendb.value(), flow_files);
 
-    utils::Identifier containerId;
-    auto eventRead = FlowFileRecord::DeSerialize(gsl::make_span(values[i]).as_span<const std::byte>(), content_repo_, containerId);
-    if (eventRead) {
-      purgeList.push_back(eventRead);
-    }
-    logger_->log_debug("Issuing batch delete, including %s, Content path %s", eventRead->getUUIDStr(), eventRead->getContentFullPath());
-    batch.Delete(keys[i]);
+  for (auto& ff : flow_files) {
+    batch.Delete(ff.key);
+    logger_->log_debug("Issuing batch delete, including %s, Content path %s", ff.key, ff.content ? ff.content->getContentFullPath() : "null");
   }
 
   auto operation = [&batch, &opendb]() { return opendb->Write(rocksdb::WriteOptions(), &batch); };
 
   if (!ExecuteWithRetry(operation)) {
-    for (const auto& key : keystrings) {
-      keys_to_delete.enqueue(key);  // Push back the values that we could get but couldn't delete
+    for (auto&& ff : flow_files) {
+      keys_to_delete_.enqueue(std::move(ff));
     }
     return;  // Stop here - don't delete from content repo while we have records in FF repo
   }
 
   if (content_repo_) {
-    for (const auto &ffr : purgeList) {
-      auto claim = ffr->getResourceClaim();
-      if (claim) claim->decreaseFlowFileRecordOwnedCount();
+    for (auto& ff : flow_files) {
+      if (ff.content) {
+        ff.content->decreaseFlowFileRecordOwnedCount();
+      }
     }
   }
 }
 
-void FlowFileRepository::printStats() {
-  auto opendb = db_->open();
-  if (!opendb) {
+void FlowFileRepository::deserializeFlowFilesWithNoContentClaim(minifi::internal::OpenRocksDb& opendb, std::list<ExpiredFlowFileInfo>& flow_files) {
+  std::vector<rocksdb::Slice> keys;
+  std::vector<std::list<ExpiredFlowFileInfo>::iterator> key_positions;
+  for (auto it = flow_files.begin(); it != flow_files.end(); ++it) {
+    if (!it->content) {
+      keys.push_back(it->key);
+      key_positions.push_back(it);
+    }
+  }
+  if (keys.empty()) {
     return;
   }
-  std::string key_count;
-  opendb->GetProperty("rocksdb.estimate-num-keys", &key_count);
+  std::vector<std::string> values;
+  auto multistatus = opendb.MultiGet(rocksdb::ReadOptions{}, keys, &values);
+  gsl_Expects(keys.size() == values.size() && values.size() == multistatus.size());
 
-  std::string table_readers;
-  opendb->GetProperty("rocksdb.estimate-table-readers-mem", &table_readers);
+  for (size_t i = 0; i < keys.size(); ++i) {
+    if (!multistatus[i].ok()) {
+      logger_->log_error("Failed to read key from rocksdb: %s! DB is most probably in an inconsistent state!", keys[i].data());
+      flow_files.erase(key_positions.at(i));
+      continue;
+    }
 
-  std::string all_memtables;
-  opendb->GetProperty("rocksdb.cur-size-all-mem-tables", &all_memtables);
-
-  logger_->log_info("Repository stats: key count: %s, table readers size: %s, all memory tables size: %s",
-      key_count, table_readers, all_memtables);
+    utils::Identifier container_id;
+    auto flow_file = FlowFileRecord::DeSerialize(gsl::make_span(values[i]).as_span<const std::byte>(), content_repo_, container_id);
+    if (flow_file) {
+      gsl_Expects(flow_file->getUUIDStr() == key_positions.at(i)->key);
+      key_positions.at(i)->content = flow_file->getResourceClaim();
+    } else {
+      logger_->log_error("Could not deserialize flow file %s", key_positions.at(i)->key);
+    }
+  }
 }
 
 void FlowFileRepository::run() {
-  auto last = std::chrono::steady_clock::now();
   while (isRunning()) {
     std::this_thread::sleep_for(purge_period_);
     flush();
-    auto now = std::chrono::steady_clock::now();
-    if ((now-last) > std::chrono::seconds(30)) {
-      printStats();
-      last = now;
-    }
   }
   flush();
 }
 
-bool FlowFileRepository::ExecuteWithRetry(const std::function<rocksdb::Status()>& operation) {
-  constexpr int RETRY_COUNT = 3;
-  std::chrono::milliseconds wait_time = 0ms;
-  for (int i=0; i < RETRY_COUNT; ++i) {
-    auto status = operation();
-    if (status.ok()) {
-      logger_->log_trace("Rocksdb operation executed successfully");
-      return true;
-    }
-    logger_->log_error("Rocksdb operation failed: %s", status.ToString());
-    wait_time += FLOWFILE_REPOSITORY_RETRY_INTERVAL_INCREMENTS;
-    std::this_thread::sleep_for(wait_time);
-  }
-  return false;
-}
-
 void FlowFileRepository::initialize_repository() {
   auto opendb = db_->open();
   if (!opendb) {
@@ -149,34 +129,34 @@ void FlowFileRepository::initialize_repository() {
 
   auto it = opendb->NewIterator(rocksdb::ReadOptions());
   for (it->SeekToFirst(); it->Valid(); it->Next()) {
-    utils::Identifier containerId;
-    auto eventRead = FlowFileRecord::DeSerialize(gsl::make_span(it->value()).as_span<const std::byte>(), content_repo_, containerId);
+    utils::Identifier container_id;
+    auto eventRead = FlowFileRecord::DeSerialize(gsl::make_span(it->value()).as_span<const std::byte>(), content_repo_, container_id);
     std::string key = it->key().ToString();
     if (eventRead) {
       // on behalf of the just resurrected persisted instance
       auto claim = eventRead->getResourceClaim();
       if (claim) claim->increaseFlowFileRecordOwnedCount();
       bool found = false;
-      auto search = containers_.find(containerId.to_string());
+      auto search = containers_.find(container_id.to_string());
       found = (search != containers_.end());
       if (!found) {
         // for backward compatibility
-        search = connection_map_.find(containerId.to_string());
+        search = connection_map_.find(container_id.to_string());
         found = (search != connection_map_.end());
       }
       if (found) {
-        logger_->log_debug("Found connection for %s, path %s ", containerId.to_string(), eventRead->getContentFullPath());
+        logger_->log_debug("Found connection for %s, path %s ", container_id.to_string(), eventRead->getContentFullPath());
         eventRead->setStoredToRepository(true);
         // we found the connection for the persistent flowFile
         // even if a processor immediately marks it for deletion, flush only happens after prune_stored_flowfiles
         search->second->restore(eventRead);
       } else {
-        logger_->log_warn("Could not find connection for %s, path %s ", containerId.to_string(), eventRead->getContentFullPath());
-        keys_to_delete.enqueue(key);
+        logger_->log_warn("Could not find connection for %s, path %s ", container_id.to_string(), eventRead->getContentFullPath());
+        keys_to_delete_.enqueue({.key = key, .content = eventRead->getResourceClaim()});
       }
     } else {
       // failed to deserialize FlowFile, cannot clear claim
-      keys_to_delete.enqueue(key);
+      keys_to_delete_.enqueue({.key = key});
     }
   }
   flush();
@@ -185,7 +165,6 @@ void FlowFileRepository::initialize_repository() {
 
 void FlowFileRepository::loadComponent(const std::shared_ptr<core::ContentRepository> &content_repo) {
   content_repo_ = content_repo;
-  repo_size_ = 0;
   swap_loader_ = std::make_unique<FlowFileLoader>(gsl::make_not_null(db_.get()), content_repo_);
 
   initialize_repository();
@@ -257,48 +236,11 @@ void FlowFileRepository::setCompactionPeriod(const std::shared_ptr<Configure> &c
   }
 }
 
-bool FlowFileRepository::Put(const std::string& key, const uint8_t *buf, size_t bufLen) {
-  // persistent to the DB
-  auto opendb = db_->open();
-  if (!opendb) {
-    return false;
-  }
-  rocksdb::Slice value((const char *) buf, bufLen);
-  auto operation = [&key, &value, &opendb]() { return opendb->Put(rocksdb::WriteOptions(), key, value); };
-  return ExecuteWithRetry(operation);
-}
-
-bool FlowFileRepository::MultiPut(const std::vector<std::pair<std::string, std::unique_ptr<minifi::io::BufferStream>>>& data) {
-  auto opendb = db_->open();
-  if (!opendb) {
-    return false;
-  }
-  auto batch = opendb->createWriteBatch();
-  for (const auto &item : data) {
-    const auto buf = item.second->getBuffer().as_span<const char>();
-    rocksdb::Slice value(buf.data(), buf.size());
-    if (!batch.Put(item.first, value).ok()) {
-      logger_->log_error("Failed to add item to batch operation");
-      return false;
-    }
-  }
-  auto operation = [&batch, &opendb]() { return opendb->Write(rocksdb::WriteOptions(), &batch); };
-  return ExecuteWithRetry(operation);
-}
-
 bool FlowFileRepository::Delete(const std::string& key) {
-  keys_to_delete.enqueue(key);
+  keys_to_delete_.enqueue({.key = key});
   return true;
 }
 
-bool FlowFileRepository::Get(const std::string &key, std::string &value) {
-  auto opendb = db_->open();
-  if (!opendb) {
-    return false;
-  }
-  return opendb->Get(rocksdb::ReadOptions(), key, &value).ok();
-}
-
 void FlowFileRepository::runCompaction() {
   do {
     if (auto opendb = db_->open()) {
@@ -340,6 +282,15 @@ std::future<std::vector<std::shared_ptr<core::FlowFile>>> FlowFileRepository::lo
   return swap_loader_->load(std::move(flow_files));
 }
 
+bool FlowFileRepository::Delete(const std::shared_ptr<core::CoreComponent>& item) {
+  if (auto ff = std::dynamic_pointer_cast<core::FlowFile>(item)) {
+    keys_to_delete_.enqueue({.key = item->getUUIDStr(), .content = ff->getResourceClaim()});
+  } else {
+    keys_to_delete_.enqueue({.key = item->getUUIDStr()});
+  }
+  return true;
+}
+
 REGISTER_RESOURCE_AS(FlowFileRepository, InternalResource, ("FlowFileRepository", "flowfilerepository"));
 
 }  // namespace org::apache::nifi::minifi::core::repository
