@@ -25,11 +25,8 @@
 #include <string>
 #include <Exception.h>
 #include "io/validation.h"
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace io {
+
+namespace org::apache::nifi::minifi::io {
 
 RocksDbStream::RocksDbStream(std::string path, gsl::not_null<minifi::internal::RocksDatabase*> db, bool write_enable, minifi::internal::WriteBatch* batch)
     : BaseStream(),
@@ -78,7 +75,7 @@ size_t RocksDbStream::write(const uint8_t *value, size_t size) {
   }
 }
 
-size_t RocksDbStream::read(gsl::span<std::byte> buf) {
+size_t RocksDbStream::read(std::span<std::byte> buf) {
   // The check have to be in this order for RocksDBStreamTest "Read zero bytes" to succeed
   if (!exists_) return STREAM_ERROR;
   if (buf.empty()) return 0;
@@ -90,9 +87,4 @@ size_t RocksDbStream::read(gsl::span<std::byte> buf) {
   return amtToRead;
 }
 
-} /* namespace io */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
-
+}  // namespace org::apache::nifi::minifi::io
