@@ -15,11 +15,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#include "SFTPLoader.h"
-#include "core/FlowConfiguration.h"
+
+#include "core/extension/Extension.h"
 #include "client/SFTPClient.h"
 
-bool SFTPFactoryInitializer::initialize() {
+static bool init(const std::shared_ptr<org::apache::nifi::minifi::Configure>& /*config*/) {
   if (libssh2_init(0) != 0) {
     return false;
   }
@@ -30,18 +30,9 @@ bool SFTPFactoryInitializer::initialize() {
   return true;
 }
 
-void SFTPFactoryInitializer::deinitialize() {
+static void deinit() {
   curl_global_cleanup();
   libssh2_exit();
 }
 
-
-bool SFTPFactory::added = core::FlowConfiguration::add_static_func("createSFTPFactory");
-
-extern "C" {
-
-void *createSFTPFactory(void) {
-  return new SFTPFactory();
-}
-
-}
+REGISTER_EXTENSION("SFTPExtension", init, deinit);
