@@ -20,7 +20,6 @@
 #include <memory>
 #include <algorithm>
 #include <cstdint>
-#include <string>
 #include <utility>
 
 #include "core/FlowFile.h"
@@ -28,7 +27,6 @@
 #include "core/Relationship.h"
 #include "core/Resource.h"
 #include "io/BufferStream.h"
-#include "io/StreamFactory.h"
 #include "utils/StringUtils.h"
 #include "utils/file/FileUtils.h"
 
@@ -37,12 +35,12 @@ namespace org::apache::nifi::minifi::processors {
 void FetchSFTP::initialize() {
   logger_->log_trace("Initializing FetchSFTP");
 
-  setSupportedProperties(properties());
-  setSupportedRelationships(relationships());
+  setSupportedProperties(Properties);
+  setSupportedRelationships(Relationships);
 }
 
-FetchSFTP::FetchSFTP(std::string name, const utils::Identifier& uuid /*= utils::Identifier()*/)
-    : SFTPProcessorBase(std::move(name), uuid) {
+FetchSFTP::FetchSFTP(std::string_view name, const utils::Identifier& uuid /*= utils::Identifier()*/)
+    : SFTPProcessorBase(name, uuid) {
   logger_ = core::logging::LoggerFactory<FetchSFTP>::getLogger(uuid_);
 }
 
@@ -52,18 +50,18 @@ void FetchSFTP::onSchedule(const std::shared_ptr<core::ProcessContext> &context,
   parseCommonPropertiesOnSchedule(context);
 
   std::string value;
-  context->getProperty(CompletionStrategy.getName(), completion_strategy_);
-  if (!context->getProperty(CreateDirectory.getName(), value)) {
+  context->getProperty(CompletionStrategy, completion_strategy_);
+  if (!context->getProperty(CreateDirectory, value)) {
     logger_->log_error("Create Directory attribute is missing or invalid");
   } else {
     create_directory_ = utils::StringUtils::toBool(value).value_or(false);
   }
-  if (!context->getProperty(DisableDirectoryListing.getName(), value)) {
+  if (!context->getProperty(DisableDirectoryListing, value)) {
     logger_->log_error("Disable Directory Listing attribute is missing or invalid");
   } else {
     disable_directory_listing_ = utils::StringUtils::toBool(value).value_or(false);
   }
-  if (!context->getProperty(UseCompression.getName(), value)) {
+  if (!context->getProperty(UseCompression, value)) {
     logger_->log_error("Use Compression attribute is missing or invalid");
   } else {
     use_compression_ = utils::StringUtils::toBool(value).value_or(false);
@@ -132,7 +130,7 @@ void FetchSFTP::onTrigger(const std::shared_ptr<core::ProcessContext> &context,
     });
   } catch (const utils::SFTPException& ex) {
     logger_->log_debug(ex.what());
-    switch (ex.error().value()) {
+    switch (ex.error()) {
       case utils::SFTPError::PermissionDenied:
         session->transfer(flow_file, PermissionDenied);
         put_connection_back_to_cache();
@@ -189,4 +187,6 @@ void FetchSFTP::onTrigger(const std::shared_ptr<core::ProcessContext> &context,
   put_connection_back_to_cache();
 }
 
+REGISTER_RESOURCE(FetchSFTP, Processor);
+
 }  // namespace org::apache::nifi::minifi::processors
