@@ -37,14 +37,13 @@
 #include "core/ProcessContext.h"
 #include "core/Relationship.h"
 #include "io/BufferStream.h"
-#include "io/StreamFactory.h"
 #include "ResourceClaim.h"
 #include "utils/StringUtils.h"
 
 namespace org::apache::nifi::minifi::processors {
 
-SFTPProcessorBase::SFTPProcessorBase(std::string name, const utils::Identifier& uuid)
-    : Processor(std::move(name), uuid),
+SFTPProcessorBase::SFTPProcessorBase(std::string_view name, const utils::Identifier& uuid)
+    : Processor(name, uuid),
       connection_timeout_(0),
       data_timeout_(0),
       strict_host_checking_(false),
@@ -71,12 +70,12 @@ void SFTPProcessorBase::notifyStop() {
 
 void SFTPProcessorBase::parseCommonPropertiesOnSchedule(const std::shared_ptr<core::ProcessContext>& context) {
   std::string value;
-  if (!context->getProperty(StrictHostKeyChecking.getName(), value)) {
+  if (!context->getProperty(StrictHostKeyChecking, value)) {
     logger_->log_error("Strict Host Key Checking attribute is missing or invalid");
   } else {
     strict_host_checking_ = utils::StringUtils::toBool(value).value_or(false);
   }
-  context->getProperty(HostKeyFile.getName(), host_key_file_);
+  context->getProperty(HostKeyFile, host_key_file_);
   if (auto connection_timeout = context->getProperty<core::TimePeriodValue>(ConnectionTimeout)) {
     connection_timeout_ = connection_timeout->getMilliseconds();
   } else {
@@ -89,12 +88,12 @@ void SFTPProcessorBase::parseCommonPropertiesOnSchedule(const std::shared_ptr<co
     logger_->log_error("Data Timeout attribute is missing or invalid");
   }
 
-  if (!context->getProperty(SendKeepaliveOnTimeout.getName(), value)) {
+  if (!context->getProperty(SendKeepaliveOnTimeout, value)) {
     logger_->log_error("Send Keep Alive On Timeout attribute is missing or invalid");
   } else {
     use_keepalive_on_timeout_ = utils::StringUtils::toBool(value).value_or(true);
   }
-  context->getProperty(ProxyType.getName(), proxy_type_);
+  context->getProperty(ProxyType, proxy_type_);
 }
 
 SFTPProcessorBase::CommonProperties::CommonProperties()
@@ -112,7 +111,7 @@ bool SFTPProcessorBase::parseCommonPropertiesOnTrigger(const std::shared_ptr<cor
     logger_->log_error("Port attribute is missing or invalid");
     return false;
   } else {
-    int port_tmp;
+    int port_tmp = 0;
     if (!core::Property::StringToInt(value, port_tmp) ||
         port_tmp <= std::numeric_limits<uint16_t>::min() ||
         port_tmp > std::numeric_limits<uint16_t>::max()) {
@@ -132,7 +131,7 @@ bool SFTPProcessorBase::parseCommonPropertiesOnTrigger(const std::shared_ptr<cor
   context->getProperty(Password, common_properties.password, flow_file);
   context->getProperty(ProxyHost, common_properties.proxy_host, flow_file);
   if (context->getProperty(ProxyPort, value, flow_file) && !value.empty()) {
-    int port_tmp;
+    int port_tmp = 0;
     if (!core::Property::StringToInt(value, port_tmp) ||
         port_tmp <= std::numeric_limits<uint16_t>::min() ||
         port_tmp > std::numeric_limits<uint16_t>::max()) {
