@@ -21,7 +21,11 @@
 #include <utility>
 
 #include "controllers/SSLContextService.h"
+#include "core/Core.h"
 #include "core/Processor.h"
+#include "core/PropertyDefinition.h"
+#include "core/PropertyDefinitionBuilder.h"
+#include "core/PropertyType.h"
 
 namespace org::apache::nifi::minifi::extensions::curl {
 class HTTPClient;
@@ -31,20 +35,38 @@ namespace org::apache::nifi::minifi::extensions::splunk {
 
 class SplunkHECProcessor : public core::Processor {
  public:
-  EXTENSIONAPI static const core::Property Hostname;
-  EXTENSIONAPI static const core::Property Port;
-  EXTENSIONAPI static const core::Property Token;
-  EXTENSIONAPI static const core::Property SplunkRequestChannel;
-  EXTENSIONAPI static const core::Property SSLContext;
-  static auto properties() {
-    return std::array{
+  EXTENSIONAPI static constexpr auto Hostname = core::PropertyDefinitionBuilder<>::createProperty("Hostname")
+      .withDescription("The ip address or hostname of the Splunk server.")
+      .isRequired(true)
+      .build();
+  EXTENSIONAPI static constexpr auto Port = core::PropertyDefinitionBuilder<>::createProperty("Port")
+      .withDescription("The HTTP Event Collector HTTP Port Number.")
+      .withPropertyType(core::StandardPropertyTypes::PORT_TYPE)
+      .withDefaultValue("8088")
+      .isRequired(true)
+      .build();
+  EXTENSIONAPI static constexpr auto Token = core::PropertyDefinitionBuilder<>::createProperty("Token")
+      .withDescription("HTTP Event Collector token starting with the string Splunk. For example \'Splunk 1234578-abcd-1234-abcd-1234abcd\'")
+      .isRequired(true)
+      .build();
+  EXTENSIONAPI static constexpr auto SplunkRequestChannel = core::PropertyDefinitionBuilder<>::createProperty("Splunk Request Channel")
+      .withDescription("Identifier of the used request channel.")
+      .isRequired(true)
+      .build();
+  EXTENSIONAPI static constexpr auto SSLContext = core::PropertyDefinitionBuilder<0, 0, 1>::createProperty("SSL Context Service")
+      .withDescription("The SSL Context Service used to provide client certificate information for TLS/SSL (https) connections.")
+      .isRequired(false)
+      .withExclusiveOfProperties({{{"Hostname", "^http:.*$"}}})
+      .withAllowedTypes<minifi::controllers::SSLContextService>()
+      .build();
+  EXTENSIONAPI static constexpr auto Properties = std::array<core::PropertyReference, 5>{
       Hostname,
       Port,
       Token,
       SplunkRequestChannel,
       SSLContext
-    };
-  }
+  };
+
 
   explicit SplunkHECProcessor(std::string name, const utils::Identifier& uuid = {})
       : Processor(std::move(name), uuid) {
