@@ -31,53 +31,22 @@
 #include "utils/StringUtils.h"
 #include "core/ProcessContext.h"
 #include "core/ProcessSession.h"
-#include "core/PropertyBuilder.h"
 #include "core/Resource.h"
 
 namespace org::apache::nifi::minifi::processors {
 
-const core::Property LogAttribute::LogLevel(core::PropertyBuilder::createProperty("Log Level")->withDescription("The Log Level to use when logging the Attributes")->withAllowableValues<std::string>(
-    {"info", "trace", "error", "warn", "debug" })->build());
-
-const core::Property LogAttribute::AttributesToLog(
-    core::PropertyBuilder::createProperty("Attributes to Log")->withDescription("A comma-separated list of Attributes to Log. If not specified, all attributes will be logged.")->build());
-
-const core::Property LogAttribute::FlowFilesToLog(
-    core::PropertyBuilder::createProperty("FlowFiles To Log")->withDescription(
-        "Number of flow files to log. If set to zero all flow files will be logged. Please note that this may block other threads from running if not used judiciously.")->withDefaultValue<uint64_t>(1)
-        ->build());
-
-const core::Property LogAttribute::AttributesToIgnore(
-    core::PropertyBuilder::createProperty("Attributes to Ignore")->withDescription("A comma-separated list of Attributes to ignore. If not specified, no attributes will be ignored.")->build());
-
-const core::Property LogAttribute::LogPayload(core::PropertyBuilder::createProperty("Log Payload")->withDescription("If true, the FlowFile's payload will be logged, in addition to its attributes."
-                                                                                                              "otherwise, just the Attributes will be logged")->withDefaultValue<bool>(false)->build());
-
-const core::Property LogAttribute::HexencodePayload(
-    core::PropertyBuilder::createProperty("Hexencode Payload")->withDescription(
-        "If true, the FlowFile's payload will be logged in a hexencoded format")->withDefaultValue<bool>(false)->build());
-
-const core::Property LogAttribute::MaxPayloadLineLength(
-    core::PropertyBuilder::createProperty("Maximum Payload Line Length")->withDescription(
-        "The logged payload will be broken into lines this long. 0 means no newlines will be added.")->withDefaultValue<uint32_t>(0U)->build());
-
-const core::Property LogAttribute::LogPrefix(
-    core::PropertyBuilder::createProperty("Log Prefix")->withDescription("Log prefix appended to the log lines. It helps to distinguish the output of multiple LogAttribute processors.")->build());
-
-const core::Relationship LogAttribute::Success("success", "success operational on the flow record");
-
 void LogAttribute::initialize() {
-  setSupportedProperties(properties());
-  setSupportedRelationships(relationships());
+  setSupportedProperties(Properties);
+  setSupportedRelationships(Relationships);
 }
 
 void LogAttribute::onSchedule(const std::shared_ptr<core::ProcessContext> &context, const std::shared_ptr<core::ProcessSessionFactory>& /*factory*/) {
-  context->getProperty(FlowFilesToLog.getName(), flowfiles_to_log_);
+  context->getProperty(FlowFilesToLog, flowfiles_to_log_);
   logger_->log_debug("FlowFiles To Log: %llu", flowfiles_to_log_);
 
-  context->getProperty(HexencodePayload.getName(), hexencode_);
+  context->getProperty(HexencodePayload, hexencode_);
 
-  context->getProperty(MaxPayloadLineLength.getName(), max_line_length_);
+  context->getProperty(MaxPayloadLineLength, max_line_length_);
   logger_->log_debug("Maximum Payload Line Length: %u", max_line_length_);
 }
 // OnTrigger method, implemented by NiFi LogAttribute
@@ -97,14 +66,14 @@ void LogAttribute::onTrigger(const std::shared_ptr<core::ProcessContext> &contex
     }
 
     std::string value;
-    if (context->getProperty(LogLevel.getName(), value)) {
+    if (context->getProperty(LogLevel, value)) {
       logLevelStringToEnum(value, level);
     }
-    if (context->getProperty(LogPrefix.getName(), value)) {
+    if (context->getProperty(LogPrefix, value)) {
       dashLine = "-----" + value + "-----";
     }
 
-    context->getProperty(LogPayload.getName(), logPayload);
+    context->getProperty(LogPayload, logPayload);
 
     std::ostringstream message;
     message << "Logging for flow file " << "\n";
