@@ -57,7 +57,7 @@ class NetworkListenerProcessor : public core::Processor {
   }
 
  protected:
-  void startTcpServer(const core::ProcessContext& context, const core::Property& ssl_context_property, const core::Property& client_auth_property);
+  void startTcpServer(const core::ProcessContext& context, const core::PropertyReference& ssl_context_property, const core::PropertyReference& client_auth_property);
   void startUdpServer(const core::ProcessContext& context);
 
  private:
@@ -71,9 +71,9 @@ class NetworkListenerProcessor : public core::Processor {
   ServerOptions readServerOptions(const core::ProcessContext& context);
 
   virtual void transferAsFlowFile(const utils::net::Message& message, core::ProcessSession& session) = 0;
-  virtual const core::Property& getMaxBatchSizeProperty() = 0;
-  virtual const core::Property& getMaxQueueSizeProperty() = 0;
-  virtual const core::Property& getPortProperty() = 0;
+  virtual core::PropertyReference getMaxBatchSizeProperty() = 0;
+  virtual core::PropertyReference getMaxQueueSizeProperty() = 0;
+  virtual core::PropertyReference getPortProperty() = 0;
 
   uint64_t max_batch_size_{500};
   std::unique_ptr<utils::net::Server> server_;
