@@ -26,6 +26,10 @@
 #include "FlowFileRecord.h"
 #include "core/Processor.h"
 #include "core/ProcessSession.h"
+#include "core/PropertyDefinition.h"
+#include "core/PropertyDefinitionBuilder.h"
+#include "core/PropertyType.h"
+#include "core/RelationshipDefinition.h"
 #include "core/Core.h"
 #include "core/logging/LoggerConfiguration.h"
 #include "utils/Id.h"
@@ -35,9 +39,9 @@ namespace org::apache::nifi::minifi::processors {
 
 class PutFile : public core::Processor {
  public:
-  static constexpr char const *CONFLICT_RESOLUTION_STRATEGY_REPLACE = "replace";
-  static constexpr char const *CONFLICT_RESOLUTION_STRATEGY_IGNORE = "ignore";
-  static constexpr char const *CONFLICT_RESOLUTION_STRATEGY_FAIL = "fail";
+  static constexpr std::string_view CONFLICT_RESOLUTION_STRATEGY_REPLACE = "replace";
+  static constexpr std::string_view CONFLICT_RESOLUTION_STRATEGY_IGNORE = "ignore";
+  static constexpr std::string_view CONFLICT_RESOLUTION_STRATEGY_FAIL = "fail";
 
   explicit PutFile(std::string name,  const utils::Identifier& uuid = {})
       : core::Processor(std::move(name), uuid) {
@@ -48,29 +52,53 @@ class PutFile : public core::Processor {
   EXTENSIONAPI static constexpr const char* Description = "Writes the contents of a FlowFile to the local file system";
 
 #ifndef WIN32
-  EXTENSIONAPI static const core::Property Permissions;
-  EXTENSIONAPI static const core::Property DirectoryPermissions;
+  EXTENSIONAPI static constexpr auto Permissions = core::PropertyDefinitionBuilder<>::createProperty("Permissions")
+      .withDescription("Sets the permissions on the output file to the value of this attribute. "
+          "Must be an octal number (e.g. 644 or 0755). Not supported on Windows systems.")
+      .build();
+  EXTENSIONAPI static constexpr auto DirectoryPermissions = core::PropertyDefinitionBuilder<>::createProperty("Directory Permissions")
+      .withDescription("Sets the permissions on the directories being created if 'Create Missing Directories' property is set. "
+          "Must be an octal number (e.g. 644 or 0755). Not supported on Windows systems.")
+      .build();
 #endif
-  EXTENSIONAPI static const core::Property Directory;
-  EXTENSIONAPI static const core::Property ConflictResolution;
-  EXTENSIONAPI static const core::Property CreateDirs;
-  EXTENSIONAPI static const core::Property MaxDestFiles;
-  static auto properties() {
-    return std::array{
+  EXTENSIONAPI static constexpr auto Directory = core::PropertyDefinitionBuilder<>::createProperty("Directory")
+      .withDescription("The output directory to which to put files")
+      .supportsExpressionLanguage(true)
+      .withDefaultValue(".")
+      .build();
+  EXTENSIONAPI static constexpr auto ConflictResolution = core::PropertyDefinitionBuilder<3>::createProperty("Conflict Resolution Strategy")
+      .withDescription("Indicates what should happen when a file with the same name already exists in the output directory")
+      .withAllowedValues({CONFLICT_RESOLUTION_STRATEGY_FAIL, CONFLICT_RESOLUTION_STRATEGY_IGNORE, CONFLICT_RESOLUTION_STRATEGY_REPLACE})
+      .withDefaultValue(CONFLICT_RESOLUTION_STRATEGY_FAIL)
+      .build();
+  EXTENSIONAPI static constexpr auto CreateDirs = core::PropertyDefinitionBuilder<0, 1>::createProperty("Create Missing Directories")
+      .withDescription("If true, then missing destination directories will be created. If false, flowfiles are penalized and sent to failure.")
+      .withDefaultValue("true")
+      .isRequired(true)
+      .withDependentProperties({Directory.name})
+      .build();
+  EXTENSIONAPI static constexpr auto MaxDestFiles = core::PropertyDefinitionBuilder<>::createProperty("Maximum File Count")
+      .withDescription("Specifies the maximum number of files that can exist in the output directory")
+      .withPropertyType(core::StandardPropertyTypes::INTEGER_TYPE)
+      .withDefaultValue("-1")
+      .build();
+  EXTENSIONAPI static constexpr auto Properties =
 #ifndef WIN32
-      Permissions,
-      DirectoryPermissions,
+      std::array<core::PropertyReference, 6>{
+          Permissions,
+          DirectoryPermissions,
+#else
+      std::array<core::PropertyReference, 4>{
 #endif
-      Directory,
-      ConflictResolution,
-      CreateDirs,
-      MaxDestFiles
-    };
-  }
+          Directory,
+          ConflictResolution,
+          CreateDirs,
+          MaxDestFiles
+      };
 
-  EXTENSIONAPI static const core::Relationship Success;
-  EXTENSIONAPI static const core::Relationship Failure;
-  static auto relationships() { return std::array{Success, Failure}; }
+  EXTENSIONAPI static constexpr auto Success = core::RelationshipDefinition{"success", "All files are routed to success"};
+  EXTENSIONAPI static constexpr auto Failure = core::RelationshipDefinition{"failure", "Failed files (conflict, write failure, etc.) are transferred to failure"};
+  EXTENSIONAPI static constexpr auto Relationships = std::array{Success, Failure};
 
   EXTENSIONAPI static constexpr bool SupportsDynamicProperties = false;
   EXTENSIONAPI static constexpr bool SupportsDynamicRelationships = false;
@@ -133,6 +161,6 @@ class PutFile : public core::Processor {
   void getPermissions(core::ProcessContext *context);
   void getDirectoryPermissions(core::ProcessContext *context);
 #endif
-};
+};  // NOLINT the linter gets confused by the '{'s inside #ifdef's
 
 }  // namespace org::apache::nifi::minifi::processors
