@@ -48,7 +48,6 @@ using org::apache::nifi::minifi::utils::verifyLogLinePresenceInPollTime;
 
 class ListFileTestFixture {
  public:
-  static const std::string FORMAT_STRING;
   ListFileTestFixture();
 
  protected:
@@ -63,8 +62,6 @@ class ListFileTestFixture {
   std::filesystem::path second_sub_file_abs_path_;
 };
 
-const std::string ListFileTestFixture::FORMAT_STRING = "%Y-%m-%dT%H:%M:%SZ";
-
 ListFileTestFixture::ListFileTestFixture()
   : plan_(test_controller_.createPlan()),
     input_dir_(test_controller_.createTempDirectory()) {
@@ -75,9 +72,9 @@ ListFileTestFixture::ListFileTestFixture()
   REQUIRE(!input_dir_.empty());
 
   list_file_processor_ = plan_->addProcessor("ListFile", "ListFile");
-  plan_->setProperty(list_file_processor_, "Input Directory", input_dir_.string());
+  plan_->setProperty(list_file_processor_, minifi::processors::ListFile::InputDirectory, input_dir_.string());
   auto log_attribute = plan_->addProcessor("LogAttribute", "logAttribute", core::Relationship("success", "description"), true);
-  plan_->setProperty(log_attribute, "FlowFiles To Log", "0");
+  plan_->setProperty(log_attribute, minifi::processors::LogAttribute::FlowFilesToLog, "0");
 
   hidden_file_path_ = utils::putFileToDir(input_dir_, ".hidden_file.txt", "hidden");
   standard_file_abs_path_ = utils::putFileToDir(input_dir_, "standard_file.log", "test");
@@ -103,12 +100,16 @@ ListFileTestFixture::ListFileTestFixture()
 }
 
 TEST_CASE_METHOD(ListFileTestFixture, "Input Directory is empty", "[testListFile]") {
-  plan_->setProperty(list_file_processor_, "Input Directory", "");
+  plan_->setProperty(list_file_processor_, minifi::processors::ListFile::InputDirectory, "");
   REQUIRE_THROWS_AS(test_controller_.runSession(plan_, true), minifi::Exception);
 }
 
+std::string get_last_modified_time_formatted_string(const std::filesystem::path& path) {
+  return utils::timeutils::getDateTimeStr(std::chrono::time_point_cast<std::chrono::seconds>(utils::file::to_sys(*utils::file::last_write_time(path))));
+}
+
 TEST_CASE_METHOD(ListFileTestFixture, "Test listing files only once with default parameters", "[testListFile]") {
-  test_controller_.runSession(plan_);
+  TestController::runSession(plan_);
   REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:filename value:standard_file.log"));
   REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:filename value:empty_file.txt"));
   REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:filename value:sub_file_one.txt"));
@@ -135,19 +136,19 @@ TEST_CASE_METHOD(ListFileTestFixture, "Test listing files only once with default
   if (auto owner = utils::file::FileUtils::get_file_owner(standard_file_abs_path_)) {
     REQUIRE(LogTestController::getInstance().countOccurrences("key:file.owner value:" + *owner) == 4);
   }
-  REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:file.lastModifiedTime value:" + *utils::file::FileUtils::get_last_modified_time_formatted_string(empty_file_abs_path_, FORMAT_STRING)));
-  REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:file.lastModifiedTime value:" + *utils::file::FileUtils::get_last_modified_time_formatted_string(standard_file_abs_path_, FORMAT_STRING)));
-  REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:file.lastModifiedTime value:" + *utils::file::FileUtils::get_last_modified_time_formatted_string(first_sub_file_abs_path_, FORMAT_STRING)));
-  REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:file.lastModifiedTime value:" + *utils::file::FileUtils::get_last_modified_time_formatted_string(second_sub_file_abs_path_, FORMAT_STRING)));
+  REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:file.lastModifiedTime value:" + get_last_modified_time_formatted_string(empty_file_abs_path_)));
+  REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:file.lastModifiedTime value:" + get_last_modified_time_formatted_string(standard_file_abs_path_)));
+  REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:file.lastModifiedTime value:" + get_last_modified_time_formatted_string(first_sub_file_abs_path_)));
+  REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:file.lastModifiedTime value:" + get_last_modified_time_formatted_string(second_sub_file_abs_path_)));
   plan_->reset();
   LogTestController::getInstance().clear();
-  test_controller_.runSession(plan_, true);
+  TestController::runSession(plan_, true);
   REQUIRE_FALSE(LogTestController::getInstance().contains("key:file.size", 0s, 0ms));
 }
 
 TEST_CASE_METHOD(ListFileTestFixture, "Test turning off recursive file listing", "[testListFile]") {
-  plan_->setProperty(list_file_processor_, "Recurse Subdirectories", "false");
-  test_controller_.runSession(plan_);
+  plan_->setProperty(list_file_processor_, minifi::processors::ListFile::RecurseSubdirectories, "false");
+  TestController::runSession(plan_);
   REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:filename value:standard_file.log"));
   REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:filename value:empty_file.txt"));
   REQUIRE_FALSE(LogTestController::getInstance().contains("key:filename value:sub_file_one.txt", 0s, 0ms));
@@ -155,8 +156,8 @@ TEST_CASE_METHOD(ListFileTestFixture, "Test turning off recursive file listing",
 }
 
 TEST_CASE_METHOD(ListFileTestFixture, "Test listing files matching the File Filter pattern", "[testListFile]") {
-  plan_->setProperty(list_file_processor_, "File Filter", "stand\\w+\\.log");
-  test_controller_.runSession(plan_);
+  plan_->setProperty(list_file_processor_, minifi::processors::ListFile::FileFilter, "stand\\w+\\.log");
+  TestController::runSession(plan_);
   REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:filename value:standard_file.log"));
   REQUIRE_FALSE(LogTestController::getInstance().contains("key:filename value:empty_file.txt", 0s, 0ms));
   REQUIRE_FALSE(LogTestController::getInstance().contains("key:filename value:sub_file_one.txt", 0s, 0ms));
@@ -164,15 +165,15 @@ TEST_CASE_METHOD(ListFileTestFixture, "Test listing files matching the File Filt
 }
 
 TEST_CASE_METHOD(ListFileTestFixture, "Test listing files matching the Path Filter pattern", "[testListFile]") {
-  plan_->setProperty(list_file_processor_, "Path Filter", "first.*");
-  test_controller_.runSession(plan_);
+  plan_->setProperty(list_file_processor_, minifi::processors::ListFile::PathFilter, "first.*");
+  TestController::runSession(plan_);
   CHECK(verifyLogLinePresenceInPollTime(3s, "key:filename value:sub_file_one.txt"));
   CHECK(LogTestController::getInstance().countOccurrences("key:filename value:") == 1);
 }
 
 TEST_CASE_METHOD(ListFileTestFixture, "Test listing files matching the Path Filter pattern when the pattern also matches .", "[testListFile]") {
-  plan_->setProperty(list_file_processor_, "Path Filter", "second.*|\\.");
-  test_controller_.runSession(plan_);
+  plan_->setProperty(list_file_processor_, minifi::processors::ListFile::PathFilter, "second.*|\\.");
+  TestController::runSession(plan_);
   CHECK(verifyLogLinePresenceInPollTime(3s, "key:filename value:standard_file.log"));
   CHECK(verifyLogLinePresenceInPollTime(3s, "key:filename value:empty_file.txt"));
   CHECK(verifyLogLinePresenceInPollTime(3s, "key:filename value:sub_file_two.txt"));
@@ -180,8 +181,8 @@ TEST_CASE_METHOD(ListFileTestFixture, "Test listing files matching the Path Filt
 }
 
 TEST_CASE_METHOD(ListFileTestFixture, "Test listing files with restriction on the minimum file age", "[testListFile]") {
-  plan_->setProperty(list_file_processor_, "Minimum File Age", "90 min");
-  test_controller_.runSession(plan_);
+  plan_->setProperty(list_file_processor_, minifi::processors::ListFile::MinimumFileAge, "90 min");
+  TestController::runSession(plan_);
   REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:filename value:sub_file_one.txt"));
   REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:filename value:sub_file_two.txt"));
   REQUIRE(LogTestController::getInstance().countOccurrences("key:filename value:empty_file.txt") == 0);
@@ -189,8 +190,8 @@ TEST_CASE_METHOD(ListFileTestFixture, "Test listing files with restriction on th
 }
 
 TEST_CASE_METHOD(ListFileTestFixture, "Test listing files with restriction on the maximum file age", "[testListFile]") {
-  plan_->setProperty(list_file_processor_, "Maximum File Age", "90 min");
-  test_controller_.runSession(plan_);
+  plan_->setProperty(list_file_processor_, minifi::processors::ListFile::MaximumFileAge, "90 min");
+  TestController::runSession(plan_);
   REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:filename value:empty_file.txt"));
   REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:filename value:standard_file.log"));
   REQUIRE(LogTestController::getInstance().countOccurrences("key:filename value:sub_file_one.txt") == 0);
@@ -198,8 +199,8 @@ TEST_CASE_METHOD(ListFileTestFixture, "Test listing files with restriction on th
 }
 
 TEST_CASE_METHOD(ListFileTestFixture, "Test listing files with restriction on the minimum file size", "[testListFile]") {
-  plan_->setProperty(list_file_processor_, "Minimum File Size", "4 B");
-  test_controller_.runSession(plan_);
+  plan_->setProperty(list_file_processor_, minifi::processors::ListFile::MinimumFileSize, "4 B");
+  TestController::runSession(plan_);
   REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:filename value:standard_file.log"));
   REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:filename value:sub_file_two.txt"));
   REQUIRE(LogTestController::getInstance().countOccurrences("key:filename value:empty_file.txt") == 0);
@@ -207,8 +208,8 @@ TEST_CASE_METHOD(ListFileTestFixture, "Test listing files with restriction on th
 }
 
 TEST_CASE_METHOD(ListFileTestFixture, "Test listing files with restriction on the maximum file size", "[testListFile]") {
-  plan_->setProperty(list_file_processor_, "Maximum File Size", "4 B");
-  test_controller_.runSession(plan_);
+  plan_->setProperty(list_file_processor_, minifi::processors::ListFile::MaximumFileSize, "4 B");
+  TestController::runSession(plan_);
   REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:filename value:standard_file.log"));
   REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:filename value:empty_file.txt"));
   REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:filename value:sub_file_one.txt"));
@@ -216,8 +217,8 @@ TEST_CASE_METHOD(ListFileTestFixture, "Test listing files with restriction on th
 }
 
 TEST_CASE_METHOD(ListFileTestFixture, "Test listing hidden files", "[testListFile]") {
-  plan_->setProperty(list_file_processor_, "Ignore Hidden Files", "false");
-  test_controller_.runSession(plan_);
+  plan_->setProperty(list_file_processor_, minifi::processors::ListFile::IgnoreHiddenFiles, "false");
+  TestController::runSession(plan_);
   REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:filename value:standard_file.log"));
   REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:filename value:empty_file.txt"));
   REQUIRE(verifyLogLinePresenceInPollTime(3s, "key:filename value:sub_file_one.txt"));
