@@ -265,14 +265,14 @@ TEST_CASE("ListenSyslog without parsing test", "[ListenSyslog]") {
     port = utils::scheduleProcessorOnRandomPort(controller.plan, listen_syslog);
 
     asio::ip::udp::endpoint endpoint;
-    SECTION("sending through IPv4", "[IPv4]") {
-      endpoint = asio::ip::udp::endpoint(asio::ip::address_v4::loopback(), port);
-    }
     SECTION("sending through IPv6", "[IPv6]") {
       if (utils::isIPv6Disabled())
-        return;
+        SKIP("IPv6 is disabled");
       endpoint = asio::ip::udp::endpoint(asio::ip::address_v6::loopback(), port);
     }
+    SECTION("sending through IPv4", "[IPv4]") {
+      endpoint = asio::ip::udp::endpoint(asio::ip::address_v4::loopback(), port);
+    }
     protocol = "UDP";
     CHECK_THAT(utils::sendUdpDatagram(rfc5424_logger_example_1, endpoint), MatchesSuccess());
     CHECK_THAT(utils::sendUdpDatagram(invalid_syslog, endpoint), MatchesSuccess());
@@ -285,14 +285,14 @@ TEST_CASE("ListenSyslog without parsing test", "[ListenSyslog]") {
     port = utils::scheduleProcessorOnRandomPort(controller.plan, listen_syslog);
 
     asio::ip::tcp::endpoint endpoint;
-    SECTION("sending through IPv4", "[IPv4]") {
-      endpoint = asio::ip::tcp::endpoint(asio::ip::address_v4::loopback(), port);
-    }
     SECTION("sending through IPv6", "[IPv6]") {
       if (utils::isIPv6Disabled())
-        return;
+        SKIP("IPv6 is disabled");
       endpoint = asio::ip::tcp::endpoint(asio::ip::address_v6::loopback(), port);
     }
+    SECTION("sending through IPv4", "[IPv4]") {
+      endpoint = asio::ip::tcp::endpoint(asio::ip::address_v4::loopback(), port);
+    }
     CHECK_THAT(utils::sendMessagesViaTCP({rfc5424_logger_example_1}, endpoint), MatchesSuccess());
     CHECK_THAT(utils::sendMessagesViaTCP({invalid_syslog}, endpoint), MatchesSuccess());
   }
@@ -322,14 +322,14 @@ TEST_CASE("ListenSyslog with parsing test", "[ListenSyslog][NetworkListenerProce
     port = utils::scheduleProcessorOnRandomPort(controller.plan, listen_syslog);
 
     asio::ip::udp::endpoint endpoint;
-    SECTION("sending through IPv4", "[IPv4]") {
-      endpoint = asio::ip::udp::endpoint(asio::ip::address_v4::loopback(), port);
-    }
     SECTION("sending through IPv6", "[IPv6]") {
       if (utils::isIPv6Disabled())
-        return;
+        SKIP("IPv6 is disabled");
       endpoint = asio::ip::udp::endpoint(asio::ip::address_v6::loopback(), port);
     }
+    SECTION("sending through IPv4", "[IPv4]") {
+      endpoint = asio::ip::udp::endpoint(asio::ip::address_v4::loopback(), port);
+    }
 
     CHECK_THAT(utils::sendUdpDatagram(rfc5424_doc_example_1.unparsed_, endpoint), MatchesSuccess());
     CHECK_THAT(utils::sendUdpDatagram(rfc5424_doc_example_2.unparsed_, endpoint), MatchesSuccess());
@@ -352,14 +352,14 @@ TEST_CASE("ListenSyslog with parsing test", "[ListenSyslog][NetworkListenerProce
     port = utils::scheduleProcessorOnRandomPort(controller.plan, listen_syslog);
 
     asio::ip::tcp::endpoint endpoint;
-    SECTION("sending through IPv4", "[IPv4]") {
-      endpoint = asio::ip::tcp::endpoint(asio::ip::address_v4::loopback(), port);
-    }
     SECTION("sending through IPv6", "[IPv6]") {
       if (utils::isIPv6Disabled())
-        return;
+        SKIP("IPv6 is disabled");
       endpoint = asio::ip::tcp::endpoint(asio::ip::address_v6::loopback(), port);
     }
+    SECTION("sending through IPv4", "[IPv4]") {
+      endpoint = asio::ip::tcp::endpoint(asio::ip::address_v4::loopback(), port);
+    }
 
     CHECK_THAT(utils::sendMessagesViaTCP({rfc5424_doc_example_1.unparsed_,
                                           rfc5424_doc_example_2.unparsed_,
@@ -450,14 +450,14 @@ TEST_CASE("ListenSyslog max queue and max batch size test", "[ListenSyslog][Netw
     port = utils::scheduleProcessorOnRandomPort(controller.plan, listen_syslog);
 
     asio::ip::udp::endpoint endpoint;
-    SECTION("sending through IPv4", "[IPv4]") {
-      endpoint = asio::ip::udp::endpoint(asio::ip::address_v4::loopback(), port);
-    }
     SECTION("sending through IPv6", "[IPv6]") {
       if (utils::isIPv6Disabled())
-        return;
+        SKIP("IPv6 is disabled");
       endpoint = asio::ip::udp::endpoint(asio::ip::address_v6::loopback(), port);
     }
+    SECTION("sending through IPv4", "[IPv4]") {
+      endpoint = asio::ip::udp::endpoint(asio::ip::address_v4::loopback(), port);
+    }
     for (auto i = 0; i < 100; ++i) {
       CHECK_THAT(utils::sendUdpDatagram(rfc5424_doc_example_1.unparsed_, endpoint), MatchesSuccess());
     }
@@ -469,14 +469,16 @@ TEST_CASE("ListenSyslog max queue and max batch size test", "[ListenSyslog][Netw
     port = utils::scheduleProcessorOnRandomPort(controller.plan, listen_syslog);
 
     asio::ip::tcp::endpoint endpoint;
+    SECTION("sending through IPv6", "[IPv6]") {
+      if (utils::isIPv6Disabled())
+        SKIP("IPv6 is disabled");
+      endpoint = asio::ip::tcp::endpoint(asio::ip::address_v6::loopback(), port);
+    }
+
     SECTION("sending through IPv4", "[IPv4]") {
       endpoint = asio::ip::tcp::endpoint(asio::ip::address_v4::loopback(), port);
     }
-    SECTION("sending through IPv6", "[IPv6]") {
-      if (utils::isIPv6Disabled())
-        return;
-      endpoint = asio::ip::tcp::endpoint(asio::ip::address_v6::loopback(), port);
-    }
+
     for (auto i = 0; i < 100; ++i) {
       CHECK_THAT(utils::sendMessagesViaTCP({rfc5424_doc_example_1.unparsed_}, endpoint), MatchesSuccess());
     }
@@ -496,9 +498,9 @@ TEST_CASE("Test ListenSyslog via TCP with SSL connection", "[ListenSyslog][Netwo
 
   auto ssl_context_service = controller.plan->addController("SSLContextService", "SSLContextService");
   const auto executable_dir = minifi::utils::file::FileUtils::get_executable_dir();
-  REQUIRE(controller.plan->setProperty(ssl_context_service, controllers::SSLContextService::CACertificate.getName(), (executable_dir / "resources" / "ca_A.crt").string()));
-  REQUIRE(controller.plan->setProperty(ssl_context_service, controllers::SSLContextService::ClientCertificate.getName(), (executable_dir / "resources" / "localhost_by_A.pem").string()));
-  REQUIRE(controller.plan->setProperty(ssl_context_service, controllers::SSLContextService::PrivateKey.getName(), (executable_dir / "resources" / "localhost_by_A.pem").string()));
+  REQUIRE(controller.plan->setProperty(ssl_context_service, controllers::SSLContextService::CACertificate, (executable_dir / "resources" / "ca_A.crt").string()));
+  REQUIRE(controller.plan->setProperty(ssl_context_service, controllers::SSLContextService::ClientCertificate, (executable_dir / "resources" / "localhost_by_A.pem").string()));
+  REQUIRE(controller.plan->setProperty(ssl_context_service, controllers::SSLContextService::PrivateKey, (executable_dir / "resources" / "localhost.key").string()));
   ssl_context_service->enable();
 
   LogTestController::getInstance().setTrace<ListenSyslog>();
@@ -510,14 +512,14 @@ TEST_CASE("Test ListenSyslog via TCP with SSL connection", "[ListenSyslog][Netwo
   auto port = utils::scheduleProcessorOnRandomPort(controller.plan, listen_syslog);
 
   asio::ip::tcp::endpoint endpoint;
-  SECTION("sending through IPv4", "[IPv4]") {
-    endpoint = asio::ip::tcp::endpoint(asio::ip::address_v4::loopback(), port);
-  }
   SECTION("sending through IPv6", "[IPv6]") {
     if (utils::isIPv6Disabled())
-      return;
+      SKIP("IPv6 is disabled");
     endpoint = asio::ip::tcp::endpoint(asio::ip::address_v6::loopback(), port);
   }
+  SECTION("sending through IPv4", "[IPv4]") {
+    endpoint = asio::ip::tcp::endpoint(asio::ip::address_v4::loopback(), port);
+  }
 
   CHECK_THAT(utils::sendMessagesViaSSL({rfc5424_logger_example_1}, endpoint, executable_dir / "resources" / "ca_A.crt"), MatchesSuccess());
   CHECK_THAT(utils::sendMessagesViaSSL({invalid_syslog}, endpoint, executable_dir / "resources" / "ca_A.crt"), MatchesSuccess());
