@@ -32,6 +32,7 @@
 
 #include "TestBase.h"
 #include "Catch.h"
+#include "catch2/matchers/catch_matchers_string.hpp"
 #include "LogAttribute.h"
 #include "GetFile.h"
 #include "unit/ProvenanceTestHelper.h"
@@ -182,8 +183,6 @@ TEST_CASE("Test GetFile Ignore", "[getfileCreate3]") {
 
   processor->onSchedule(context, factory);
 
-  int prev = 0;
-
   auto session = std::make_shared<core::ProcessSession>(context);
   REQUIRE(processor->getName() == "getfileCreate2");
 
@@ -228,7 +227,6 @@ TEST_CASE("Test GetFile Ignore", "[getfileCreate3]") {
   std::shared_ptr<core::FlowFile> ffr = session->get();
 
   REQUIRE(repo->getRepoMap().empty());
-  prev++;
 }
 
 TEST_CASE("TestConnectionFull", "[ConnectionFull]") {
@@ -241,7 +239,6 @@ TEST_CASE("TestConnectionFull", "[ConnectionFull]") {
   processor->setProperty(minifi::processors::GenerateFlowFile::BatchSize, "10");
   processor->setProperty(minifi::processors::GenerateFlowFile::FileSize, "0");
 
-
   std::shared_ptr<core::Repository> test_repo = std::make_shared<TestRepository>();
   std::shared_ptr<TestRepository> repo = std::static_pointer_cast<TestRepository>(test_repo);
 
@@ -249,7 +246,6 @@ TEST_CASE("TestConnectionFull", "[ConnectionFull]") {
   connection->setBackpressureThresholdCount(5);
   connection->addRelationship(core::Relationship("success", "description"));
 
-
   utils::Identifier processoruuid = processor->getUUID();
 
   // link the connections so that we can test results at the end for this
@@ -295,7 +291,7 @@ TEST_CASE("LogAttributeTest", "[getfileCreate3]") {
 
   auto dir = testController.createTempDirectory();
 
-  plan->setProperty(getfile, org::apache::nifi::minifi::processors::GetFile::Directory.getName(), dir.string());
+  plan->setProperty(getfile, org::apache::nifi::minifi::processors::GetFile::Directory, dir.string());
   testController.runSession(plan, false);
   auto records = plan->getProvenanceRecords();
   std::shared_ptr<core::FlowFile> record = plan->getCurrentFlowFile();
@@ -337,9 +333,9 @@ TEST_CASE("LogAttributeTestInvalid", "[TestLogAttribute]") {
 
   auto dir = testController.createTempDirectory();
 
-  plan->setProperty(getfile, org::apache::nifi::minifi::processors::GetFile::Directory.getName(), dir.string());
-  plan->setProperty(getfile, org::apache::nifi::minifi::processors::GetFile::BatchSize.getName(), "1");
-  REQUIRE_THROWS_AS(plan->setProperty(loggattr, org::apache::nifi::minifi::processors::LogAttribute::FlowFilesToLog.getName(), "-1"), utils::internal::ParseException);
+  plan->setProperty(getfile, org::apache::nifi::minifi::processors::GetFile::Directory, dir.string());
+  plan->setProperty(getfile, org::apache::nifi::minifi::processors::GetFile::BatchSize, "1");
+  REQUIRE_THROWS_AS(plan->setProperty(loggattr, org::apache::nifi::minifi::processors::LogAttribute::FlowFilesToLog, "-1"), utils::internal::ParseException);
   LogTestController::getInstance().reset();
 }
 
@@ -358,9 +354,9 @@ void testMultiplesLogAttribute(int fileCount, int flowsToLog, std::string verify
   auto flowsToLogStr = std::to_string(flowsToLog);
   if (verifyStringFlowsLogged.empty())
     verifyStringFlowsLogged = std::to_string(flowsToLog);
-  plan->setProperty(getfile, org::apache::nifi::minifi::processors::GetFile::Directory.getName(), dir.string());
-  plan->setProperty(getfile, org::apache::nifi::minifi::processors::GetFile::BatchSize.getName(), std::to_string(fileCount));
-  plan->setProperty(loggattr, org::apache::nifi::minifi::processors::LogAttribute::FlowFilesToLog.getName(), flowsToLogStr);
+  plan->setProperty(getfile, org::apache::nifi::minifi::processors::GetFile::Directory, dir.string());
+  plan->setProperty(getfile, org::apache::nifi::minifi::processors::GetFile::BatchSize, std::to_string(fileCount));
+  plan->setProperty(loggattr, org::apache::nifi::minifi::processors::LogAttribute::FlowFilesToLog, flowsToLogStr);
   testController.runSession(plan, false);
   auto records = plan->getProvenanceRecords();
   std::shared_ptr<core::FlowFile> record = plan->getCurrentFlowFile();
@@ -417,11 +413,11 @@ TEST_CASE("Test Find file", "[getfileCreate3]") {
   std::shared_ptr<TestPlan> plan = testController.createPlan();
   std::shared_ptr<core::Processor> processor = plan->addProcessor("GetFile", "getfileCreate2");
   std::shared_ptr<core::Processor> processorReport = std::make_shared<org::apache::nifi::minifi::core::reporting::SiteToSiteProvenanceReportingTask>(
-      minifi::io::StreamFactory::getInstance(std::make_shared<org::apache::nifi::minifi::Configure>()), std::make_shared<org::apache::nifi::minifi::Configure>());
+      std::make_shared<org::apache::nifi::minifi::Configure>());
   plan->addProcessor(processorReport, "reporter", core::Relationship("success", "description"), false);
 
   auto dir = testController.createTempDirectory();
-  plan->setProperty(processor, org::apache::nifi::minifi::processors::GetFile::Directory.getName(), dir.string());
+  plan->setProperty(processor, org::apache::nifi::minifi::processors::GetFile::Directory, dir.string());
   testController.runSession(plan, false);
   auto records = plan->getProvenanceRecords();
   std::shared_ptr<core::FlowFile> record = plan->getCurrentFlowFile();
@@ -491,14 +487,14 @@ TEST_CASE("Test Find file", "[getfileCreate3]") {
 
 class TestProcessorNoContent : public minifi::core::Processor {
  public:
-  explicit TestProcessorNoContent(std::string name, const utils::Identifier& uuid = {})
-      : Processor(std::move(name), uuid) {
+  explicit TestProcessorNoContent(std::string_view name, const utils::Identifier& uuid = {})
+      : Processor(name, uuid) {
   }
 
   static constexpr const char* Description = "test resource";
-  static auto properties() { return std::array<core::Property, 0>{}; }
-  static const core::Relationship Success;
-  static auto relationships() { return std::array{Success}; }
+  static constexpr auto Properties = std::array<core::PropertyReference, 0>{};
+  static constexpr auto Success = core::RelationshipDefinition{"success", "All files are routed to success"};
+  static constexpr auto Relationships = std::array{Success};
   static constexpr bool SupportsDynamicProperties = false;
   static constexpr bool SupportsDynamicRelationships = false;
   static constexpr core::annotation::Input InputRequirement = core::annotation::Input::INPUT_ALLOWED;
@@ -515,8 +511,6 @@ class TestProcessorNoContent : public minifi::core::Processor {
   }
 };
 
-const core::Relationship TestProcessorNoContent::Success("success", "All files are routed to success");
-
 REGISTER_RESOURCE(TestProcessorNoContent, Processor);
 
 TEST_CASE("TestEmptyContent", "[emptyContent]") {
@@ -549,14 +543,13 @@ void testRPGBypass(const std::string &host, const std::string &port, const std::
   LogTestController::getInstance().setTrace<TestPlan>();
 
   auto configuration = std::make_shared<org::apache::nifi::minifi::Configure>();
-  auto factory = minifi::io::StreamFactory::getInstance(configuration);
 
   std::shared_ptr<core::ContentRepository> content_repo = std::make_shared<core::repository::VolatileContentRepository>();
 
   std::shared_ptr<core::Repository> test_repo = std::make_shared<TestRepository>();
   std::shared_ptr<TestRepository> repo = std::static_pointer_cast<TestRepository>(test_repo);
 
-  auto rpg = std::make_shared<minifi::RemoteProcessorGroupPort>(factory, "rpg", "http://localhost:8989/nifi", configuration);
+  auto rpg = std::make_shared<minifi::RemoteProcessorGroupPort>("rpg", "http://localhost:8989/nifi", configuration);
   rpg->initialize();
   REQUIRE(rpg->setProperty(minifi::RemoteProcessorGroupPort::hostName, host));
   rpg->setProperty(minifi::RemoteProcessorGroupPort::port, port);
@@ -754,7 +747,7 @@ TEST_CASE("InputRequirementTestForbidden", "[InputRequirement]") {
   plan->addProcessor("GenerateFlowFile", "generateFlowFile");
   plan->addProcessor("GenerateFlowFile", "generateFlowFile2", core::Relationship("success", "description"), true);
 
-  REQUIRE_THROWS_WITH(plan->validateAnnotations(), Catch::EndsWith("INPUT_FORBIDDEN was specified for the processor, but there are incoming connections"));
+  REQUIRE_THROWS_WITH(plan->validateAnnotations(), Catch::Matchers::EndsWith("INPUT_FORBIDDEN was specified for the processor, but there are incoming connections"));
   testController.runSession(plan);
 }
 
@@ -766,7 +759,7 @@ TEST_CASE("InputRequirementTestRequired", "[InputRequirement]") {
   plan->addProcessor("LogAttribute", "logAttribute");
   plan->addProcessor("LogAttribute", "logAttribute2", core::Relationship("success", "description"), true);
 
-  REQUIRE_THROWS_WITH(plan->validateAnnotations(), Catch::EndsWith("INPUT_REQUIRED was specified for the processor, but no incoming connections were found"));
+  REQUIRE_THROWS_WITH(plan->validateAnnotations(), Catch::Matchers::EndsWith("INPUT_REQUIRED was specified for the processor, but no incoming connections were found"));
   testController.runSession(plan);
 }
 
@@ -824,3 +817,9 @@ TEST_CASE("Test getProcessorType", "[getProcessorType]") {
   auto processor = plan->addProcessor("GenerateFlowFile", "myProc");
   REQUIRE(processor->getProcessorType() == "GenerateFlowFile");
 }
+
+TEST_CASE("IsYield and getYieldTime is consistent") {
+  auto processor = TestProcessorNoContent("test_processor");
+  processor.yield(1ms);
+  REQUIRE(processor.isYield() == (processor.getYieldTime() != 0ms));
+}
