@@ -26,9 +26,9 @@
 #include "TailFile.h"
 #include "TestBase.h"
 #include "Catch.h"
-#include "utils/TestUtils.h"
 #include "utils/StringUtils.h"
 #include "ConfigurationTestController.h"
+#include "utils/IntegrationTestUtils.h"
 
 using namespace std::literals::chrono_literals;
 
@@ -141,8 +141,7 @@ Provenance Reporting:
     batch size: 1000;
         )";
 
-    std::istringstream configYamlStream(CONFIG_YAML_WITHOUT_IDS);
-    std::unique_ptr<core::ProcessGroup> rootFlowConfig = yamlConfig.getYamlRoot(configYamlStream);
+    std::unique_ptr<core::ProcessGroup> rootFlowConfig = yamlConfig.getRootFromPayload(CONFIG_YAML_WITHOUT_IDS);
 
     REQUIRE(rootFlowConfig);
     REQUIRE(rootFlowConfig->findProcessorByName("TailFile"));
@@ -151,16 +150,16 @@ Provenance Reporting:
     REQUIRE(!rootFlowConfig->findProcessorByName("TailFile")->getUUIDStr().empty());
     REQUIRE(1 == rootFlowConfig->findProcessorByName("TailFile")->getMaxConcurrentTasks());
     REQUIRE(core::SchedulingStrategy::TIMER_DRIVEN == rootFlowConfig->findProcessorByName("TailFile")->getSchedulingStrategy());
-    REQUIRE(1s == rootFlowConfig->findProcessorByName("TailFile")->getSchedulingPeriodNano());
+    REQUIRE(1s == rootFlowConfig->findProcessorByName("TailFile")->getSchedulingPeriod());
     REQUIRE(30s == rootFlowConfig->findProcessorByName("TailFile")->getPenalizationPeriod());
-    REQUIRE(1s == rootFlowConfig->findProcessorByName("TailFile")->getYieldPeriodMsec());
+    REQUIRE(1s == rootFlowConfig->findProcessorByName("TailFile")->getYieldPeriod());
     REQUIRE(0s == rootFlowConfig->findProcessorByName("TailFile")->getRunDurationNano());
 
     std::map<std::string, minifi::Connection*> connectionMap;
     rootFlowConfig->getConnections(connectionMap);
     REQUIRE(2 == connectionMap.size());
     // This is a map of UUID->Connection, and we don't know UUID, so just going to loop over it
-    for (auto it : connectionMap) {
+    for (const auto& it : connectionMap) {
       REQUIRE(it.second);
       REQUIRE(!it.second->getUUIDStr().empty());
       REQUIRE(it.second->getDestination());
@@ -190,8 +189,7 @@ Remote Processing Groups:
             use compression: false
       )";
 
-    std::istringstream configYamlStream(CONFIG_YAML_NO_RPG_PORT_ID);
-    REQUIRE_THROWS_AS(yamlConfig.getYamlRoot(configYamlStream), std::invalid_argument);
+    REQUIRE_THROWS_AS(yamlConfig.getRootFromPayload(CONFIG_YAML_NO_RPG_PORT_ID), std::invalid_argument);
   }
 
   SECTION("Validated YAML property failure throws exception and logs invalid attribute name") {
@@ -212,8 +210,7 @@ Remote Processing Groups: []
 Provenance Reporting:
       )";
 
-    std::istringstream configYamlStream(CONFIG_YAML_EMPTY_RETRY_ATTRIBUTE);
-    REQUIRE_THROWS_AS(yamlConfig.getYamlRoot(configYamlStream), utils::internal::InvalidValueException);
+    REQUIRE_THROWS_AS(yamlConfig.getRootFromPayload(CONFIG_YAML_EMPTY_RETRY_ATTRIBUTE), utils::internal::InvalidValueException);
     REQUIRE(LogTestController::getInstance().contains("Invalid value was set for property 'Retry Attribute' creating component 'RetryFlowFile'"));
   }
 }
@@ -334,9 +331,8 @@ Remote Process Groups:
   Output Ports: []
 NiFi Properties Overrides: {}
       )";
-  std::istringstream configYamlStream(TEST_CONFIG_YAML);
 
-  REQUIRE_THROWS_AS(yamlConfig.getYamlRoot(configYamlStream), minifi::Exception);
+  REQUIRE_THROWS_AS(yamlConfig.getRootFromPayload(TEST_CONFIG_YAML), minifi::Exception);
 }
 
 TEST_CASE("Test YAML v3 Config Processing", "[YamlConfiguration3]") {
@@ -455,8 +451,7 @@ Remote Process Groups:
   Output Ports: []
 NiFi Properties Overrides: {}
       )";
-  std::istringstream configYamlStream(TEST_CONFIG_YAML);
-  std::unique_ptr<core::ProcessGroup> rootFlowConfig = yamlConfig.getYamlRoot(configYamlStream);
+  std::unique_ptr<core::ProcessGroup> rootFlowConfig = yamlConfig.getRootFromPayload(TEST_CONFIG_YAML);
 
   REQUIRE(rootFlowConfig);
   REQUIRE(rootFlowConfig->findProcessorByName("TailFile"));
@@ -466,16 +461,16 @@ NiFi Properties Overrides: {}
   REQUIRE(1 == rootFlowConfig->findProcessorByName("TailFile")->getMaxConcurrentTasks());
   REQUIRE(core::SchedulingStrategy::TIMER_DRIVEN == rootFlowConfig->findProcessorByName("TailFile")->getSchedulingStrategy());
   REQUIRE(1 == rootFlowConfig->findProcessorByName("TailFile")->getMaxConcurrentTasks());
-  REQUIRE(1s == rootFlowConfig->findProcessorByName("TailFile")->getSchedulingPeriodNano());
+  REQUIRE(1s == rootFlowConfig->findProcessorByName("TailFile")->getSchedulingPeriod());
   REQUIRE(30s == rootFlowConfig->findProcessorByName("TailFile")->getPenalizationPeriod());
-  REQUIRE(1s == rootFlowConfig->findProcessorByName("TailFile")->getYieldPeriodMsec());
+  REQUIRE(1s == rootFlowConfig->findProcessorByName("TailFile")->getYieldPeriod());
   REQUIRE(0s == rootFlowConfig->findProcessorByName("TailFile")->getRunDurationNano());
 
   std::map<std::string, minifi::Connection*> connectionMap;
   rootFlowConfig->getConnections(connectionMap);
   REQUIRE(2 == connectionMap.size());
 
-  for (auto it : connectionMap) {
+  for (const auto& it : connectionMap) {
     REQUIRE(it.second);
     REQUIRE(!it.second->getUUIDStr().empty());
     REQUIRE(it.second->getDestination());
@@ -498,8 +493,7 @@ Processors:
   Properties:
      Dynamic Property: Bad
       )";
-  std::istringstream configYamlStream(TEST_CONFIG_YAML);
-  std::unique_ptr<core::ProcessGroup> rootFlowConfig = yamlConfig.getYamlRoot(configYamlStream);
+  std::unique_ptr<core::ProcessGroup> rootFlowConfig = yamlConfig.getRootFromPayload(TEST_CONFIG_YAML);
 
   REQUIRE(rootFlowConfig);
   REQUIRE(rootFlowConfig->findProcessorByName("GenerateFlowFile"));
@@ -526,11 +520,10 @@ Processors:
     Input Directory: ""
     Batch Size: 1
       )";
-  std::istringstream configYamlStream(TEST_CONFIG_YAML);
   bool caught_exception = false;
 
   try {
-    std::unique_ptr<core::ProcessGroup> rootFlowConfig = yamlConfig.getYamlRoot(configYamlStream);
+    std::unique_ptr<core::ProcessGroup> rootFlowConfig = yamlConfig.getRootFromPayload(TEST_CONFIG_YAML);
 
     REQUIRE(rootFlowConfig);
     REQUIRE(rootFlowConfig->findProcessorByName("GetFile"));
@@ -561,8 +554,7 @@ Processors:
     Input Directory: "/"
     Batch Size: 1
       )";
-  std::istringstream configYamlStream(TEST_CONFIG_YAML);
-  std::unique_ptr<core::ProcessGroup> rootFlowConfig = yamlConfig.getYamlRoot(configYamlStream);
+  std::unique_ptr<core::ProcessGroup> rootFlowConfig = yamlConfig.getRootFromPayload(TEST_CONFIG_YAML);
 
   REQUIRE(rootFlowConfig);
   REQUIRE(rootFlowConfig->findProcessorByName("XYZ"));
@@ -591,9 +583,9 @@ TEST_CASE("Test Dependent Property", "[YamlConfigurationDependentProperty]") {
 
   core::YamlConfiguration yamlConfig(test_controller.getContext());
   const auto component = std::make_shared<DummyComponent>();
-  component->setSupportedProperties(std::array{
-    core::Property("Prop A", "Prop A desc", "val A", true, "", { }, { }),
-    core::Property("Prop B", "Prop B desc", "val B", true, "", { "Prop A" }, { })
+  component->setSupportedProperties(std::array<core::PropertyReference, 2>{
+    core::PropertyDefinitionBuilder<>::createProperty("Prop A").withDescription("Prop A desc").withDefaultValue("val A").isRequired(true).build(),
+    core::PropertyDefinitionBuilder<0, 1>::createProperty("Prop B").withDescription("Prop B desc").withDefaultValue("val B").isRequired(true).withDependentProperties({ "Prop A" }).build()
   });
   yamlConfig.validateComponentProperties(*component, "component A", "section A");
   REQUIRE(true);  // Expected to get here w/o any exceptions
@@ -604,9 +596,9 @@ TEST_CASE("Test Dependent Property 2", "[YamlConfigurationDependentProperty2]")
 
   core::YamlConfiguration yamlConfig(test_controller.getContext());
   const auto component = std::make_shared<DummyComponent>();
-  component->setSupportedProperties(std::array{
-    core::Property("Prop A", "Prop A desc", "", false, "", { }, { }),
-    core::Property("Prop B", "Prop B desc", "val B", true, "", { "Prop A" }, { })
+  component->setSupportedProperties(std::array<core::PropertyReference, 2>{
+    core::PropertyDefinitionBuilder<>::createProperty("Prop A").withDescription("Prop A desc").isRequired(false).build(),
+    core::PropertyDefinitionBuilder<0, 1>::createProperty("Prop B").withDescription("Prop B desc").withDefaultValue("val B").isRequired(true).withDependentProperties({ "Prop A" }).build()
   });
   bool config_failed = false;
   try {
@@ -620,40 +612,29 @@ TEST_CASE("Test Dependent Property 2", "[YamlConfigurationDependentProperty2]")
   REQUIRE(config_failed);
 }
 
-TEST_CASE("Test Exclusive Property", "[YamlConfigurationExclusiveProperty]") {
+TEST_CASE("Test Exclusive Property", "[YamlConfigurationExclusiveOfProperty]") {
   ConfigurationTestController test_controller;
 
   core::YamlConfiguration yamlConfig(test_controller.getContext());
   const auto component = std::make_shared<DummyComponent>();
-  component->setSupportedProperties(std::array{
-    core::Property("Prop A", "Prop A desc", "val A", true, "", { }, { }),
-    core::Property("Prop B", "Prop B desc", "val B", true, "", { }, { { "Prop A", "^abcd.*$" } })
+  component->setSupportedProperties(std::array<core::PropertyReference, 2>{
+    core::PropertyDefinitionBuilder<>::createProperty("Prop A").withDescription("Prop A desc").withDefaultValue("val A").isRequired(true).build(),
+    core::PropertyDefinitionBuilder<0, 0, 1>::createProperty("Prop B").withDescription("Prop B desc").withDefaultValue("val B").isRequired(true)
+        .withExclusiveOfProperties({{ { "Prop A", "^abcd.*$" } }}).build()
   });
   yamlConfig.validateComponentProperties(*component, "component A", "section A");
   REQUIRE(true);  // Expected to get here w/o any exceptions
 }
 
-TEST_CASE("Test Regex Property", "[YamlConfigurationRegexProperty]") {
+TEST_CASE("Test Exclusive Property 2", "[YamlConfigurationExclusiveOfProperty2]") {
   ConfigurationTestController test_controller;
 
   core::YamlConfiguration yamlConfig(test_controller.getContext());
   const auto component = std::make_shared<DummyComponent>();
-  component->setSupportedProperties(std::array{
-    core::Property("Prop A", "Prop A desc", "val A", true, "", { }, { }),
-    core::Property("Prop B", "Prop B desc", "val B", true, "^val.*$", { }, { })
-  });
-  yamlConfig.validateComponentProperties(*component, "component A", "section A");
-  REQUIRE(true);  // Expected to get here w/o any exceptions
-}
-
-TEST_CASE("Test Exclusive Property 2", "[YamlConfigurationExclusiveProperty2]") {
-  ConfigurationTestController test_controller;
-
-  core::YamlConfiguration yamlConfig(test_controller.getContext());
-  const auto component = std::make_shared<DummyComponent>();
-  component->setSupportedProperties(std::array{
-    core::Property("Prop A", "Prop A desc", "val A", true, "", { }, { }),
-    core::Property("Prop B", "Prop B desc", "val B", true, "", { }, { { "Prop A", "^val.*$" } })
+  component->setSupportedProperties(std::array<core::PropertyReference, 2>{
+    core::PropertyDefinitionBuilder<>::createProperty("Prop A").withDescription("Prop A desc").withDefaultValue("val A").isRequired(true).build(),
+    core::PropertyDefinitionBuilder<0, 0, 1>::createProperty("Prop B").withDescription("Prop B desc").withDefaultValue("val B").isRequired(true)
+        .withExclusiveOfProperties({{ { "Prop A", "^val.*$" } }}).build()
   });
   bool config_failed = false;
   try {
@@ -667,26 +648,6 @@ TEST_CASE("Test Exclusive Property 2", "[YamlConfigurationExclusiveProperty2]")
   REQUIRE(config_failed);
 }
 
-TEST_CASE("Test Regex Property 2", "[YamlConfigurationRegexProperty2]") {
-  ConfigurationTestController test_controller;
-  core::YamlConfiguration yamlConfig(test_controller.getContext());
-  const auto component = std::make_shared<DummyComponent>();
-  component->setSupportedProperties(std::array{
-    core::Property("Prop A", "Prop A desc", "val A", true, "", { }, { }),
-    core::Property("Prop B", "Prop B desc", "val B", true, "^notval.*$", { }, { })
-  });
-  bool config_failed = false;
-  try {
-    yamlConfig.validateComponentProperties(*component, "component A", "section A");
-  } catch (const std::exception &e) {
-    config_failed = true;
-    REQUIRE("Unable to parse configuration file for component named 'component A' because "
-        "property 'Prop B' does not match validation pattern '^notval.*$' "
-        "[in 'section A' section of configuration file]" == std::string(e.what()));
-  }
-  REQUIRE(config_failed);
-}
-
 TEST_CASE("Test YAML Config With Funnel", "[YamlConfiguration]") {
   ConfigurationTestController test_controller;
 
@@ -755,8 +716,7 @@ Connections:
 Remote Process Groups: []
     )";
 
-  std::istringstream configYamlStream(CONFIG_YAML_WITH_FUNNEL);
-  std::unique_ptr<core::ProcessGroup> rootFlowConfig = yamlConfig.getYamlRoot(configYamlStream);
+  std::unique_ptr<core::ProcessGroup> rootFlowConfig = yamlConfig.getRootFromPayload(CONFIG_YAML_WITH_FUNNEL);
 
   REQUIRE(rootFlowConfig);
   REQUIRE(rootFlowConfig->findProcessorByName("GenerateFlowFile1"));
@@ -766,7 +726,7 @@ Remote Process Groups: []
   std::map<std::string, minifi::Connection*> connectionMap;
   rootFlowConfig->getConnections(connectionMap);
   REQUIRE(6 == connectionMap.size());
-  for (auto it : connectionMap) {
+  for (const auto& it : connectionMap) {
     REQUIRE(it.second);
     REQUIRE(!it.second->getUUIDStr().empty());
     REQUIRE(it.second->getDestination());
@@ -824,10 +784,15 @@ TEST_CASE("Test UUID duplication checks", "[YamlConfiguration]") {
               class: SSLContextService
             )";
 
-      auto config_old = config_yaml;
       utils::StringUtils::replaceAll(config_yaml, std::string("00000000-0000-0000-0000-00000000000") + i, "99999999-9999-9999-9999-999999999999");
-      std::istringstream config_yaml_stream(config_yaml);
-      REQUIRE_THROWS_WITH(yaml_config.getYamlRoot(config_yaml_stream), "General Operation: UUID 99999999-9999-9999-9999-999999999999 is duplicated in the flow configuration");
+      REQUIRE_THROWS_WITH(yaml_config.getRootFromPayload(config_yaml), "General Operation: UUID 99999999-9999-9999-9999-999999999999 is duplicated in the flow configuration");
     }
   }
 }
+
+TEST_CASE("Configuration is not valid yaml", "[YamlConfiguration]") {
+  ConfigurationTestController test_controller;
+  core::YamlConfiguration yaml_config(test_controller.getContext());
+  REQUIRE_THROWS(yaml_config.getRootFromPayload("}"));
+  REQUIRE(utils::verifyLogLinePresenceInPollTime(0s, "Configuration is not valid yaml"));
+}
