@@ -29,13 +29,16 @@ bootstrap_cmake(){
     sudo yum -y install epel-release-latest-7.noarch.rpm
     sudo yum -y install cmake3
 }
+bootstrap_compiler() {
+    sudo yum -y install gcc gcc-c++
+}
 build_deps(){
     # Install epel-release so that cmake3 will be available for installation
     sudo yum -y install wget
     wget https://dl.fedoraproject.org/pub/epel/epel-release-latest-7.noarch.rpm
     sudo yum -y install epel-release-latest-7.noarch.rpm
 
-    COMMAND="sudo yum -y install gcc gcc-c++ libuuid libuuid-devel patch"
+    COMMAND="sudo yum -y install libuuid libuuid-devel patch"
     INSTALLED=()
     INSTALLED+=("bzip2-devel")
     for option in "${OPTIONS[@]}" ; do
@@ -52,7 +55,7 @@ build_deps(){
                     if [ "$FOUND_VALUE" = "libpcap" ]; then
                         INSTALLED+=("libpcap-devel")
                     elif [ "$FOUND_VALUE" = "libusb" ]; then
-                        INSTALLED+=("libusb-devel")
+                        INSTALLED+=("libusb1-devel")
                     elif [ "$FOUND_VALUE" = "libpng" ]; then
                         INSTALLED+=("libpng-devel")
                     elif [ "$FOUND_VALUE" = "bison" ]; then
@@ -79,6 +82,10 @@ build_deps(){
                         INSTALLED+=("xz-devel")
                     elif [ "$FOUND_VALUE" = "libssh2" ]; then
                         INSTALLED+=("libssh2-devel")
+                    elif [ "$FOUND_VALUE" = "boost" ]; then
+                        INSTALLED+=("boost-devel")
+                    elif [ "$FOUND_VALUE" = "opensslbuild" ]; then
+                        INSTALLED+=("perl")
                     fi
                 fi
             done
