@@ -50,7 +50,6 @@
 #include "c2/C2Agent.h"
 #include "CronDrivenSchedulingAgent.h"
 #include "EventDrivenSchedulingAgent.h"
-#include "FlowControlProtocol.h"
 #include "FlowFileRecord.h"
 #include "properties/Configure.h"
 #include "TimerDrivenSchedulingAgent.h"
@@ -60,6 +59,7 @@
 #include "core/state/MetricsPublisher.h"
 #include "core/state/MetricsPublisherStore.h"
 #include "RootProcessGroupWrapper.h"
+#include "c2/ControllerSocketProtocol.h"
 
 namespace org::apache::nifi::minifi {
 
@@ -88,7 +88,7 @@ class FlowController : public core::controller::ForwardingControllerServiceProvi
   }
 
   bool isRunning() const override {
-    return running_.load() || updating_.load();
+    return running_.load() || updating_.isUpdating();
   }
 
   virtual bool isInitialized() {
@@ -114,7 +114,7 @@ class FlowController : public core::controller::ForwardingControllerServiceProvi
 
   int16_t applyUpdate(const std::string& /*source*/, const std::shared_ptr<state::Update>&) override { return -1; }
   // Asynchronous function trigger unloading and wait for a period of time
-  virtual void waitUnload(uint64_t timeToWaitMs);
+  virtual void waitUnload(const std::chrono::milliseconds time_to_wait);
   void updatePropertyValue(std::string processorName, std::string propertyName, std::string propertyValue) {
     root_wrapper_.updatePropertyValue(std::move(processorName), std::move(propertyName), std::move(propertyValue));
   }
@@ -148,6 +148,18 @@ class FlowController : public core::controller::ForwardingControllerServiceProvi
   std::map<std::string, std::unique_ptr<io::InputStream>> getDebugInfo() override;
 
  private:
+  class UpdateState {
+   public:
+    bool isUpdating() const { return update_block_count_ > 0; }
+    void beginUpdate() { ++update_block_count_; }
+    void endUpdate() { --update_block_count_; }
+    void lock() { beginUpdate(); }
+    void unlock() { endUpdate(); }
+
+   private:
+    std::atomic<uint32_t> update_block_count_;
+  };
+
   /**
    * Loads the flow as specified in the flow config file or if not present
    * tries to fetch it from the C2 server (if enabled).
@@ -170,12 +182,11 @@ class FlowController : public core::controller::ForwardingControllerServiceProvi
 
   std::recursive_mutex mutex_;
   std::atomic<bool> running_;
-  std::atomic<bool> updating_;
+  UpdateState updating_;
   std::atomic<bool> initialized_;
   std::unique_ptr<TimerDrivenSchedulingAgent> timer_scheduler_;
   std::unique_ptr<EventDrivenSchedulingAgent> event_scheduler_;
   std::unique_ptr<CronDrivenSchedulingAgent> cron_scheduler_;
-  std::unique_ptr<FlowControlProtocol> protocol_;
   std::chrono::steady_clock::time_point start_time_;
   std::shared_ptr<Configure> configuration_;
   std::shared_ptr<core::Repository> provenance_repo_;
@@ -185,10 +196,11 @@ class FlowController : public core::controller::ForwardingControllerServiceProvi
   std::unique_ptr<state::MetricsPublisherStore> metrics_publisher_store_;
   RootProcessGroupWrapper root_wrapper_;
   std::unique_ptr<c2::C2Agent> c2_agent_{};
+  std::unique_ptr<c2::ControllerSocketProtocol> controller_socket_protocol_;
   std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<FlowController>::getLogger();
 
   // Thread pool for schedulers
-  utils::ThreadPool<utils::TaskRescheduleInfo> thread_pool_;
+  utils::ThreadPool thread_pool_;
 };
 
 }  // namespace org::apache::nifi::minifi
