@@ -80,6 +80,15 @@ class C2Agent : public state::UpdateController {
 
   std::optional<std::string> fetchFlow(const std::string& uri) const;
 
+  /**
+   * Serializes metrics into a payload.
+   * @parem parent_paylaod parent payload into which we insert the newly generated payload.
+   * @param name name of this metric
+   * @param metrics metrics to include.
+   */
+  static void serializeMetrics(C2Payload &metric_payload, const std::string &name, const std::vector<state::response::SerializedResponseNode> &metrics,
+    bool is_container = false, bool is_collapsible = true);
+
  protected:
   /**
    * Check the collection of triggers for any updates that need to be handled.
@@ -89,14 +98,6 @@ class C2Agent : public state::UpdateController {
 
   void configure(const std::shared_ptr<Configure> &configure, bool reconfigure = true);
 
-  /**
-   * Serializes metrics into a payload.
-   * @parem parent_paylaod parent payload into which we insert the newly generated payload.
-   * @param name name of this metric
-   * @param metrics metrics to include.
-   */
-  void serializeMetrics(C2Payload &metric_payload, const std::string &name, const std::vector<state::response::SerializedResponseNode> &metrics, bool is_container = false, bool is_collapsible = true);
-
   /**
    * Extract the payload
    * @param resp payload to be moved into the function.
@@ -226,7 +227,7 @@ class C2Agent : public state::UpdateController {
 
   std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<C2Agent>::getLogger();
 
-  utils::ThreadPool<utils::TaskRescheduleInfo> thread_pool_;
+  utils::ThreadPool thread_pool_;
 
   std::vector<utils::Identifier> task_ids_;
 
