@@ -28,6 +28,9 @@
 #include "controllers/SSLContextService.h"
 #include "core/controller/ControllerService.h"
 #include "core/logging/LoggerFactory.h"
+#include "core/PropertyDefinition.h"
+#include "core/PropertyDefinitionBuilder.h"
+#include "core/PropertyType.h"
 #include "ThreadManagementService.h"
 #include "io/NetworkPrioritizer.h"
 #include "utils/Export.h"
@@ -62,20 +65,42 @@ class NetworkPrioritizerService : public core::controller::ControllerService, pu
 
   MINIFIAPI static constexpr const char* Description = "Enables selection of networking interfaces on defined parameters to include output and payload size";
 
-  MINIFIAPI static const core::Property NetworkControllers;
-  MINIFIAPI static const core::Property MaxThroughput;
-  MINIFIAPI static const core::Property MaxPayload;
-  MINIFIAPI static const core::Property VerifyInterfaces;
-  MINIFIAPI static const core::Property DefaultPrioritizer;
-  static auto properties() {
-    return std::array{
+  MINIFIAPI static constexpr auto NetworkControllers = core::PropertyDefinitionBuilder<>::createProperty("Network Controllers")
+      .withDescription("Comma separated list of network controllers in order of priority for this prioritizer")
+      .isRequired(false)
+      .build();
+  MINIFIAPI static constexpr auto MaxThroughput = core::PropertyDefinitionBuilder<>::createProperty("Max Throughput")
+      .withDescription("Max throughput ( per second ) for these network controllers")
+      .isRequired(true)
+      .withPropertyType(core::StandardPropertyTypes::DATA_SIZE_TYPE)
+      .withDefaultValue("1 MB")
+      .build();
+  MINIFIAPI static constexpr auto MaxPayload = core::PropertyDefinitionBuilder<>::createProperty("Max Payload")
+      .withDescription("Maximum payload for these network controllers")
+      .isRequired(true)
+      .withPropertyType(core::StandardPropertyTypes::DATA_SIZE_TYPE)
+      .withDefaultValue("1 GB")
+      .build();
+  MINIFIAPI static constexpr auto VerifyInterfaces = core::PropertyDefinitionBuilder<>::createProperty("Verify Interfaces")
+      .withDescription("Verify that interfaces are operational")
+      .isRequired(true)
+      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withDefaultValue("true")
+      .build();
+  MINIFIAPI static constexpr auto DefaultPrioritizer = core::PropertyDefinitionBuilder<>::createProperty("Default Prioritizer")
+      .withDescription("Sets this controller service as the default prioritizer for all comms")
+      .isRequired(false)
+      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withDefaultValue("false")
+      .build();
+  MINIFIAPI static constexpr auto Properties = std::array<core::PropertyReference, 5>{
       NetworkControllers,
       MaxThroughput,
       MaxPayload,
       VerifyInterfaces,
       DefaultPrioritizer
-    };
-  }
+  };
+
 
   MINIFIAPI static constexpr bool SupportsDynamicProperties = false;
   ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_CONTROLLER_SERVICES
