@@ -18,49 +18,28 @@
 
 #pragma once
 
-#include <map>
 #include <memory>
 #include "ResourceClaim.h"
 #include "io/BaseStream.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace core {
-
-class ContentRepository;
+namespace org::apache::nifi::minifi::core {
 
 class ContentSession {
  public:
-  enum class WriteMode {
-    OVERWRITE,
-    APPEND
-  };
+  virtual std::shared_ptr<ResourceClaim> create() = 0;
 
-  explicit ContentSession(std::shared_ptr<ContentRepository> repository);
+  virtual std::shared_ptr<io::BaseStream> write(const std::shared_ptr<ResourceClaim>& resource_id) = 0;
 
-  std::shared_ptr<ResourceClaim> create();
+  virtual std::shared_ptr<io::BaseStream> append(const std::shared_ptr<ResourceClaim>& resource_id) = 0;
 
-  std::shared_ptr<io::BaseStream> write(const std::shared_ptr<ResourceClaim>& resourceId, WriteMode mode = WriteMode::OVERWRITE);
+  virtual std::shared_ptr<io::BaseStream> read(const std::shared_ptr<ResourceClaim>& resource_id) = 0;
 
-  std::shared_ptr<io::BaseStream> read(const std::shared_ptr<ResourceClaim>& resourceId);
+  virtual void commit() = 0;
 
-  virtual void commit();
-
-  void rollback();
+  virtual void rollback() = 0;
 
   virtual ~ContentSession() = default;
-
- protected:
-  std::map<std::shared_ptr<ResourceClaim>, std::shared_ptr<io::BufferStream>> managedResources_;
-  std::map<std::shared_ptr<ResourceClaim>, std::shared_ptr<io::BufferStream>> extendedResources_;
-  std::shared_ptr<ContentRepository> repository_;
 };
 
-}  // namespace core
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
+}  // namespace org::apache::nifi::minifi::core
 
