@@ -15,8 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef LIBMINIFI_INCLUDE_CORE_PROPERTYVALUE_H_
-#define LIBMINIFI_INCLUDE_CORE_PROPERTYVALUE_H_
+#pragma once
 
 #include <typeindex>
 #include <string>
@@ -24,15 +23,13 @@
 #include <memory>
 
 #include "CachedValueValidator.h"
-#include "PropertyValidation.h"
+#include "ValidationResult.h"
 #include "state/Value.h"
 #include "TypedValues.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace core {
+namespace org::apache::nifi::minifi::core {
+
+class PropertyValidator;
 
 static inline std::shared_ptr<state::response::Value> convert(const std::shared_ptr<state::response::Value> &prior, const std::string &ref) {
   if (prior->getTypeIndex() == state::response::Value::UINT64_TYPE) {
@@ -74,16 +71,21 @@ class PropertyValue : public state::response::ValueNode {
   PropertyValue(const PropertyValue &o) = default;
   PropertyValue(PropertyValue &&o) noexcept = default;
 
-  void setValidator(const gsl::not_null<std::shared_ptr<PropertyValidator>> &val) {
-    validator_ = val;
+  template<typename T>
+  static PropertyValue parse(std::string_view input, const PropertyValidator& validator) {
+    PropertyValue property_value;
+    property_value.value_ = std::make_shared<T>(std::string{input});
+    property_value.type_id = property_value.value_->getTypeIndex();
+    property_value.cached_value_validator_ = validator;
+    return property_value;
   }
 
-  std::shared_ptr<PropertyValidator> getValidator() const {
-    return *validator_;
+  void setValidator(const PropertyValidator& validator) {
+    cached_value_validator_ = validator;
   }
 
   ValidationResult validate(const std::string &subject) const {
-    return validator_.validate(subject, getValue());
+    return cached_value_validator_.validate(subject, getValue());
   }
 
   operator uint64_t() const {
@@ -136,7 +138,7 @@ class PropertyValue : public state::response::ValueNode {
    */
   template<typename T>
   auto operator=(const T ref) -> typename std::enable_if<std::is_same<T, std::string>::value, PropertyValue&>::type {
-    validator_.invalidateCachedResult();
+    cached_value_validator_.invalidateCachedResult();
     return WithAssignmentGuard(ref, [&] () -> PropertyValue& {
       if (value_ == nullptr) {
         type_id = std::type_index(typeid(T));
@@ -166,7 +168,7 @@ class PropertyValue : public state::response::ValueNode {
   std::is_same<T, uint64_t >::value ||
   std::is_same<T, int64_t >::value ||
   std::is_same<T, bool >::value, PropertyValue&>::type {
-    validator_.invalidateCachedResult();
+    cached_value_validator_.invalidateCachedResult();
     if (value_ == nullptr) {
       type_id = std::type_index(typeid(T));
       value_ = minifi::state::response::createValue(ref);
@@ -200,7 +202,7 @@ class PropertyValue : public state::response::ValueNode {
   auto operator=(const std::string &ref) -> typename std::enable_if<
   std::is_same<T, DataSizeValue >::value ||
   std::is_same<T, TimePeriodValue >::value, PropertyValue&>::type {
-    validator_.invalidateCachedResult();
+    cached_value_validator_.invalidateCachedResult();
     return WithAssignmentGuard(ref, [&] () -> PropertyValue& {
       value_ = std::make_shared<T>(ref);
       type_id = value_->getTypeIndex();
@@ -223,7 +225,7 @@ class PropertyValue : public state::response::ValueNode {
 
   bool isValueUsable() const {
     if (!value_) return false;
-    return validate("__unknown__").valid();
+    return validate("__unknown__").valid;
   }
 
   template<typename Fn>
@@ -241,17 +243,11 @@ class PropertyValue : public state::response::ValueNode {
 
  protected:
   std::type_index type_id;
-  CachedValueValidator validator_;
+  CachedValueValidator cached_value_validator_;
 };
 
 inline std::string conditional_conversion(const PropertyValue &v) {
   return v.getValue()->getStringValue();
 }
 
-}  // namespace core
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
-
-#endif  // LIBMINIFI_INCLUDE_CORE_PROPERTYVALUE_H_
+}  // namespace org::apache::nifi::minifi::core
