@@ -28,15 +28,14 @@
 #include "core/Processor.h"
 #include "core/ProcessSession.h"
 #include "RemoteProcessorGroupPort.h"
-#include "io/StreamFactory.h"
 #include "core/logging/LoggerFactory.h"
 
 namespace org::apache::nifi::minifi::core::reporting {
 
 class SiteToSiteProvenanceReportingTask : public minifi::RemoteProcessorGroupPort {
  public:
-  SiteToSiteProvenanceReportingTask(const std::shared_ptr<io::StreamFactory> &stream_factory, std::shared_ptr<Configure> configure)
-      : minifi::RemoteProcessorGroupPort(stream_factory, ReportTaskName, "", std::move(configure)),
+  explicit SiteToSiteProvenanceReportingTask(std::shared_ptr<Configure> configure)
+      : minifi::RemoteProcessorGroupPort(ReportTaskName, "", std::move(configure)),
         logger_(logging::LoggerFactory<SiteToSiteProvenanceReportingTask>::getLogger()) {
     this->setTriggerWhenEmpty(true);
     batch_size_ = 100;
