@@ -17,14 +17,12 @@
  */
 #pragma once
 
-#include <memory>
 #include <string>
-#include <utility>
 #include <vector>
 
-#include "../nodes/MetricsBase.h"
 #include "Connection.h"
-#include "../ConnectionStore.h"
+#include "core/state/nodes/MetricsBase.h"
+#include "core/state/ConnectionStore.h"
 
 namespace org::apache::nifi::minifi::state::response {
 
@@ -57,36 +55,7 @@ class QueueMetrics : public ResponseNode {
     connection_store_.updateConnection(connection);
   }
 
-  std::vector<SerializedResponseNode> serialize() override {
-    std::vector<SerializedResponseNode> serialized;
-    for (const auto& [_, connection] : connection_store_.getConnections()) {
-      SerializedResponseNode parent;
-      parent.name = connection->getName();
-      SerializedResponseNode datasize;
-      datasize.name = "datasize";
-      datasize.value = std::to_string(connection->getQueueDataSize());
-
-      SerializedResponseNode datasizemax;
-      datasizemax.name = "datasizemax";
-      datasizemax.value = std::to_string(connection->getBackpressureThresholdDataSize());
-
-      SerializedResponseNode queuesize;
-      queuesize.name = "queued";
-      queuesize.value = std::to_string(connection->getQueueSize());
-
-      SerializedResponseNode queuesizemax;
-      queuesizemax.name = "queuedmax";
-      queuesizemax.value = std::to_string(connection->getBackpressureThresholdCount());
-
-      parent.children.push_back(datasize);
-      parent.children.push_back(datasizemax);
-      parent.children.push_back(queuesize);
-      parent.children.push_back(queuesizemax);
-
-      serialized.push_back(parent);
-    }
-    return serialized;
-  }
+  std::vector<SerializedResponseNode> serialize() override;
 
   std::vector<PublishedMetric> calculateMetrics() override {
     return connection_store_.calculateConnectionMetrics("QueueMetrics");
