@@ -74,7 +74,7 @@ class FileStream : public io::BaseStream {
    * @param buf buffer in which we extract data
    * @param buflen
    */
-  size_t read(gsl::span<std::byte> buf) override;
+  size_t read(std::span<std::byte> buf) override;
 
   /**
    * writes value to stream
