@@ -23,7 +23,8 @@
 #include <functional>
 #include <memory>
 #include <utility>
-#include "BaseStream.h"
+#include "InputStream.h"
+#include "OutputStream.h"
 #include "StreamCallback.h"
 
 namespace org::apache::nifi::minifi {
@@ -37,7 +38,7 @@ inline int64_t pipe(io::InputStream& src, io::OutputStream& dst) {
     if (io::isError(readRet)) return -1;
     if (readRet == 0) break;
     auto remaining = readRet;
-    int transferred = 0;
+    size_t transferred = 0;
     while (remaining > 0) {
       const auto writeRet = dst.write(gsl::make_span(buffer).subspan(transferred, remaining));
       // TODO(adebreceni):
@@ -62,7 +63,7 @@ class InputStreamPipe {
  public:
   explicit InputStreamPipe(io::OutputStream& output) : output_(&output) {}
 
-  int64_t operator()(const std::shared_ptr<io::BaseStream>& stream) const {
+  int64_t operator()(const std::shared_ptr<io::InputStream>& stream) const {
     return internal::pipe(*stream, *output_);
   }
 
@@ -74,7 +75,7 @@ class OutputStreamPipe {
  public:
   explicit OutputStreamPipe(io::InputStream& input) : input_(&input) {}
 
-  int64_t operator()(const std::shared_ptr<io::BaseStream>& stream) const {
+  int64_t operator()(const std::shared_ptr<io::OutputStream>& stream) const {
     return internal::pipe(*input_, *stream);
   }
 
