@@ -178,7 +178,7 @@ class SiteToSiteClient : public core::Connectable {
   /**
    * Determines if we are connected and operating
    */
-  bool isRunning() override {
+  bool isRunning() const override {
     return running_;
   }
 
