@@ -32,9 +32,14 @@
   #include <cwctype>
   #include <cctype>
 #endif
+#include "utils/expected.h"
 #include "utils/FailurePolicy.h"
 #include "utils/gsl.h"
+#include "utils/span.h"
 #include "utils/meta/detected.h"
+#include "range/v3/view/transform.hpp"
+#include "range/v3/range/conversion.hpp"
+#include "range/v3/view/join.hpp"
 
 // libc++ doesn't define operator<=> on strings, and apparently the operator rewrite rules don't automagically make one
 #if defined(_LIBCPP_VERSION) && _LIBCPP_VERSION < 16000
@@ -45,10 +50,6 @@ constexpr std::strong_ordering operator<=>(const std::string& lhs, const std::st
 }
 #endif
 
-#include "range/v3/view/transform.hpp"
-#include "range/v3/view/join.hpp"
-#include "range/v3/range/conversion.hpp"
-
 namespace org::apache::nifi::minifi::utils {
 
 template<class Char>
@@ -88,7 +89,17 @@ class StringUtils {
    */
   static std::optional<bool> toBool(const std::string& input);
 
-  static std::string toLower(std::string_view str);
+  static inline std::string toLower(std::string str) {
+    const auto tolower = [](auto c) { return std::tolower(static_cast<unsigned char>(c)); };
+    std::transform(std::begin(str), std::end(str), std::begin(str), tolower);
+    return str;
+  }
+
+  static inline std::string toUpper(std::string str)  {
+    const auto toupper = [](auto c) { return std::toupper(static_cast<unsigned char>(c)); };
+    std::transform(std::begin(str), std::end(str), std::begin(str), toupper);
+    return str;
+  }
 
   /**
    * Strips the line ending (\n or \r\n) from the end of the input line.
@@ -132,14 +143,14 @@ class StringUtils {
   /**
    * Compares strings by lower casing them.
    */
-  static inline bool equalsIgnoreCase(const std::string& left, const std::string& right) {
+  static inline bool equalsIgnoreCase(std::string_view left, std::string_view right) {
     if (left.length() != right.length()) {
       return false;
     }
     return std::equal(right.cbegin(), right.cend(), left.cbegin(), [](unsigned char lc, unsigned char rc) { return std::tolower(lc) == std::tolower(rc); });
   }
 
-  static inline bool equals(const char* left, const char* right, bool caseSensitive = true) {
+  static constexpr bool equals(const char* left, const char* right, bool caseSensitive = true) {
     if (caseSensitive) {
       return std::strcmp(left, right) == 0;
     }
@@ -151,7 +162,7 @@ class StringUtils {
     return std::equal(right, right + right_len, left, [](unsigned char lc, unsigned char rc) { return std::tolower(lc) == std::tolower(rc); });
   }
 
-  static inline bool equals(const std::string_view& left, const std::string_view& right, bool case_sensitive = true) {
+  static constexpr bool equals(std::string_view left, std::string_view right, bool case_sensitive = true) {
     if (case_sensitive) {
       return left == right;
     }
@@ -161,10 +172,10 @@ class StringUtils {
     return std::equal(left.begin(), left.end(), right.begin(), [](unsigned char lc, unsigned char rc) { return std::tolower(lc) == std::tolower(rc); });
   }
 
-  static std::vector<std::string> split(const std::string &str, const std::string &delimiter);
-  static std::vector<std::string> splitRemovingEmpty(const std::string& str, const std::string& delimiter);
-  static std::vector<std::string> splitAndTrim(const std::string &str, const std::string &delimiter);
-  static std::vector<std::string> splitAndTrimRemovingEmpty(const std::string& str, const std::string& delimiter);
+  static std::vector<std::string> split(std::string_view str, std::string_view delimiter);
+  static std::vector<std::string> splitRemovingEmpty(std::string_view str, std::string_view delimiter);
+  static std::vector<std::string> splitAndTrim(std::string_view str, std::string_view delimiter);
+  static std::vector<std::string> splitAndTrimRemovingEmpty(std::string_view str, std::string_view delimiter);
 
   /**
    * Converts a string to a float
@@ -180,7 +191,7 @@ class StringUtils {
 
   static std::string& replaceAll(std::string& source_string, const std::string &from_string, const std::string &to_string);
 
-  inline static bool startsWith(const std::string_view& value, const std::string_view& start, bool case_sensitive = true) {
+  inline static bool startsWith(std::string_view value, std::string_view start, bool case_sensitive = true) {
     if (start.length() > value.length()) {
       return false;
     }
@@ -190,7 +201,7 @@ class StringUtils {
     return std::equal(start.begin(), start.end(), value.begin(), [](unsigned char lc, unsigned char rc) {return tolower(lc) == tolower(rc);});
   }
 
-  inline static bool endsWith(const std::string_view& value, const std::string_view& end, bool case_sensitive = true) {
+  inline static bool endsWith(std::string_view value, std::string_view end, bool case_sensitive = true) {
     if (end.length() > value.length()) {
       return false;
     }
@@ -352,7 +363,8 @@ class StringUtils {
    */
   static std::vector<std::byte> from_hex(std::string_view hex);
   static std::string from_hex(std::string_view hex, as_string_tag_t) {
-    return utils::span_to<std::string>(gsl::make_span(from_hex(hex)).as_span<const char>());
+    const auto decoded = from_hex(hex);
+    return utils::span_to<std::string>(utils::as_span<const char>(std::span(decoded)));
   }
 
 
@@ -364,7 +376,7 @@ class StringUtils {
    * @param uppercase whether the hexencoded string should be upper case
    * @return the size of hexencoded bytes
    */
-  static size_t to_hex(char* hex, gsl::span<const std::byte> data_to_be_transformed, bool uppercase);
+  static size_t to_hex(char* hex, std::span<const std::byte> data_to_be_transformed, bool uppercase);
 
   /**
    * Creates a hexencoded string from data
@@ -373,7 +385,7 @@ class StringUtils {
    * @param uppercase whether the hexencoded string should be upper case
    * @return the hexencoded string
    */
-  static std::string to_hex(gsl::span<const std::byte> data_to_be_transformed, bool uppercase = false);
+  static std::string to_hex(std::span<const std::byte> data_to_be_transformed, bool uppercase = false);
 
   /**
    * Hexencodes a string
@@ -404,7 +416,8 @@ class StringUtils {
    */
   static std::vector<std::byte> from_base64(std::string_view base64);
   static std::string from_base64(std::string_view base64, as_string_tag_t) {
-    return utils::span_to<std::string>(gsl::make_span(from_base64(base64)).as_span<const char>());
+    const auto decoded = from_base64(base64);
+    return utils::span_to<std::string>(utils::as_span<const char>(std::span(decoded)));
   }
 
   /**
@@ -415,7 +428,7 @@ class StringUtils {
    * @param padded if true, padding is added to the Base64 encoded string
    * @return the size of Base64 encoded bytes
    */
-  static size_t to_base64(char* base64, gsl::span<const std::byte> raw_data, bool url, bool padded);
+  static size_t to_base64(char* base64, std::span<const std::byte> raw_data, bool url, bool padded);
 
   /**
    * Creates a Base64 encoded string from data
@@ -424,7 +437,7 @@ class StringUtils {
    * @param padded if true, padding is added to the Base64 encoded string
    * @return the Base64 encoded string
    */
-  static std::string to_base64(gsl::span<const std::byte> raw_data, bool url = false, bool padded = true);
+  static std::string to_base64(std::span<const std::byte> raw_data, bool url = false, bool padded = true);
 
   /**
    * Base64 encodes a string
@@ -469,7 +482,7 @@ class StringUtils {
     return str;
   }
 
-  static std::string escapeUnprintableBytes(gsl::span<const std::byte> data);
+  static std::string escapeUnprintableBytes(std::span<const std::byte> data);
 
   /**
    * Returns whether sequence of patterns are found in given string in their incoming order
@@ -480,7 +493,11 @@ class StringUtils {
    */
   static bool matchesSequence(std::string_view str, const std::vector<std::string>& patterns);
 
- private:
+  static bool splitToValueAndUnit(std::string_view input, int64_t& value, std::string& unit);
+
+  struct ParseError {};
+
+  static nonstd::expected<std::optional<char>, ParseError> parseCharacter(const std::string &input);
 };
 
 }  // namespace org::apache::nifi::minifi::utils
