@@ -83,9 +83,9 @@ namespace org::apache::nifi::minifi::utils::file {
 
 namespace FileUtils = ::org::apache::nifi::minifi::utils::file;
 
-time_t to_time_t(std::filesystem::file_time_type time);
+std::chrono::system_clock::time_point to_sys(std::filesystem::file_time_type file_time);
 
-std::chrono::system_clock::time_point to_sys(std::filesystem::file_time_type time);
+std::filesystem::file_time_type from_sys(std::chrono::system_clock::time_point sys_time);
 
 inline int64_t delete_dir(const std::filesystem::path& path, bool delete_files_recursively = true) {
   // Empty path is interpreted as the root of the current partition on Windows, which should not be allowed
@@ -126,19 +126,6 @@ inline std::optional<std::filesystem::file_time_type> last_write_time(const std:
   return std::nullopt;
 }
 
-inline std::optional<std::string> format_time(const std::filesystem::file_time_type& time, const std::string& format) {
-  auto last_write_time_t = to_time_t(time);
-  std::array<char, 128U> result{};
-  if (std::strftime(result.data(), result.size(), format.c_str(), gmtime(&last_write_time_t)) != 0) {
-    return std::string(result.data());
-  }
-  return std::nullopt;
-}
-
-inline std::optional<std::string> get_last_modified_time_formatted_string(const std::filesystem::path& path, const std::string& format_string) {
-  return utils::file::last_write_time(path) | utils::flatMap([format_string](auto time) { return format_time(time, format_string); });
-}
-
 inline bool set_last_write_time(const std::filesystem::path& path, std::filesystem::file_time_type new_time) {
   std::error_code ec;
   std::filesystem::last_write_time(path, new_time, ec);
@@ -206,6 +193,20 @@ inline bool is_directory(const std::filesystem::path &path) {
   return false;
 }
 
+inline uint64_t path_size(const std::filesystem::path& path) {
+  uint64_t size = 0;
+  if (std::filesystem::is_regular_file(path)) {
+    return utils::file::file_size(path);
+  } else if (utils::file::is_directory(path)) {
+    for (const std::filesystem::directory_entry& entry : std::filesystem::recursive_directory_iterator(path, std::filesystem::directory_options::skip_permission_denied)) {
+      if (entry.is_regular_file()) {
+        size += entry.file_size();
+      }
+    }
+  }
+  return size;
+}
+
 inline bool exists(const std::filesystem::path &path) {
   std::error_code ec;
   bool result = std::filesystem::exists(path, ec);
@@ -418,14 +419,6 @@ inline std::filesystem::path get_executable_dir() {
   return executable_path.parent_path();
 }
 
-inline int close(int file_descriptor) {
-#ifdef WIN32
-  return _close(file_descriptor);
-#else
-  return ::close(file_descriptor);
-#endif
-}
-
 uint64_t computeChecksum(const std::filesystem::path& file_name, uint64_t up_to_position);
 
 inline std::string get_content(const std::filesystem::path& file_name) {
