@@ -43,6 +43,7 @@
 #include "core/ClassLoader.h"
 #include "core/ThreadedRepository.h"
 #include "c2/C2MetricsPublisher.h"
+#include "c2/ControllerSocketMetricsPublisher.h"
 
 namespace org::apache::nifi::minifi {
 
@@ -50,11 +51,10 @@ FlowController::FlowController(std::shared_ptr<core::Repository> provenance_repo
                                std::shared_ptr<Configure> configure, std::shared_ptr<core::FlowConfiguration> flow_configuration,
                                std::shared_ptr<core::ContentRepository> content_repo, std::unique_ptr<state::MetricsPublisherStore> metrics_publisher_store,
                                std::shared_ptr<utils::file::FileSystem> filesystem, std::function<void()> request_restart)
-    : core::controller::ForwardingControllerServiceProvider(core::getClassName<FlowController>()),
+    : core::controller::ForwardingControllerServiceProvider(core::className<FlowController>()),
       running_(false),
-      updating_(false),
       initialized_(false),
-      thread_pool_(5, false, nullptr, "Flowcontroller threadpool"),
+      thread_pool_(5, nullptr, "Flowcontroller threadpool"),
       configuration_(std::move(configure)),
       provenance_repo_(std::move(provenance_repo)),
       flow_file_repo_(std::move(flow_file_repo)),
@@ -73,7 +73,6 @@ FlowController::FlowController(std::shared_ptr<core::Repository> provenance_repo
   if (flow_configuration_) {
     controller_service_provider_impl_ = flow_configuration_->getControllerServiceProvider();
   }
-  protocol_ = std::make_unique<FlowControlProtocol>(this, configuration_);
   if (metrics_publisher_store_) {
     metrics_publisher_store_->initialize(this, this);
   }
@@ -85,6 +84,14 @@ FlowController::FlowController(std::shared_ptr<core::Repository> provenance_repo
     }
     c2_agent_ = std::make_unique<c2::C2Agent>(configuration_, c2_metrics_publisher, std::move(filesystem), std::move(request_restart));
   }
+
+  if (c2::isControllerSocketEnabled(configuration_)) {
+    std::shared_ptr<c2::ControllerSocketMetricsPublisher> controller_socket_metrics_publisher;
+    if (auto publisher = metrics_publisher_store_->getMetricsPublisher(c2::CONTROLLER_SOCKET_METRICS_PUBLISHER).lock()) {
+      controller_socket_metrics_publisher = std::dynamic_pointer_cast<c2::ControllerSocketMetricsPublisher>(publisher);
+    }
+    controller_socket_protocol_ = std::make_unique<c2::ControllerSocketProtocol>(*this, *this, configuration_, controller_socket_metrics_publisher);
+  }
 }
 
 FlowController::~FlowController() {
@@ -93,7 +100,6 @@ FlowController::~FlowController() {
   }
   stop();
   // TODO(adebreceni): are these here on purpose, so they are destroyed first?
-  protocol_ = nullptr;
   flow_file_repo_ = nullptr;
   provenance_repo_ = nullptr;
   logger_->log_trace("Destroying FlowController");
@@ -119,10 +125,9 @@ bool FlowController::applyConfiguration(const std::string &source, const std::st
 
   logger_->log_info("Starting to reload Flow Controller with flow control name %s, version %d", newRoot->getName(), newRoot->getVersion());
 
-  updating_ = true;
   bool started = false;
-
   {
+    std::scoped_lock<UpdateState> update_lock(updating_);
     std::lock_guard<std::recursive_mutex> flow_lock(mutex_);
     stop();
 
@@ -146,8 +151,6 @@ bool FlowController::applyConfiguration(const std::string &source, const std::st
     }
   }
 
-  updating_ = false;
-
   if (started) {
     auto flowVersion = flow_configuration_->getFlowVersion();
     if (flowVersion) {
@@ -184,7 +187,6 @@ int16_t FlowController::stop() {
     this->content_repo_->stop();
     // stop the ControllerServices
     disableAllControllerServices();
-    initialized_ = false;
     running_ = false;
   }
   return 0;
@@ -199,10 +201,10 @@ int16_t FlowController::stop() {
  * @param timeToWaitMs Maximum time to wait before manually
  * marking running as false.
  */
-void FlowController::waitUnload(const uint64_t timeToWaitMs) {
+void FlowController::waitUnload(const std::chrono::milliseconds time_to_wait) {
   if (running_) {
     // use the current time and increment with the provided argument.
-    std::chrono::system_clock::time_point wait_time = std::chrono::system_clock::now() + std::chrono::milliseconds(timeToWaitMs);
+    std::chrono::system_clock::time_point wait_time = std::chrono::system_clock::now() + time_to_wait;
 
     // create an asynchronous future.
     std::future<void> unload_task = std::async(std::launch::async, [this]() {stop();});
@@ -256,14 +258,17 @@ void FlowController::load(bool reload) {
     io::NetworkPrioritizerFactory::getInstance()->clearPrioritizer();
   }
 
-  if (!root_wrapper_.initialized()) {
-    logger_->log_info("Instantiating new flow");
-    root_wrapper_.setNewRoot(loadInitialFlow());
-    if (c2_agent_ && !c2_agent_->isControllerRunning()) {
-      // TODO(lordgamez): this initialization configures the C2 sender protocol (e.g. RESTSender) which may contain an SSL Context service from the flow config
-      // for SSL communication. This service may change on flow update and we should take care of the SSL Context Service change in the C2 Agent.
-      c2_agent_->initialize(this, this, this);
-      c2_agent_->start();
+  {
+    std::scoped_lock<UpdateState> update_lock(updating_);
+    if (!root_wrapper_.initialized()) {
+      logger_->log_info("Instantiating new flow");
+      root_wrapper_.setNewRoot(loadInitialFlow());
+      if (c2_agent_ && !c2_agent_->isControllerRunning()) {
+        // TODO(lordgamez): this initialization configures the C2 sender protocol (e.g. RESTSender) which may contain an SSL Context service from the flow config
+        // for SSL communication. This service may change on flow update and we should take care of the SSL Context Service change in the C2 Agent.
+        c2_agent_->initialize(this, this, this);
+        c2_agent_->start();
+      }
     }
   }
 
@@ -323,6 +328,10 @@ int16_t FlowController::start() {
   } else if (!running_) {
     logger_->log_info("Starting Flow Controller");
     enableAllControllerServices();
+    if (controller_socket_protocol_) {
+      // Initialization is postponed after controller services are enabled so the controller socket may load the SSL context defined in the flow configuration
+      controller_socket_protocol_->initialize();
+    }
     timer_scheduler_->start();
     event_scheduler_->start();
     cron_scheduler_->start();
@@ -335,7 +344,6 @@ int16_t FlowController::start() {
 
     core::logging::LoggerConfiguration::getConfiguration().initializeAlertSinks(this, configuration_);
     running_ = true;
-    protocol_->start();
     content_repo_->start();
     provenance_repo_->start();
     flow_file_repo_->start();
@@ -390,7 +398,7 @@ int16_t FlowController::clearConnection(const std::string &connection) {
 }
 
 void FlowController::executeOnAllComponents(std::function<void(state::StateController&)> func) {
-  if (updating_ || !initialized_) {
+  if (updating_.isUpdating()) {
     return;
   }
   std::lock_guard<std::recursive_mutex> lock(mutex_);
@@ -400,7 +408,7 @@ void FlowController::executeOnAllComponents(std::function<void(state::StateContr
 }
 
 void FlowController::executeOnComponent(const std::string &id_or_name, std::function<void(state::StateController&)> func) {
-  if (updating_ || !initialized_) {
+  if (updating_.isUpdating()) {
     return;
   }
   std::lock_guard<std::recursive_mutex> lock(mutex_);
