@@ -41,9 +41,9 @@
 #include "core/logging/Logger.h"
 #include "core/ProcessContext.h"
 #include "core/ProcessorNode.h"
-#include "core/PropertyBuilder.h"
 #include "core/Relationship.h"
 #include "utils/BaseHTTPClient.h"
+#include "utils/net/DNS.h"
 
 #undef GetObject  // windows.h #defines GetObject = GetObjectA or GetObjectW, which conflicts with rapidjson
 
@@ -53,16 +53,6 @@ namespace org::apache::nifi::minifi {
 
 const char *RemoteProcessorGroupPort::RPG_SSL_CONTEXT_SERVICE_NAME = "RemoteProcessorGroupPortSSLContextService";
 
-const core::Property RemoteProcessorGroupPort::hostName("Host Name", "Remote Host Name.", "");
-const core::Property RemoteProcessorGroupPort::SSLContext("SSL Context Service", "The SSL Context Service used to provide client certificate information for TLS/SSL (https) connections.", "");
-const core::Property RemoteProcessorGroupPort::port("Port", "Remote Port", "");
-const core::Property RemoteProcessorGroupPort::portUUID("Port UUID", "Specifies remote NiFi Port UUID.", "");
-const core::Property RemoteProcessorGroupPort::idleTimeout(
-            core::PropertyBuilder::createProperty("Idle Timeout")->withDescription("Max idle time for remote service")->isRequired(false)
-                    ->withDefaultValue<core::TimePeriodValue>("15 s")->build());
-
-const core::Relationship RemoteProcessorGroupPort::relation;
-
 std::unique_ptr<sitetosite::SiteToSiteClient> RemoteProcessorGroupPort::getNextProtocol(bool create = true) {
   std::unique_ptr<sitetosite::SiteToSiteClient> nextProtocol = nullptr;
   if (!available_protocols_.try_dequeue(nextProtocol)) {
@@ -74,10 +64,10 @@ std::unique_ptr<sitetosite::SiteToSiteClient> RemoteProcessorGroupPort::getNextP
           auto host = rpg.host_;
 #ifdef WIN32
           if ("localhost" == host) {
-            host = org::apache::nifi::minifi::io::Socket::getMyHostName();
+            host = org::apache::nifi::minifi::utils::net::getMyHostName();
           }
 #endif
-          sitetosite::SiteToSiteClientConfiguration config(stream_factory_, std::make_shared<sitetosite::Peer>(protocol_uuid_, host, rpg.port_, ssl_service != nullptr), this->getInterface(),
+          sitetosite::SiteToSiteClientConfiguration config(std::make_shared<sitetosite::Peer>(protocol_uuid_, host, rpg.port_, ssl_service != nullptr), this->getInterface(),
                                                            client_type_);
           config.setHTTPProxy(this->proxy_);
           config.setIdleTimeout(idle_timeout_);
@@ -86,7 +76,7 @@ std::unique_ptr<sitetosite::SiteToSiteClient> RemoteProcessorGroupPort::getNextP
       } else if (peer_index_ >= 0) {
         std::lock_guard<std::mutex> lock(peer_mutex_);
         logger_->log_debug("Creating client from peer %d", peer_index_.load());
-        sitetosite::SiteToSiteClientConfiguration config(stream_factory_, peers_[this->peer_index_].getPeer(), local_network_interface_, client_type_);
+        sitetosite::SiteToSiteClientConfiguration config(peers_[this->peer_index_].getPeer(), local_network_interface_, client_type_);
         config.setSecurityContext(ssl_service);
         peer_index_++;
         if (peer_index_ >= static_cast<int>(peers_.size())) {
@@ -119,20 +109,20 @@ void RemoteProcessorGroupPort::returnProtocol(std::unique_ptr<sitetosite::SiteTo
 }
 
 void RemoteProcessorGroupPort::initialize() {
-  setSupportedProperties(properties());
-  setSupportedRelationships(relationships());
+  setSupportedProperties(Properties);
+  setSupportedRelationships(Relationships);
 
   logger_->log_trace("Finished initialization");
 }
 
 void RemoteProcessorGroupPort::onSchedule(const std::shared_ptr<core::ProcessContext> &context, const std::shared_ptr<core::ProcessSessionFactory>& /*sessionFactory*/) {
   std::string value;
-  if (context->getProperty(portUUID.getName(), value) && !value.empty()) {
+  if (context->getProperty(portUUID, value) && !value.empty()) {
     protocol_uuid_ = value;
   }
 
   std::string context_name;
-  if (!context->getProperty(SSLContext.getName(), context_name) || IsNullOrEmpty(context_name)) {
+  if (!context->getProperty(SSLContext, context_name) || IsNullOrEmpty(context_name)) {
     context_name = RPG_SSL_CONTEXT_SERVICE_NAME;
   }
   std::shared_ptr<core::controller::ControllerService> service = context->getControllerService(context_name);
@@ -149,8 +139,9 @@ void RemoteProcessorGroupPort::onSchedule(const std::shared_ptr<core::ProcessCon
     if (auto idle_timeout = context->getProperty<core::TimePeriodValue>(idleTimeout)) {
       idle_timeout_ = idle_timeout->getMilliseconds();
     } else {
-      logger_->log_debug("%s attribute is invalid, so default value of %s will be used", idleTimeout.getName(), idleTimeout.getDefaultValue());
-      idle_timeout_ = core::TimePeriodValue(idleTimeout.getDefaultValue().to_string()).getMilliseconds();
+      static_assert(idleTimeout.default_value);
+      logger_->log_debug("%s attribute is invalid, so default value of %s will be used", std::string(idleTimeout.name), std::string(*idleTimeout.default_value));
+      idle_timeout_ = core::TimePeriodValue(std::string(*idleTimeout.default_value)).getMilliseconds();
     }
   }
 
@@ -169,8 +160,8 @@ void RemoteProcessorGroupPort::onSchedule(const std::shared_ptr<core::ProcessCon
     std::string portStr;
     int configured_port = -1;
     // place hostname/port into the log message if we have it
-    context->getProperty(hostName.getName(), host);
-    context->getProperty(port.getName(), portStr);
+    context->getProperty(hostName, host);
+    context->getProperty(port, portStr);
     if (!host.empty() && !portStr.empty() && !portStr.empty() && core::Property::StringToInt(portStr, configured_port)) {
       nifi_instances_.push_back({ host, configured_port, "" });
       bypass_rest_api_ = true;
@@ -187,7 +178,7 @@ void RemoteProcessorGroupPort::onSchedule(const std::shared_ptr<core::ProcessCon
       count = max_concurrent_tasks_;
     for (uint32_t i = 0; i < count; i++) {
       std::unique_ptr<sitetosite::SiteToSiteClient> nextProtocol = nullptr;
-      sitetosite::SiteToSiteClientConfiguration config(stream_factory_, peers_[this->peer_index_].getPeer(), this->getInterface(), client_type_);
+      sitetosite::SiteToSiteClientConfiguration config(peers_[this->peer_index_].getPeer(), this->getInterface(), client_type_);
       config.setSecurityContext(ssl_service);
       peer_index_++;
       if (peer_index_ >= static_cast<int>(peers_.size())) {
@@ -265,7 +256,7 @@ std::pair<std::string, int> RemoteProcessorGroupPort::refreshRemoteSite2SiteInfo
     std::string host = nifi.host_;
 #ifdef WIN32
     if ("localhost" == host) {
-      host = org::apache::nifi::minifi::io::Socket::getMyHostName();
+      host = org::apache::nifi::minifi::utils::net::getMyHostName();
     }
 #endif
     std::string protocol = nifi.protocol_;
@@ -377,7 +368,7 @@ void RemoteProcessorGroupPort::refreshPeerList() {
   this->peers_.clear();
 
   std::unique_ptr<sitetosite::SiteToSiteClient> protocol;
-  sitetosite::SiteToSiteClientConfiguration config(stream_factory_, std::make_shared<sitetosite::Peer>(protocol_uuid_, connection.first, connection.second, ssl_service != nullptr),
+  sitetosite::SiteToSiteClientConfiguration config(std::make_shared<sitetosite::Peer>(protocol_uuid_, connection.first, connection.second, ssl_service != nullptr),
                                                    this->getInterface(), client_type_);
   config.setSecurityContext(ssl_service);
   config.setHTTPProxy(this->proxy_);
