@@ -25,6 +25,8 @@
 #include "core/Processor.h"
 #include "utils/gsl.h"
 
+using namespace std::literals::chrono_literals;
+
 namespace {
 bool hasWorkToDo(org::apache::nifi::minifi::core::Processor* processor) {
   // Whether it has work to do
@@ -34,66 +36,28 @@ bool hasWorkToDo(org::apache::nifi::minifi::core::Processor* processor) {
 
 namespace org::apache::nifi::minifi {
 
-std::future<utils::TaskRescheduleInfo> SchedulingAgent::enableControllerService(std::shared_ptr<core::controller::ControllerServiceNode> &serviceNode) {
-  logger_->log_info("Enabling CSN in SchedulingAgent %s", serviceNode->getName());
-  // reference the enable function from serviceNode
-  std::function<utils::TaskRescheduleInfo()> f_ex = [serviceNode] {
-      serviceNode->enable();
-      return utils::TaskRescheduleInfo::Done();
-    };
-
-  // only need to run this once.
-  auto monitor = std::make_unique<utils::ComplexMonitor>();
-  utils::Worker<utils::TaskRescheduleInfo> functor(f_ex, serviceNode->getUUIDStr(), std::move(monitor));
-  // move the functor into the thread pool. While a future is returned
-  // we aren't terribly concerned with the result.
-  std::future<utils::TaskRescheduleInfo> future;
-  thread_pool_.execute(std::move(functor), future);
-  if (future.valid())
-    future.wait();
-  return future;
-}
-
-std::future<utils::TaskRescheduleInfo> SchedulingAgent::disableControllerService(std::shared_ptr<core::controller::ControllerServiceNode> &serviceNode) {
-  logger_->log_info("Disabling CSN in SchedulingAgent %s", serviceNode->getName());
-  // reference the disable function from serviceNode
-  std::function<utils::TaskRescheduleInfo()> f_ex = [serviceNode] {
-    serviceNode->disable();
-    return utils::TaskRescheduleInfo::Done();
-  };
-
-  // only need to run this once.
-  auto monitor = std::make_unique<utils::ComplexMonitor>();
-  utils::Worker<utils::TaskRescheduleInfo> functor(f_ex, serviceNode->getUUIDStr(), std::move(monitor));
-
-  // move the functor into the thread pool. While a future is returned
-  // we aren't terribly concerned with the result.
-  std::future<utils::TaskRescheduleInfo> future;
-  thread_pool_.execute(std::move(functor), future);
-  if (future.valid())
-    future.wait();
-  return future;
-}
-
-bool SchedulingAgent::onTrigger(core::Processor* processor, const std::shared_ptr<core::ProcessContext> &processContext,
-                                const std::shared_ptr<core::ProcessSessionFactory> &sessionFactory) {
+nonstd::expected<void, std::exception_ptr> SchedulingAgent::onTrigger(core::Processor* processor,
+    const std::shared_ptr<core::ProcessContext> &process_context,
+    const std::shared_ptr<core::ProcessSessionFactory> &session_factory) {
   gsl_Expects(processor);
   if (processor->isYield()) {
     logger_->log_debug("Not running %s since it must yield", processor->getName());
-    return false;
+    return {};
   }
 
   // No need to yield, reset yield expiration to 0
   processor->clearYield();
 
+  auto bored_yield_duration = bored_yield_duration_ > 0ms ? bored_yield_duration_ : 10ms;
+
   if (!hasWorkToDo(processor)) {
-    // No work to do, yield
-    return true;
+    processor->yield(bored_yield_duration);
+    return {};
   }
   if (processor->isThrottledByBackpressure()) {
     logger_->log_debug("backpressure applied because too much outgoing for %s %s", processor->getUUIDStr(), processor->getName());
-    // need to apply backpressure
-    return true;
+    processor->yield(bored_yield_duration);
+    return {};
   }
 
   auto schedule_it = scheduled_processors_.end();
@@ -109,20 +73,21 @@ bool SchedulingAgent::onTrigger(core::Processor* processor, const std::shared_pt
   });
 
   processor->incrementActiveTasks();
+  auto decrement_task = gsl::finally([processor]() { processor->decrementActiveTask(); });
   try {
-    processor->onTrigger(processContext, sessionFactory);
+    processor->onTrigger(process_context, session_factory);
   } catch (const std::exception& exception) {
     logger_->log_warn("Caught Exception during SchedulingAgent::onTrigger of processor %s (uuid: %s), type: %s, what: %s",
         processor->getName(), processor->getUUIDStr(), typeid(exception).name(), exception.what());
     processor->yield(admin_yield_duration_);
+    return nonstd::make_unexpected(std::current_exception());
   } catch (...) {
     logger_->log_warn("Caught Exception during SchedulingAgent::onTrigger of processor %s (uuid: %s), type: %s",
         processor->getName(), processor->getUUIDStr(), getCurrentExceptionTypeName());
     processor->yield(admin_yield_duration_);
+    return nonstd::make_unexpected(std::current_exception());
   }
-  processor->decrementActiveTask();
-
-  return false;
+  return {};
 }
 
 void SchedulingAgent::watchDogFunc() {
