@@ -25,4 +25,10 @@ bool isC2Enabled(const std::shared_ptr<Configure>& configuration) {
   return utils::StringUtils::toBool(c2_enable_str).value_or(false);
 }
 
+bool isControllerSocketEnabled(const std::shared_ptr<Configure>& configuration) {
+  std::string controller_socket_enable_str;
+  configuration->get(minifi::Configuration::controller_socket_enable, controller_socket_enable_str);
+  return utils::StringUtils::toBool(controller_socket_enable_str).value_or(false);
+}
+
 }  // namespace org::apache::nifi::minifi::c2
