@@ -25,8 +25,8 @@ namespace org::apache::nifi::minifi::c2 {
  */
 C2Payload FileUpdateTrigger::getAction() {
   if (update_) {
-    C2Payload response_payload(Operation::UPDATE, state::UpdateState::READ_COMPLETE, true);
-    C2ContentResponse resp(Operation::UPDATE);
+    C2Payload response_payload(Operation::update, state::UpdateState::READ_COMPLETE, true);
+    C2ContentResponse resp(Operation::update);
     resp.ident = "triggered";
     resp.name = "configuration";
     resp.operation_arguments["location"] = file_;
@@ -35,7 +35,7 @@ C2Payload FileUpdateTrigger::getAction() {
     update_ = false;
     return response_payload;
   }
-  C2Payload response_payload(Operation::HEARTBEAT, state::UpdateState::READ_COMPLETE, true);
+  C2Payload response_payload(Operation::heartbeat, state::UpdateState::READ_COMPLETE, true);
   return response_payload;
 }
 
