@@ -21,6 +21,7 @@
 #include <openssl/err.h>
 #include <openssl/ssl.h>
 #include <openssl/x509v3.h>
+#include <openssl/bio.h>
 #ifdef WIN32
 #pragma comment(lib, "crypt32.lib")
 #pragma comment(lib, "Ws2_32.lib")
@@ -32,10 +33,10 @@
 #include <memory>
 #include <string>
 
-#include "core/PropertyBuilder.h"
 #include "core/Resource.h"
 #include "io/validation.h"
 #include "properties/Configure.h"
+#include "utils/HTTPUtils.h"
 #include "utils/tls/CertificateUtils.h"
 #include "utils/tls/TLSUtils.h"
 #include "utils/tls/DistinguishedName.h"
@@ -44,73 +45,34 @@
 
 namespace org::apache::nifi::minifi::controllers {
 
-const core::Property SSLContextService::ClientCertificate(
-    core::PropertyBuilder::createProperty("Client Certificate")
-        ->withDescription("Client Certificate")
-        ->isRequired(false)
-        ->build());
-
-const core::Property SSLContextService::PrivateKey(
-    core::PropertyBuilder::createProperty("Private Key")
-        ->withDescription("Private Key file")
-        ->isRequired(false)
-        ->build());
-
-const core::Property SSLContextService::Passphrase(
-    core::PropertyBuilder::createProperty("Passphrase")
-        ->withDescription("Client passphrase. Either a file or unencrypted text")
-        ->isRequired(false)
-        ->build());
-
-const core::Property SSLContextService::CACertificate(
-    core::PropertyBuilder::createProperty("CA Certificate")
-        ->withDescription("CA certificate file")
-        ->isRequired(false)
-        ->build());
-
-const core::Property SSLContextService::UseSystemCertStore(
-    core::PropertyBuilder::createProperty("Use System Cert Store")
-        ->withDescription("Whether to use the certificates in the OS's certificate store")
-        ->isRequired(false)
-        ->withDefaultValue<bool>(false)
-        ->build());
+namespace {
+bool is_valid_and_readable_path(const std::filesystem::path& path_to_be_tested) {
+  std::ifstream file_to_be_tested(path_to_be_tested);
+  return file_to_be_tested.good();
+}
 
 #ifdef WIN32
-const core::Property SSLContextService::CertStoreLocation(
-    core::PropertyBuilder::createProperty("Certificate Store Location")
-        ->withDescription("One of the Windows certificate store locations, eg. LocalMachine or CurrentUser")
-        ->withAllowableValues(utils::tls::WindowsCertStoreLocation::allowedLocations())
-        ->isRequired(false)
-        ->withDefaultValue(utils::tls::WindowsCertStoreLocation::defaultLocation())
-        ->build());
+std::string getCertName(const utils::tls::X509_unique_ptr& cert) {
+  const size_t BUFFER_SIZE = 256;
+  char name_buffer[BUFFER_SIZE];
 
-const core::Property SSLContextService::ServerCertStore(
-    core::PropertyBuilder::createProperty("Server Cert Store")
-        ->withDescription("The name of the certificate store which contains the server certificate")
-        ->isRequired(false)
-        ->withDefaultValue("ROOT")
-        ->build());
+  BIO* bio = BIO_new(BIO_s_mem());
+  if (!bio) {
+    return {};
+  }
+  const auto guard = gsl::finally([&bio]() {
+    BIO_free(bio);
+  });
 
-const core::Property SSLContextService::ClientCertStore(
-    core::PropertyBuilder::createProperty("Client Cert Store")
-        ->withDescription("The name of the certificate store which contains the client certificate")
-        ->isRequired(false)
-        ->withDefaultValue("MY")
-        ->build());
+  X509_NAME_print_ex(bio, X509_get_subject_name(cert.get()), 0, XN_FLAG_ONELINE);
 
-const core::Property SSLContextService::ClientCertCN(
-    core::PropertyBuilder::createProperty("Client Cert CN")
-        ->withDescription("The CN that the client certificate is required to match; default: use the first available client certificate in the store")
-        ->isRequired(false)
-        ->build());
+  int length = BIO_read(bio, name_buffer, BUFFER_SIZE - 1);
+  name_buffer[length] = '\0';
 
-const core::Property SSLContextService::ClientCertKeyUsage(
-    core::PropertyBuilder::createProperty("Client Cert Key Usage")
-        ->withDescription("Comma-separated list of enhanced key usage values that the client certificate is required to have")
-        ->isRequired(false)
-        ->withDefaultValue("Client Authentication")
-        ->build());
-#endif  // WIN32
+  return name_buffer;
+}
+#endif
+}  // namespace
 
 void SSLContextService::initialize() {
   std::lock_guard<std::mutex> lock(initialization_mutex_);
@@ -165,6 +127,19 @@ bool SSLContextService::configure_ssl_context(SSL_CTX *ctx) {
     }
   }
 
+  // Security level set to 0 for backwards compatibility to support TLS versions below v1.2
+  if ((minimum_tls_version_ != -1 && minimum_tls_version_ < TLS1_2_VERSION) || (maximum_tls_version_ != -1 && maximum_tls_version_ < TLS1_2_VERSION)) {
+    SSL_CTX_set_security_level(ctx, 0);
+  }
+
+  if (minimum_tls_version_ != -1) {
+    SSL_CTX_set_min_proto_version(ctx, minimum_tls_version_);
+  }
+
+  if (maximum_tls_version_ != -1) {
+    SSL_CTX_set_max_proto_version(ctx, maximum_tls_version_);
+  }
+
   return true;
 }
 
@@ -245,13 +220,14 @@ bool SSLContextService::findClientCertificate(ClientCertCallback cb) const {
 #ifdef WIN32
 bool SSLContextService::addClientCertificateFromSystemStoreToSSLContext(SSL_CTX* ctx) const {
   return findClientCertificate([&] (auto cert, auto priv_key) -> bool {
+    auto cert_name = getCertName(cert);
     if (SSL_CTX_use_certificate(ctx, cert.get()) != 1) {
-      logger_->log_error("Failed to set certificate from %s, %s", cert->name, getLatestOpenSSLErrorString);
+      logger_->log_error("Failed to set certificate from %s, %s", cert_name, getLatestOpenSSLErrorString);
       return false;
     }
 
     if (SSL_CTX_use_PrivateKey(ctx, priv_key.get()) != 1) {
-      logger_->log_error("Failed to use private key %s, %s", cert->name, getLatestOpenSSLErrorString());
+      logger_->log_error("Failed to use private key %s, %s", cert_name, getLatestOpenSSLErrorString());
       return false;
     }
     return true;
@@ -272,36 +248,36 @@ bool SSLContextService::useClientCertificate(PCCERT_CONTEXT certificate, ClientC
     return false;
   }
 
+  std::string x509_name = getCertName(x509_cert);
   utils::tls::EVP_PKEY_unique_ptr private_key = utils::tls::extractPrivateKey(certificate);
   if (!private_key) {
-    logger_->log_debug("Skipping client certificate %s because it has no exportable private key", x509_cert->name);
+    logger_->log_debug("Skipping client certificate %s because it has no exportable private key", x509_name);
     return false;
   }
 
   if (!client_cert_cn_.empty()) {
-    utils::tls::DistinguishedName dn = utils::tls::DistinguishedName::fromSlashSeparated(x509_cert->name);
+    utils::tls::DistinguishedName dn = utils::tls::DistinguishedName::fromSlashSeparated(x509_name);
     std::optional<std::string> cn = dn.getCN();
     if (!cn || *cn != client_cert_cn_) {
-      logger_->log_debug("Skipping client certificate %s because it doesn't match CN=%s", x509_cert->name, client_cert_cn_);
+      logger_->log_debug("Skipping client certificate %s because it doesn't match CN=%s", x509_name, client_cert_cn_);
       return false;
     }
   }
 
   utils::tls::EXTENDED_KEY_USAGE_unique_ptr key_usage{static_cast<EXTENDED_KEY_USAGE*>(X509_get_ext_d2i(x509_cert.get(), NID_ext_key_usage, nullptr, nullptr))};
   if (!key_usage) {
-    logger_->log_error("Skipping client certificate %s because it has no extended key usage", x509_cert->name);
+    logger_->log_error("Skipping client certificate %s because it has no extended key usage", x509_name);
     return false;
   }
 
   if (!(client_cert_key_usage_.isSubsetOf(utils::tls::ExtendedKeyUsage{*key_usage}))) {
     logger_->log_debug("Skipping client certificate %s because its extended key usage set does not contain all usages specified in %s",
-                       x509_cert->name, Configuration::nifi_security_windows_client_cert_key_usage);
+                       x509_name, Configuration::nifi_security_windows_client_cert_key_usage);
     return false;
   }
 
-  std::string cert_name = x509_cert->name;
   if (cb(std::move(x509_cert), std::move(private_key))) {
-    logger_->log_debug("Found client certificate %s", cert_name);
+    logger_->log_debug("Found client certificate %s", x509_name);
     return true;
   }
 
@@ -319,25 +295,31 @@ bool SSLContextService::addServerCertificatesFromSystemStoreToSSLContext(SSL_CTX
 
   findServerCertificate([&] (auto cert) -> bool {
     // return false to indicate that we wish to iterate over all subsequent certificates as well
+    auto cert_name = getCertName(cert);
     int success = X509_STORE_add_cert(ssl_store, cert.get());
     if (success == 1) {
-      logger_->log_debug("Added server certificate %s from the system store to the SSL store", cert->name);
+      logger_->log_debug("Added server certificate %s from the system store to the SSL store", cert_name);
       return false;
     }
 
     auto err = ERR_peek_last_error();
     if (ERR_GET_REASON(err) == X509_R_CERT_ALREADY_IN_HASH_TABLE) {
-      logger_->log_debug("Ignoring duplicate server certificate %s", cert->name);
+      logger_->log_debug("Ignoring duplicate server certificate %s", cert_name);
       return false;
     }
 
-    logger_->log_error("Failed to add server certificate %s to the SSL store; error: %s", cert->name, getLatestOpenSSLErrorString());
+    logger_->log_error("Failed to add server certificate %s to the SSL store; error: %s", cert_name, getLatestOpenSSLErrorString());
     return false;
   });
 
   return true;
 #else
-  SSL_CTX_set_default_verify_paths(ctx);
+  static const auto default_ca_file = utils::getDefaultCAFile();
+  if (default_ca_file) {
+    SSL_CTX_load_verify_file(ctx, std::string(*default_ca_file).c_str());
+  } else {
+    SSL_CTX_set_default_verify_paths(ctx);
+  }
   return true;
 #endif  // WIN32
 }
@@ -387,7 +369,7 @@ std::unique_ptr<SSLContext> SSLContextService::createSSLContext() {
 
   OpenSSL_add_all_algorithms();
   SSL_load_error_strings();
-  method = TLSv1_2_client_method();
+  method = TLS_client_method();
   SSL_CTX *ctx = SSL_CTX_new(method);
 
   if (ctx == nullptr) {
@@ -425,13 +407,6 @@ const std::filesystem::path &SSLContextService::getCACertificate() const {
   return ca_certificate_;
 }
 
-namespace {
-bool is_valid_and_readable_path(const std::filesystem::path& path_to_be_tested) {
-  std::ifstream file_to_be_tested(path_to_be_tested);
-  return file_to_be_tested.good();
-}
-}  // namespace
-
 void SSLContextService::onEnable() {
   std::filesystem::path default_dir;
 
@@ -444,7 +419,7 @@ void SSLContextService::onEnable() {
   logger_->log_trace("onEnable()");
 
   certificate_.clear();
-  if (auto certificate = getProperty(ClientCertificate.getName())) {
+  if (auto certificate = getProperty(ClientCertificate)) {
     if (is_valid_and_readable_path(*certificate)) {
       certificate_ = *certificate;
     } else {
@@ -461,7 +436,7 @@ void SSLContextService::onEnable() {
 
   private_key_.clear();
   if (!certificate_.empty() && !isFileTypeP12(certificate_)) {
-    if (auto private_key = getProperty(PrivateKey.getName())) {
+    if (auto private_key = getProperty(PrivateKey)) {
       if (is_valid_and_readable_path(*private_key)) {
         private_key_ = *private_key;
       } else {
@@ -479,7 +454,7 @@ void SSLContextService::onEnable() {
   }
 
   passphrase_.clear();
-  if (!getProperty(Passphrase.getName(), passphrase_)) {
+  if (!getProperty(Passphrase, passphrase_)) {
     logger_->log_debug("No pass phrase for %s", certificate_.string());
   } else {
     std::ifstream passphrase_file(passphrase_);
@@ -500,7 +475,7 @@ void SSLContextService::onEnable() {
   }
 
   ca_certificate_.clear();
-  if (auto ca_certificate = getProperty(CACertificate.getName())) {
+  if (auto ca_certificate = getProperty(CACertificate)) {
     if (is_valid_and_readable_path(*ca_certificate)) {
       ca_certificate_ = *ca_certificate;
     } else {
@@ -516,24 +491,29 @@ void SSLContextService::onEnable() {
     logger_->log_debug("CA Certificate empty");
   }
 
-  getProperty(UseSystemCertStore.getName(), use_system_cert_store_);
+  getProperty(UseSystemCertStore, use_system_cert_store_);
 
 #ifdef WIN32
-  getProperty(CertStoreLocation.getName(), cert_store_location_);
-  getProperty(ServerCertStore.getName(), server_cert_store_);
-  getProperty(ClientCertStore.getName(), client_cert_store_);
-  getProperty(ClientCertCN.getName(), client_cert_cn_);
+  getProperty(CertStoreLocation, cert_store_location_);
+  getProperty(ServerCertStore, server_cert_store_);
+  getProperty(ClientCertStore, client_cert_store_);
+  getProperty(ClientCertCN, client_cert_cn_);
 
   std::string client_cert_key_usage;
-  getProperty(ClientCertKeyUsage.getName(), client_cert_key_usage);
+  getProperty(ClientCertKeyUsage, client_cert_key_usage);
   client_cert_key_usage_ = utils::tls::ExtendedKeyUsage{client_cert_key_usage};
 #endif  // WIN32
 
+  logger_->log_debug("Using certificate file \"%s\"", certificate_.string());
+  logger_->log_debug("Using private key file \"%s\"", private_key_.string());
+  logger_->log_debug("Using CA certificate file \"%s\"", ca_certificate_.string());
+  logger_->log_debug("Using the system cert store: %s", use_system_cert_store_ ? "yes" : "no");
+
   verifyCertificateExpiration();
 }
 
 void SSLContextService::initializeProperties() {
-  setSupportedProperties(properties());
+  setSupportedProperties(Properties);
 }
 
 void SSLContextService::verifyCertificateExpiration() {
@@ -605,14 +585,16 @@ void SSLContextService::verifyCertificateExpiration() {
 #ifdef WIN32
   if (use_system_cert_store_ && IsNullOrEmpty(certificate_)) {
     findClientCertificate([&] (auto cert, auto /*priv_key*/) -> bool {
-      verify(cert->name, cert);
+      auto cert_name = getCertName(cert);
+      verify(cert_name, cert);
       return false;  // keep on iterating, check all
     });
   }
 
   if (use_system_cert_store_ && IsNullOrEmpty(ca_certificate_)) {
     findServerCertificate([&] (auto cert) -> bool {
-      verify(cert->name, cert);
+      auto cert_name = getCertName(cert);
+      verify(cert_name, cert);
       return false;  // keep on iterating, check all
     });
   }
