@@ -122,25 +122,30 @@ std::unique_ptr<core::ProcessGroup> StructuredConfiguration::parseProcessGroup(c
 }
 
 std::unique_ptr<core::ProcessGroup> StructuredConfiguration::getRootFrom(const Node& root_node, FlowSchema schema) {
-  schema_ = std::move(schema);
-  uuids_.clear();
-  Node controllerServiceNode = root_node[schema_.root_group][schema_.controller_services];
-  Node provenanceReportNode = root_node[schema_.provenance_reporting];
+  try {
+    schema_ = std::move(schema);
+    uuids_.clear();
+    Node controllerServiceNode = root_node[schema_.root_group][schema_.controller_services];
+    Node provenanceReportNode = root_node[schema_.provenance_reporting];
 
-  parseControllerServices(controllerServiceNode);
-  // Create the root process group
-  std::unique_ptr<core::ProcessGroup> root = parseRootProcessGroup(root_node);
-  parseProvenanceReporting(provenanceReportNode, root.get());
+    parseControllerServices(controllerServiceNode);
+    // Create the root process group
+    std::unique_ptr<core::ProcessGroup> root = parseRootProcessGroup(root_node);
+    parseProvenanceReporting(provenanceReportNode, root.get());
 
-  // set the controller services into the root group.
-  for (const auto& controller_service : controller_services_->getAllControllerServices()) {
-    root->addControllerService(controller_service->getName(), controller_service);
-    root->addControllerService(controller_service->getUUIDStr(), controller_service);
+    // set the controller services into the root group.
+    for (const auto& controller_service : controller_services_->getAllControllerServices()) {
+      root->addControllerService(controller_service->getName(), controller_service);
+      root->addControllerService(controller_service->getUUIDStr(), controller_service);
+    }
+
+    root->verify();
+
+    return root;
+  } catch (const std::exception& ex) {
+    logger_->log_error("Error while processing configuration file: %s", ex.what());
+    throw;
   }
-
-  root->verify();
-
-  return root;
 }
 
 void StructuredConfiguration::parseProcessorNode(const Node& processors_node, core::ProcessGroup* parentGroup) {
@@ -242,7 +247,7 @@ void StructuredConfiguration::parseProcessorNode(const Node& processors_node, co
     if (procCfg.schedulingStrategy == "TIMER_DRIVEN" || procCfg.schedulingStrategy == "EVENT_DRIVEN") {
       if (auto scheduling_period = utils::timeutils::StringToDuration<std::chrono::nanoseconds>(procCfg.schedulingPeriod)) {
         logger_->log_debug("convert: parseProcessorNode: schedulingPeriod => [%" PRId64 "] ns", scheduling_period->count());
-        processor->setSchedulingPeriodNano(*scheduling_period);
+        processor->setSchedulingPeriod(*scheduling_period);
       }
     } else {
       processor->setCronPeriod(procCfg.schedulingPeriod);
@@ -432,7 +437,7 @@ void StructuredConfiguration::parseProvenanceReporting(const Node& node, core::P
 
   if (auto scheduling_period = utils::timeutils::StringToDuration<std::chrono::nanoseconds>(schedulingPeriodStr)) {
     logger_->log_debug("ProvenanceReportingTask schedulingPeriod %" PRId64 " ns", scheduling_period->count());
-    reportTask->setSchedulingPeriodNano(*scheduling_period);
+    reportTask->setSchedulingPeriod(*scheduling_period);
   }
 
   if (schedulingStrategyStr == "TIMER_DRIVEN") {
@@ -586,7 +591,7 @@ void StructuredConfiguration::parseRPGPort(const Node& port_node, core::ProcessG
   uuid = portId;
 
   auto port = std::make_unique<minifi::RemoteProcessorGroupPort>(
-          stream_factory_, nameStr, parent->getURL(), this->configuration_, uuid);
+          nameStr, parent->getURL(), this->configuration_, uuid);
   port->setDirection(direction);
   port->setTimeout(parent->getTimeout());
   port->setTransmitting(true);
@@ -605,7 +610,7 @@ void StructuredConfiguration::parseRPGPort(const Node& port_node, core::ProcessG
   if (Node propertiesNode = port_node[schema_.rpg_port_properties]) {
     parsePropertiesNode(propertiesNode, *port, nameStr);
   } else {
-    parsePropertyNodeElement(minifi::RemoteProcessorGroupPort::portUUID.getName(), port_node[schema_.rpg_port_target_id], *port);
+    parsePropertyNodeElement(std::string(minifi::RemoteProcessorGroupPort::portUUID.name), port_node[schema_.rpg_port_target_id], *port);
     validateComponentProperties(*port, nameStr, port_node.getPath());
   }
 
@@ -800,7 +805,7 @@ void StructuredConfiguration::validateComponentProperties(ConfigurableComponent&
       if (prop_pair.second.getValue().to_string().empty()) {
         std::string reason = utils::StringUtils::join_pack("required property '", prop_pair.second.getName(), "' is not set");
         raiseComponentError(component_name, section, reason);
-      } else if (!prop_pair.second.getValue().validate(prop_pair.first).valid()) {
+      } else if (!prop_pair.second.getValue().validate(prop_pair.first).valid) {
         std::string reason = utils::StringUtils::join_pack("the value '", prop_pair.first, "' is not valid for property '", prop_pair.second.getName(), "'");
         raiseComponentError(component_name, section, reason);
       }
@@ -841,19 +846,6 @@ void StructuredConfiguration::validateComponentProperties(ConfigurableComponent&
       }
     }
   }
-
-  // Validate regex properties
-  for (const auto &prop_pair : component_properties) {
-    const auto &prop_regex_str = prop_pair.second.getValidRegex();
-
-    if (!prop_regex_str.empty()) {
-      utils::Regex prop_regex(prop_regex_str);
-      if (!utils::regexMatch(prop_pair.second.getValue().to_string(), prop_regex)) {
-        std::string reason = utils::StringUtils::join_pack("property '", prop_pair.second.getName(), "' does not match validation pattern '", prop_regex_str, "'");
-        raiseComponentError(component_name, section, reason);
-      }
-    }
-  }
 }
 
 void StructuredConfiguration::raiseComponentError(const std::string &component_name, const std::string &section, const std::string &reason) const {
