@@ -17,12 +17,10 @@
  */
 
 #include "core/state/Value.h"
-#include <openssl/sha.h>
+#include <openssl/evp.h>
 #include <utility>
 #include <string>
-#include "rapidjson/document.h"
-#include "rapidjson/writer.h"
-#include "rapidjson/stringbuffer.h"
+#include "rapidjson/prettywriter.h"
 
 namespace org::apache::nifi::minifi::state::response {
 
@@ -34,30 +32,32 @@ const std::type_index Value::BOOL_TYPE = std::type_index(typeid(bool));
 const std::type_index Value::DOUBLE_TYPE = std::type_index(typeid(double));
 const std::type_index Value::STRING_TYPE = std::type_index(typeid(std::string));
 
-void hashNode(const SerializedResponseNode& node, SHA512_CTX& ctx) {
-  SHA512_Update(&ctx, node.name.c_str(), node.name.length());
+void hashNode(const SerializedResponseNode& node, EVP_MD_CTX& ctx) {
+  EVP_DigestUpdate(&ctx, node.name.c_str(), node.name.length());
   const auto valueStr = node.value.to_string();
-  SHA512_Update(&ctx, valueStr.c_str(), valueStr.length());
-  SHA512_Update(&ctx, &node.array, sizeof(node.array));
-  SHA512_Update(&ctx, &node.collapsible, sizeof(node.collapsible));
+  EVP_DigestUpdate(&ctx, valueStr.c_str(), valueStr.length());
+  EVP_DigestUpdate(&ctx, &node.array, sizeof(node.array));
+  EVP_DigestUpdate(&ctx, &node.collapsible, sizeof(node.collapsible));
   for (const auto& child : node.children) {
     hashNode(child, ctx);
   }
 }
 
 std::string hashResponseNodes(const std::vector<SerializedResponseNode>& nodes) {
-  SHA512_CTX ctx;
-  SHA512_Init(&ctx);
+  EVP_MD_CTX *ctx = EVP_MD_CTX_new();
+  const auto guard = gsl::finally([&ctx]() {
+    EVP_MD_CTX_free(ctx);
+  });
+  EVP_DigestInit_ex(ctx, EVP_sha512(), nullptr);
   for (const auto& node : nodes) {
-    hashNode(node, ctx);
+    hashNode(node, *ctx);
   }
-  std::array<std::byte, SHA512_DIGEST_LENGTH> digest{};
-  SHA512_Final(reinterpret_cast<unsigned char*>(digest.data()), &ctx);
+  std::array<std::byte, EVP_MAX_MD_SIZE> digest{};
+  EVP_DigestFinal_ex(ctx, reinterpret_cast<unsigned char*>(digest.data()), nullptr);
   return utils::StringUtils::to_hex(digest, true /*uppercase*/);
 }
 
-namespace {
-rapidjson::Value nodeToJson(const SerializedResponseNode& node, rapidjson::MemoryPoolAllocator<rapidjson::CrtAllocator>& alloc) {
+rapidjson::Value SerializedResponseNode::nodeToJson(const SerializedResponseNode& node, rapidjson::MemoryPoolAllocator<rapidjson::CrtAllocator>& alloc) {
   if (node.value.empty()) {
     if (node.array) {
       rapidjson::Value result(rapidjson::kArrayType);
@@ -76,16 +76,9 @@ rapidjson::Value nodeToJson(const SerializedResponseNode& node, rapidjson::Memor
     return {node.value.to_string().c_str(), alloc};
   }
 }
-}  // namespace
 
-std::string SerializedResponseNode::to_string() const {
-  rapidjson::Document doc;
-  doc.SetObject();
-  doc.AddMember(rapidjson::Value(name.c_str(), doc.GetAllocator()), nodeToJson(*this, doc.GetAllocator()), doc.GetAllocator());
-  rapidjson::StringBuffer buf;
-  rapidjson::Writer<rapidjson::StringBuffer> writer{buf};
-  doc.Accept(writer);
-  return buf.GetString();
+std::string SerializedResponseNode::to_pretty_string() const {
+  return to_string<rapidjson::PrettyWriter<rapidjson::StringBuffer>>();
 }
 }  // namespace org::apache::nifi::minifi::state::response
 
