@@ -16,9 +16,11 @@
  */
 
 #include "core/state/nodes/SupportedOperations.h"
-#include "core/PropertyBuilder.h"
 #include "core/Resource.h"
-#include "range/v3/algorithm/find.hpp"
+#include "range/v3/algorithm/contains.hpp"
+#include "range/v3/view/filter.hpp"
+#include "range/v3/view/view.hpp"
+#include "utils/Enum.h"
 
 namespace org::apache::nifi::minifi::state::response {
 
@@ -37,50 +39,41 @@ std::string SupportedOperations::getName() const {
 }
 
 void SupportedOperations::addProperty(SerializedResponseNode& properties, const std::string& operand, const Metadata& metadata) {
-  SerializedResponseNode operand_node;
-  operand_node.name = operand;
-  operand_node.keep_empty = true;
+  SerializedResponseNode operand_node{.name = operand, .keep_empty = true};
 
   for (const auto& [key, value_array] : metadata) {
-    SerializedResponseNode metadata_item;
-    metadata_item.name = key;
-    metadata_item.array = true;
-
+    SerializedResponseNode metadata_item{.name = key, .array = true};
     for (const auto& value_object : value_array) {
       SerializedResponseNode value_child;
       for (const auto& pair: value_object) {
-        SerializedResponseNode object_element;
-        object_element.name = pair.first;
-        object_element.value = pair.second;
-        value_child.children.push_back(object_element);
+        value_child.children.push_back({.name = pair.first, .value = pair.second});
       }
       metadata_item.children.push_back(value_child);
     }
-
     operand_node.children.push_back(metadata_item);
   }
-
   properties.children.push_back(operand_node);
 }
 
 SupportedOperations::Metadata SupportedOperations::buildUpdatePropertiesMetadata() const {
   std::vector<std::unordered_map<std::string, std::string>> supported_config_updates;
-  for (const auto& config_property : Configuration::CONFIGURATION_PROPERTIES) {
-    auto sensitive_properties = Configuration::getSensitiveProperties(configuration_reader_);
-    if (ranges::find(sensitive_properties, config_property.name) != ranges::end(sensitive_properties)) {
-      continue;
-    }
-    if (!update_policy_controller_ || update_policy_controller_->canUpdate(std::string(config_property.name))) {
-      std::unordered_map<std::string, std::string> property;
-      property.emplace("propertyName", config_property.name);
-      property.emplace("validator", config_property.validator->getName());
-      if (configuration_reader_) {
-        if (auto property_value = configuration_reader_(std::string(config_property.name))) {
-          property.emplace("propertyValue", *property_value);
-        }
+  auto sensitive_properties = Configuration::getSensitiveProperties(configuration_reader_);
+  auto updatable_not_sensitive_configuration_properties = minifi::Configuration::CONFIGURATION_PROPERTIES | ranges::views::filter([&](const auto& configuration_property) {
+    const auto& configuration_property_name = configuration_property.first;
+    return !ranges::contains(sensitive_properties, configuration_property_name)
+        && (!update_policy_controller_ || update_policy_controller_->canUpdate(std::string(configuration_property_name)));
+  });
+
+  for (const auto& [config_property_name, config_property_validator] : updatable_not_sensitive_configuration_properties) {
+    std::unordered_map<std::string, std::string> property;
+    property.emplace("propertyName", config_property_name);
+    property.emplace("validator", config_property_validator->getValidatorName());
+    if (configuration_reader_) {
+      if (auto property_value = configuration_reader_(std::string(config_property_name))) {
+        property.emplace("propertyValue", *property_value);
       }
-      supported_config_updates.push_back(property);
     }
+    supported_config_updates.push_back(property);
   }
   Metadata available_properties;
   available_properties.emplace("availableProperties", supported_config_updates);
@@ -88,27 +81,27 @@ SupportedOperations::Metadata SupportedOperations::buildUpdatePropertiesMetadata
 }
 
 void SupportedOperations::fillProperties(SerializedResponseNode& properties, minifi::c2::Operation operation) const {
-  switch (operation.value()) {
-    case minifi::c2::Operation::DESCRIBE: {
+  switch (operation) {
+    case minifi::c2::Operation::describe: {
       serializeProperty<minifi::c2::DescribeOperand>(properties);
       break;
     }
-    case minifi::c2::Operation::UPDATE: {
+    case minifi::c2::Operation::update: {
       std::unordered_map<std::string, Metadata> operand_with_metadata;
       operand_with_metadata.emplace("properties", buildUpdatePropertiesMetadata());
       serializeProperty<minifi::c2::UpdateOperand>(properties, operand_with_metadata);
       break;
     }
-    case minifi::c2::Operation::TRANSFER: {
+    case minifi::c2::Operation::transfer: {
       serializeProperty<minifi::c2::TransferOperand>(properties);
       break;
     }
-    case minifi::c2::Operation::CLEAR: {
+    case minifi::c2::Operation::clear: {
       serializeProperty<minifi::c2::ClearOperand>(properties);
       break;
     }
-    case minifi::c2::Operation::START:
-    case minifi::c2::Operation::STOP: {
+    case minifi::c2::Operation::start:
+    case minifi::c2::Operation::stop: {
       addProperty(properties, "c2");
       if (monitor_) {
         monitor_->executeOnAllComponents([&properties](StateController& component){
@@ -123,31 +116,23 @@ void SupportedOperations::fillProperties(SerializedResponseNode& properties, min
 }
 
 std::vector<SerializedResponseNode> SupportedOperations::serialize() {
-  std::vector<SerializedResponseNode> serialized;
-  SerializedResponseNode supported_operation;
-  supported_operation.name = "supportedOperations";
-  supported_operation.array = true;
+  SerializedResponseNode supported_operation{.name = "supportedOperations", .array = true};
 
-  for (const auto& operation : minifi::c2::Operation::values()) {
-    SerializedResponseNode child;
-    child.name = "supportedOperations";
+  for (const auto& operation : magic_enum::enum_names<minifi::c2::Operation>()) {
+    SerializedResponseNode child{
+      .name = "supportedOperations",
+      .children = {
+        {.name = "type", .value = std::string(operation)}
+      }
+    };
 
-    SerializedResponseNode operation_type;
-    operation_type.name = "type";
-    operation_type.value = operation;
-
-    SerializedResponseNode properties;
-    properties.name = "properties";
-
-    fillProperties(properties, minifi::c2::Operation::parse(operation.c_str(), {}, false));
-
-    child.children.push_back(operation_type);
+    SerializedResponseNode properties{.name = "properties"};
+    fillProperties(properties, utils::enumCast<minifi::c2::Operation>(operation, true));
     child.children.push_back(properties);
     supported_operation.children.push_back(child);
   }
 
-  serialized.push_back(supported_operation);
-  return serialized;
+  return {supported_operation};
 }
 
 REGISTER_RESOURCE(SupportedOperations, DescriptionOnly);
