@@ -23,11 +23,7 @@
 
 #include "utils/gsl.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace sitetosite {
+namespace org::apache::nifi::minifi::sitetosite {
 
 int SiteToSiteClient::readResponse(const std::shared_ptr<Transaction>& /*transaction*/, RespondCode &code, std::string &message) {
   uint8_t firstByte;
@@ -78,7 +74,7 @@ void SiteToSiteClient::deleteTransaction(const utils::Identifier& transactionID)
   known_transactions_.erase(transactionID);
 }
 
-int SiteToSiteClient::writeResponse(const std::shared_ptr<Transaction>& /*transaction*/, RespondCode code, std::string message) {
+int SiteToSiteClient::writeResponse(const std::shared_ptr<Transaction>& /*transaction*/, RespondCode code, const std::string& message) {
   RespondCodeContext *resCode = this->getRespondCodeContext(code);
   if (!resCode) {
     return -1;
@@ -176,14 +172,14 @@ bool SiteToSiteClient::transferFlowFiles(const std::shared_ptr<core::ProcessCont
       deleteTransaction(transactionID);
     context->yield();
     tearDown();
-    logger_->log_debug("Caught Exception %s", exception.what());
+    logger_->log_debug("Caught Exception during SiteToSiteClient::transferFlowFiles, type: %s, what: %s", typeid(exception).name(), exception.what());
     throw;
   } catch (...) {
     if (transaction)
       deleteTransaction(transactionID);
     context->yield();
     tearDown();
-    logger_->log_debug("Caught Exception during SiteToSiteClient::transferFlowFiles");
+    logger_->log_debug("Caught Exception during SiteToSiteClient::transferFlowFiles, type: %s", getCurrentExceptionTypeName());
     throw;
   }
 
@@ -281,7 +277,7 @@ bool SiteToSiteClient::confirm(const utils::Identifier& transactionID) {
           return true;
         } else {
           logger_->log_debug("Site2Site transaction %s CRC not matched %s", transactionID.to_string(), crc);
-          ret = writeResponse(transaction, BAD_CHECKSUM, "BAD_CHECKSUM");
+          writeResponse(transaction, BAD_CHECKSUM, "BAD_CHECKSUM");
           return false;
         }
       }
@@ -299,7 +295,7 @@ bool SiteToSiteClient::confirm(const utils::Identifier& transactionID) {
 }
 
 void SiteToSiteClient::cancel(const utils::Identifier& transactionID) {
-  std::shared_ptr<Transaction> transaction = NULL;
+  std::shared_ptr<Transaction> transaction = nullptr;
 
   if (peer_state_ != READY) {
     return;
@@ -321,11 +317,10 @@ void SiteToSiteClient::cancel(const utils::Identifier& transactionID) {
   transaction->_state = TRANSACTION_CANCELED;
 
   tearDown();
-  return;
 }
 
 void SiteToSiteClient::error(const utils::Identifier& transactionID) {
-  std::shared_ptr<Transaction> transaction = NULL;
+  std::shared_ptr<Transaction> transaction = nullptr;
 
   auto it = this->known_transactions_.find(transactionID);
 
@@ -337,13 +332,12 @@ void SiteToSiteClient::error(const utils::Identifier& transactionID) {
 
   transaction->_state = TRANSACTION_ERROR;
   tearDown();
-  return;
 }
 
 // Complete the transaction
 bool SiteToSiteClient::complete(const utils::Identifier& transactionID) {
   int ret;
-  std::shared_ptr<Transaction> transaction = NULL;
+  std::shared_ptr<Transaction> transaction = nullptr;
 
   if (peer_state_ != READY) {
     bootstrap();
@@ -471,7 +465,7 @@ int16_t SiteToSiteClient::send(const utils::Identifier &transactionID, DataPacke
       return -1;
     }
     if (flowFile->getSize() > 0) {
-      session->read(flowFile, [packet](const std::shared_ptr<io::BaseStream>& input_stream) -> int64_t {
+      session->read(flowFile, [packet](const std::shared_ptr<io::InputStream>& input_stream) -> int64_t {
         const auto result = internal::pipe(*input_stream, packet->transaction_->getStream());
         if (result == -1) return -1;
         packet->_size = gsl::narrow<size_t>(result);
@@ -644,7 +638,7 @@ bool SiteToSiteClient::receive(const utils::Identifier& transactionID, DataPacke
 bool SiteToSiteClient::receiveFlowFiles(const std::shared_ptr<core::ProcessContext> &context, const std::shared_ptr<core::ProcessSession> &session) {
   uint64_t bytes = 0;
   int transfers = 0;
-  std::shared_ptr<Transaction> transaction = NULL;
+  std::shared_ptr<Transaction> transaction = nullptr;
 
   if (peer_state_ != READY) {
     if (!bootstrap()) {
@@ -661,7 +655,7 @@ bool SiteToSiteClient::receiveFlowFiles(const std::shared_ptr<core::ProcessConte
   // Create the transaction
   transaction = createTransaction(RECEIVE);
 
-  if (transaction == NULL) {
+  if (transaction == nullptr) {
     context->yield();
     tearDown();
     throw Exception(SITE2SITE_EXCEPTION, "Can not create transaction");
@@ -698,7 +692,7 @@ bool SiteToSiteClient::receiveFlowFiles(const std::shared_ptr<core::ProcessConte
       }
 
       if (packet._size > 0) {
-        session->write(flowFile, [&packet](const std::shared_ptr<io::BaseStream>& output_stream) -> int64_t {
+        session->write(flowFile, [&packet](const std::shared_ptr<io::OutputStream>& output_stream) -> int64_t {
           return internal::pipe(packet.transaction_->getStream(), *output_stream);
         });
         if (flowFile->getSize() != packet._size) {
@@ -738,22 +732,18 @@ bool SiteToSiteClient::receiveFlowFiles(const std::shared_ptr<core::ProcessConte
       deleteTransaction(transactionID);
     context->yield();
     tearDown();
-    logger_->log_warn("Caught Exception %s", exception.what());
+    logger_->log_warn("Caught Exception during RawSiteToSiteClient::receiveFlowFiles, type: %s, what: %s", typeid(exception).name(), exception.what());
     throw;
   } catch (...) {
     if (transaction)
       deleteTransaction(transactionID);
     context->yield();
     tearDown();
-    logger_->log_warn("Caught Exception during RawSiteToSiteClient::receiveFlowFiles");
+    logger_->log_warn("Caught Exception during RawSiteToSiteClient::receiveFlowFiles, type: %s", getCurrentExceptionTypeName());
     throw;
   }
 
   deleteTransaction(transactionID);
   return true;
 }
-} /* namespace sitetosite */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::sitetosite
