@@ -23,8 +23,8 @@
 
 #include "utils/Id.h"
 
-#define __STDC_FORMAT_MACROS 1
-#include <inttypes.h>
+#define __STDC_FORMAT_MACROS 1  // NOLINT(bugprone-reserved-identifier,cert-dcl37-c,cert-dcl51-cpp)
+#include <cinttypes>
 #include <algorithm>
 #include <chrono>
 #include <cmath>
@@ -32,7 +32,7 @@
 #include <memory>
 #include <string>
 #include <limits>
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 
 #ifdef WIN32
 #include "Rpc.h"
@@ -42,12 +42,9 @@
 #endif
 
 #include "utils/StringUtils.h"
+#include "utils/gsl.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace utils {
+namespace org::apache::nifi::minifi::utils {
 
 #ifdef WIN32
 namespace {
@@ -171,7 +168,8 @@ std::optional<Identifier> Identifier::parse(const std::string &str) {
 }
 
 bool Identifier::parseByte(Data &data, const uint8_t *input, int &charIdx, int &byteIdx) {
-  uint8_t upper, lower;
+  uint8_t upper;
+  uint8_t lower;
   if (!StringUtils::from_hex(input[charIdx++], upper)
       || !StringUtils::from_hex(input[charIdx++], lower)) {
     return false;
@@ -193,8 +191,8 @@ IdGenerator::~IdGenerator() = default;
 
 uint64_t IdGenerator::getDeviceSegmentFromString(const std::string& str, int numBits) const {
   uint64_t deviceSegment = 0;
-  for (size_t i = 0; i < str.length(); i++) {
-    unsigned char c = toupper(str[i]);
+  for (auto ch : str) {
+    auto c = gsl::narrow_cast<unsigned char>(std::toupper(gsl::narrow_cast<unsigned char>(ch)));
     if (c >= '0' && c <= '9') {
       deviceSegment = deviceSegment + (c - '0');
     } else if (c >= 'A' && c <= 'F') {
@@ -330,8 +328,4 @@ Identifier IdGenerator::generate() {
   return Identifier{output};
 }
 
-} /* namespace utils */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::utils
