@@ -16,9 +16,7 @@
  */
 
 #include <limits>
-
-#include "range/v3/view/transform.hpp"
-#include "range/v3/range/conversion.hpp"
+#include <charconv>
 
 #include "utils/Environment.h"
 #include "utils/GeneralUtils.h"
@@ -26,8 +24,6 @@
 
 namespace org::apache::nifi::minifi::utils {
 
-namespace views = ranges::views;
-
 std::optional<bool> StringUtils::toBool(const std::string& input) {
   std::string trimmed = trim(input);
   if (equalsIgnoreCase(trimmed, "true")) {
@@ -39,11 +35,6 @@ std::optional<bool> StringUtils::toBool(const std::string& input) {
   return std::nullopt;
 }
 
-std::string StringUtils::toLower(std::string_view str) {
-  const auto tolower = [](auto c) { return std::tolower(static_cast<unsigned char>(c)); };
-  return str | views::transform(tolower) | ranges::to<std::string>();
-}
-
 std::pair<std::string, std::string> StringUtils::chomp(const std::string& input_line) {
   if (endsWith(input_line, "\r\n")) {
     return std::make_pair(input_line.substr(0, input_line.size() - 2), "\r\n");
@@ -73,7 +64,8 @@ std::string_view StringUtils::trim(const char* str) {
 }
 
 template<typename Fun>
-std::vector<std::string> split_transformed(std::string str, const std::string& delimiter, Fun transformation) {
+std::vector<std::string> split_transformed(std::string_view str_view, std::string_view delimiter, Fun transformation) {
+  std::string str{str_view};
   std::vector<std::string> result;
   if (delimiter.empty()) {
     for (auto c : str) {
@@ -96,21 +88,21 @@ std::vector<std::string> split_transformed(std::string str, const std::string& d
   return result;
 }
 
-std::vector<std::string> StringUtils::split(const std::string& str, const std::string& delimiter) {
+std::vector<std::string> StringUtils::split(std::string_view str, std::string_view delimiter) {
   return split_transformed(str, delimiter, identity{});
 }
 
-std::vector<std::string> StringUtils::splitRemovingEmpty(const std::string& str, const std::string& delimiter) {
+std::vector<std::string> StringUtils::splitRemovingEmpty(std::string_view str, std::string_view delimiter) {
   auto result = split(str, delimiter);
   result.erase(std::remove_if(result.begin(), result.end(), [](const std::string& str) { return str.empty(); }), result.end());
   return result;
 }
 
-std::vector<std::string> StringUtils::splitAndTrim(const std::string& str, const std::string& delimiter) {
+std::vector<std::string> StringUtils::splitAndTrim(std::string_view str, std::string_view delimiter) {
   return split_transformed(str, delimiter, static_cast<std::string(*)(const std::string&)>(trim));
 }
 
-std::vector<std::string> StringUtils::splitAndTrimRemovingEmpty(const std::string& str, const std::string& delimiter) {
+std::vector<std::string> StringUtils::splitAndTrimRemovingEmpty(std::string_view str, std::string_view delimiter) {
   auto result = splitAndTrim(str, delimiter);
   result.erase(std::remove_if(result.begin(), result.end(), [](const std::string& str) { return str.empty(); }), result.end());
   return result;
@@ -327,7 +319,7 @@ std::vector<std::byte> StringUtils::from_hex(std::string_view hex) {
   return decoded;
 }
 
-size_t StringUtils::to_hex(char* hex, gsl::span<const std::byte> data_to_be_transformed, bool uppercase) {
+size_t StringUtils::to_hex(char* hex, std::span<const std::byte> data_to_be_transformed, bool uppercase) {
   if (data_to_be_transformed.size() > std::numeric_limits<size_t>::max() / 2) {
     throw std::length_error("Data is too large to be hexencoded");
   }
@@ -338,7 +330,7 @@ size_t StringUtils::to_hex(char* hex, gsl::span<const std::byte> data_to_be_tran
   return data_to_be_transformed.size() * 2;
 }
 
-std::string StringUtils::to_hex(gsl::span<const std::byte> data_to_be_transformed, bool uppercase /*= false*/) {
+std::string StringUtils::to_hex(std::span<const std::byte> data_to_be_transformed, bool uppercase /*= false*/) {
   if (data_to_be_transformed.size() > (std::numeric_limits<size_t>::max() / 2 - 1)) {
     throw std::length_error("Data is too large to be hexencoded");
   }
@@ -427,7 +419,7 @@ std::vector<std::byte> StringUtils::from_base64(const std::string_view base64) {
   return decoded;
 }
 
-size_t StringUtils::to_base64(char* base64, const gsl::span<const std::byte> raw_data, bool url, bool padded) {
+size_t StringUtils::to_base64(char* base64, const std::span<const std::byte> raw_data, bool url, bool padded) {
   gsl_Expects(base64);
   if (raw_data.size() > std::numeric_limits<size_t>::max() * 3 / 4 - 3) {
     throw std::length_error("Data is too large to be base64 encoded");
@@ -461,7 +453,7 @@ size_t StringUtils::to_base64(char* base64, const gsl::span<const std::byte> raw
   return base64_length;
 }
 
-std::string StringUtils::to_base64(const gsl::span<const std::byte> raw_data, bool url /*= false*/, bool padded /*= true*/) {
+std::string StringUtils::to_base64(const std::span<const std::byte> raw_data, bool url /*= false*/, bool padded /*= true*/) {
   std::string buf;
   buf.resize((raw_data.size() / 3 + 1) * 4);
   size_t base64_length = to_base64(buf.data(), raw_data, url, padded);
@@ -470,7 +462,7 @@ std::string StringUtils::to_base64(const gsl::span<const std::byte> raw_data, bo
   return buf;
 }
 
-std::string StringUtils::escapeUnprintableBytes(gsl::span<const std::byte> data) {
+std::string StringUtils::escapeUnprintableBytes(std::span<const std::byte> data) {
   constexpr const char* hex_digits = "0123456789abcdef";
   std::string result;
   for (auto byte : data) {
@@ -510,4 +502,40 @@ bool StringUtils::matchesSequence(std::string_view str, const std::vector<std::s
   return true;
 }
 
+bool StringUtils::splitToValueAndUnit(std::string_view input, int64_t& value, std::string& unit) {
+  const char* begin = input.data();
+  const char* end = begin + input.size();
+  auto [ptr, ec] = std::from_chars(begin, end, value);
+  if (ptr == begin || ec != std::errc()) {
+    return false;
+  }
+
+  while (ptr != end && *ptr == ' ') {
+    // Skip the spaces
+    ptr++;
+  }
+  unit = std::string(ptr, end);
+  return true;
+}
+
+nonstd::expected<std::optional<char>, StringUtils::ParseError> StringUtils::parseCharacter(const std::string &input) {
+  if (input.empty()) { return std::nullopt; }
+  if (input.size() == 1) { return input[0]; }
+
+  if (input.size() == 2 && input.starts_with('\\')) {
+    switch (input[1]) {
+      case '0': return '\0';  // Null
+      case 'a': return '\a';  // Bell
+      case 'b': return '\b';  // Backspace
+      case 't': return '\t';  // Horizontal Tab
+      case 'n': return '\n';  // Line Feed
+      case 'v': return '\v';  // Vertical Tab
+      case 'f': return '\f';  // Form Feed
+      case 'r': return '\r';  // Carriage Return
+      default: return input[1];
+    }
+  }
+  return nonstd::make_unexpected(ParseError{});
+}
+
 }  // namespace org::apache::nifi::minifi::utils
