@@ -50,7 +50,7 @@ bool contains(const std::filesystem::path& file_path, std::string_view text_to_s
   gsl_Expects(text_to_search.size() <= 8_KiB);
   gsl_ExpectsAudit(std::filesystem::exists(file_path));
   std::array<char, 16_KiB> buf{};
-  gsl::span<char> view;
+  std::span<char> view;
 
   Searcher searcher(text_to_search.begin(), text_to_search.end());
 
@@ -58,7 +58,7 @@ bool contains(const std::filesystem::path& file_path, std::string_view text_to_s
   do {
     std::copy(buf.end() - text_to_search.size(), buf.end(), buf.begin());
     ifs.read(buf.data() + text_to_search.size(), buf.size() - text_to_search.size());
-    view = gsl::span<char>(buf.data(), text_to_search.size() + gsl::narrow<size_t>(ifs.gcount()));
+    view = std::span<char>(buf.data(), text_to_search.size() + gsl::narrow<size_t>(ifs.gcount()));
     if (std::search(view.begin(), view.end(), searcher) != view.end()) {
       return true;
     }
@@ -66,21 +66,33 @@ bool contains(const std::filesystem::path& file_path, std::string_view text_to_s
   return std::search(view.begin(), view.end(), searcher) != view.end();
 }
 
-time_t to_time_t(std::filesystem::file_time_type file_time) {
-#if defined(_LIBCPP_VERSION) && _LIBCPP_VERSION < 14000
-  return std::chrono::file_clock::to_time_t(file_time);
+std::chrono::system_clock::time_point to_sys(std::filesystem::file_time_type file_time) {
+  using namespace std::chrono;  // NOLINT(build/namespaces)
+#if defined(WIN32)
+  // workaround for https://github.com/microsoft/STL/issues/2446
+  // clock_cast can fail on older windows versions
+  constexpr file_clock::duration clock_epoch_diff{std::filesystem::__std_fs_file_time_epoch_adjustment};
+  return system_clock::time_point(file_time.time_since_epoch() - clock_epoch_diff);
+#elif(defined(_LIBCPP_VERSION) && (_LIBCPP_VERSION < 14000))
+  // relies on file_clock and system_clock having the same epoch
+  return system_clock::time_point(duration_cast<system_clock::duration>(file_time.time_since_epoch()));
 #else
-  return std::chrono::system_clock::to_time_t(to_sys(file_time));
+  return time_point_cast<system_clock::duration>(file_clock::to_sys(file_time));
 #endif
 }
 
-std::chrono::time_point<std::chrono::system_clock> to_sys(std::filesystem::file_time_type file_time) {
-#if defined(WIN32) || defined(_LIBCPP_VERSION) && _LIBCPP_VERSION >= 14000
-  return std::chrono::time_point_cast<std::chrono::system_clock::duration>(file_time - std::filesystem::file_time_type::clock::now() + std::chrono::system_clock::now());
-#elif defined(_LIBCPP_VERSION)
-  return std::chrono::system_clock::from_time_t(std::chrono::file_clock::to_time_t(file_time));
+std::filesystem::file_time_type from_sys(std::chrono::system_clock::time_point sys_time) {
+  using namespace std::chrono;  // NOLINT(build/namespaces)
+#if defined(WIN32)
+  // workaround for https://github.com/microsoft/STL/issues/2446
+  // clock_cast can fail on older windows versions
+  constexpr file_clock::duration clock_epoch_diff{std::filesystem::__std_fs_file_time_epoch_adjustment};
+  return file_clock::time_point(sys_time.time_since_epoch() + clock_epoch_diff);
+#elif(defined(_LIBCPP_VERSION) && (_LIBCPP_VERSION < 14000))
+  // relies on file_clock and system_clock having the same epoch
+  return file_clock::time_point(duration_cast<file_clock::duration>(sys_time.time_since_epoch()));
 #else
-  return std::chrono::file_clock::to_sys(file_time);
+  return time_point_cast<file_clock::duration>(file_clock::from_sys(sys_time));
 #endif
 }
 
