@@ -26,6 +26,7 @@
 
 #include "core/Processor.h"
 #include "core/ProcessContextBuilder.h"
+#include "core/PropertyDefinition.h"
 #include "core/logging/LoggerConfiguration.h"
 #include "core/state/nodes/FlowInformation.h"
 #include "core/controller/StandardControllerServiceProvider.h"
@@ -35,6 +36,7 @@
 #include "core/extension/ExtensionManager.h"
 #include "utils/Id.h"
 #include "utils/StringUtils.h"
+#include "utils/span.h"
 #include "LogUtils.h"
 
 #include "spdlog/spdlog.h"
@@ -50,16 +52,15 @@ std::shared_ptr<LogTestController> LogTestController::getInstance(const std::sha
   } else {
     // in practice I'd use a derivation here or another paradigm entirely but for the purposes of this test code
     // having extra overhead is negligible. this is the most readable and least impactful way
-    auto instance = std::shared_ptr<LogTestController>(new LogTestController(logger_properties));
-    map.insert(std::make_pair(logger_properties, instance));
+    map.insert(std::make_pair(logger_properties, std::shared_ptr<LogTestController>(new LogTestController(logger_properties))));
     return map.find(logger_properties)->second;
   }
 }
 
-void LogTestController::setLevel(const std::string& name, spdlog::level::level_enum level) {
+void LogTestController::setLevel(std::string_view name, spdlog::level::level_enum level) {
   const auto levelView(spdlog::level::to_string_view(level));
-  logger_->log_info("Setting log level for %s to %s", name, std::string(levelView.begin(), levelView.end()));
-  std::string adjusted_name = name;
+  logger_->log_info("Setting log level for %s to %s", std::string(name), std::string(levelView.begin(), levelView.end()));
+  std::string adjusted_name{name};
   const std::string clazz = "class ";
   auto haz_clazz = name.find(clazz);
   if (haz_clazz == 0)
@@ -70,22 +71,22 @@ void LogTestController::setLevel(const std::string& name, spdlog::level::level_e
   logging::LoggerConfiguration::getSpdlogLogger(adjusted_name)->set_level(level);
 }
 
-std::shared_ptr<logging::Logger> LogTestController::getLoggerByClassName(const std::string& class_name, const std::optional<utils::Identifier>& id) {
+std::shared_ptr<logging::Logger> LogTestController::getLoggerByClassName(std::string_view class_name, const std::optional<utils::Identifier>& id) {
   return config ? config->getLogger(class_name, id) : logging::LoggerConfiguration::getConfiguration().getLogger(class_name, id);
 }
 
-void LogTestController::setLevelByClassName(spdlog::level::level_enum level, const std::string& class_name) {
+void LogTestController::setLevelByClassName(spdlog::level::level_enum level, std::string_view class_name) {
   if (config)
     config->getLogger(class_name);
   else
     logging::LoggerConfiguration::getConfiguration().getLogger(class_name);
-  modified_loggers.push_back(class_name);
+  modified_loggers.emplace_back(class_name);
   setLevel(class_name, level);
   // also support shortened classnames
   if (config && config->shortenClassNames()) {
-    std::string adjusted = class_name;
+    std::string adjusted{class_name};
     if (minifi::utils::ClassUtils::shortenClassName(class_name, adjusted)) {
-      modified_loggers.push_back(class_name);
+      modified_loggers.emplace_back(class_name);
       setLevel(class_name, level);
     }
   }
@@ -177,21 +178,21 @@ LogTestController::LogTestController(const std::shared_ptr<logging::LoggerProper
     initMain = true;
   }
   my_properties_->set("logger.root", "ERROR,ostream");
-  my_properties_->set("logger." + minifi::core::getClassName<LogTestController>(), "INFO");
-  my_properties_->set("logger." + minifi::core::getClassName<logging::LoggerConfiguration>(), "INFO");
+  my_properties_->set("logger." + std::string(minifi::core::className<LogTestController>()), "INFO");
+  my_properties_->set("logger." + std::string(minifi::core::className<logging::LoggerConfiguration>()), "INFO");
   std::shared_ptr<spdlog::sinks::dist_sink_mt> dist_sink = std::make_shared<spdlog::sinks::dist_sink_mt>();
   dist_sink->add_sink(std::make_shared<StringStreamSink>(log_output_ptr_, log_output_mutex_, true));
   dist_sink->add_sink(std::make_shared<spdlog::sinks::stderr_sink_mt>());
   my_properties_->add_sink("ostream", dist_sink);
   if (initMain) {
     logging::LoggerConfiguration::getConfiguration().initialize(my_properties_);
-    logger_ = logging::LoggerConfiguration::getConfiguration().getLogger(minifi::core::getClassName<LogTestController>());
+    logger_ = logging::LoggerConfiguration::getConfiguration().getLogger(minifi::core::className<LogTestController>());
   } else {
     config = logging::LoggerConfiguration::newInstance();
     // create for test purposes. most tests use the main logging factory, but this exists to test the logging
     // framework itself.
     config->initialize(my_properties_);
-    logger_ = config->getLogger(minifi::core::getClassName<LogTestController>());
+    logger_ = config->getLogger(minifi::core::className<LogTestController>());
   }
 }
 
@@ -206,7 +207,6 @@ TestPlan::TestPlan(std::shared_ptr<minifi::core::ContentRepository> content_repo
       current_flowfile_(nullptr),
       flow_version_(std::move(flow_version)),
       logger_(logging::LoggerFactory<TestPlan>::getLogger()) {
-  stream_factory = org::apache::nifi::minifi::io::StreamFactory::getInstance(std::make_shared<minifi::Configure>());
   controller_services_ = std::make_shared<minifi::core::controller::ControllerServiceMap>();
   controller_services_provider_ = std::make_shared<minifi::core::controller::StandardControllerServiceProvider>(controller_services_, configuration_);
   /* Inject the default state storage ahead of ProcessContext to make sure we have a unique state directory */
@@ -239,7 +239,6 @@ std::shared_ptr<minifi::core::Processor> TestPlan::addProcessor(const std::share
     return nullptr;
   }
   std::lock_guard<std::recursive_mutex> guard(mutex);
-  processor->setStreamFactory(stream_factory);
   // initialize the processor
   processor->initialize();
   processor->setFlowIdentifier(flow_version_->getFlowIdentifier());
@@ -368,12 +367,13 @@ std::shared_ptr<minifi::core::controller::ControllerServiceNode> TestPlan::addCo
   return controller_service_node;
 }
 
-bool TestPlan::setProperty(const std::shared_ptr<minifi::core::Processor>& proc, const std::string &prop, const std::string &value, bool dynamic) {
+bool TestPlan::setProperty(const std::shared_ptr<minifi::core::Processor>& processor, const std::string& property, const std::string& value, bool dynamic) {
   std::lock_guard<std::recursive_mutex> guard(mutex);
+
   size_t i = 0;
-  logger_->log_info("Attempting to set property %s %s for %s", prop, value, proc->getName());
+  logger_->log_info("Attempting to set property %s to %s for %s", property, value, processor->getName());
   for (i = 0; i < processor_queue_.size(); i++) {
-    if (processor_queue_.at(i) == proc) {
+    if (processor_queue_.at(i) == processor) {
       break;
     }
   }
@@ -383,22 +383,46 @@ bool TestPlan::setProperty(const std::shared_ptr<minifi::core::Processor>& proc,
   }
 
   if (dynamic) {
-    return processor_contexts_.at(i)->setDynamicProperty(prop, value);
+    return processor_contexts_.at(i)->setDynamicProperty(property, value);
   } else {
-    return processor_contexts_.at(i)->setProperty(prop, value);
+    return processor_contexts_.at(i)->setProperty(property, value);
   }
 }
 
-bool TestPlan::setProperty(const std::shared_ptr<minifi::core::controller::ControllerServiceNode>& controller_service_node, const std::string &prop, const std::string &value, bool dynamic /*= false*/) {
+bool TestPlan::setProperty(const std::shared_ptr<minifi::core::Processor>& processor, const core::PropertyReference& property, std::string_view value) {
+  return setProperty(processor, std::string(property.name), std::string(value), false);
+}
+
+bool TestPlan::setProperty(const std::shared_ptr<minifi::core::Processor>& processor, std::string_view property, std::string_view value) {
+  return setProperty(processor, std::string(property), std::string(value), false);
+}
+
+bool TestPlan::setDynamicProperty(const std::shared_ptr<minifi::core::Processor>& processor, std::string_view property, std::string_view value) {
+  return setProperty(processor, std::string(property), std::string(value), true);
+}
+
+bool TestPlan::setProperty(const std::shared_ptr<minifi::core::controller::ControllerServiceNode>& controller_service_node, const std::string& property, const std::string& value, bool dynamic) {
   if (dynamic) {
-    controller_service_node->setDynamicProperty(prop, value);
-    return controller_service_node->getControllerServiceImplementation()->setDynamicProperty(prop, value);
+    controller_service_node->setDynamicProperty(property, value);
+    return controller_service_node->getControllerServiceImplementation()->setDynamicProperty(property, value);
   } else {
-    controller_service_node->setProperty(prop, value);
-    return controller_service_node->getControllerServiceImplementation()->setProperty(prop, value);
+    controller_service_node->setProperty(property, value);
+    return controller_service_node->getControllerServiceImplementation()->setProperty(property, value);
   }
 }
 
+bool TestPlan::setProperty(const std::shared_ptr<minifi::core::controller::ControllerServiceNode>& controller_service_node, const core::PropertyReference& property, std::string_view value) {
+  return setProperty(controller_service_node, std::string(property.name), std::string(value), false);
+}
+
+bool TestPlan::setProperty(const std::shared_ptr<minifi::core::controller::ControllerServiceNode>& controller_service_node, std::string_view property, std::string_view value) {
+  return setProperty(controller_service_node, std::string(property), std::string(value), false);
+}
+
+bool TestPlan::setDynamicProperty(const std::shared_ptr<minifi::core::controller::ControllerServiceNode>& controller_service_node, std::string_view property, std::string_view value) {
+  return setProperty(controller_service_node, std::string(property), std::string(value), true);
+}
+
 void TestPlan::reset(bool reschedule) {
   std::lock_guard<std::recursive_mutex> guard(mutex);
   process_sessions_.clear();
@@ -515,7 +539,7 @@ bool TestPlan::runNextProcessor(const PreTriggerVerifier& verify) {
   return runProcessor(location, verify);
 }
 
-bool TestPlan::runCurrentProcessor(const PreTriggerVerifier& /*verify*/) {
+bool TestPlan::runCurrentProcessor() {
   std::lock_guard<std::recursive_mutex> guard(mutex);
   return runProcessor(location);
 }
@@ -645,7 +669,7 @@ std::string TestPlan::getContent(const minifi::core::FlowFile& file) const {
   auto content_stream = content_repo_->read(*content_claim);
   auto output_stream = std::make_shared<minifi::io::BufferStream>();
   minifi::InputStreamPipe{*output_stream}(content_stream);
-  return utils::span_to<std::string>(output_stream->getBuffer().as_span<const char>());
+  return utils::span_to<std::string>(utils::as_span<const char>(output_stream->getBuffer()));
 }
 
 TestController::TestController()
