@@ -25,6 +25,7 @@
 #include <random>
 #include <sstream>
 #include <iostream>
+
 #include "FlowController.h"
 #include "../TestBase.h"
 #include "../Catch.h"
@@ -39,6 +40,7 @@
 #include "io/FileStream.h"
 #include "FlowFileRecord.h"
 #include "processors/LogAttribute.h"
+#include "processors/GetFile.h"
 #include "processors/PutFile.h"
 #include "utils/file/FileUtils.h"
 #include "../Utils.h"
@@ -57,7 +59,7 @@ class ReadCallback {
   int64_t operator()(const std::shared_ptr<minifi::io::InputStream>& stream) {
     int64_t total_read = 0;
     do {
-      const auto ret = stream->read(gsl::make_span(buffer_).subspan(read_size_));
+      const auto ret = stream->read(std::span(buffer_).subspan(read_size_));
       if (ret == 0) break;
       if (minifi::io::isError(ret)) return -1;
       read_size_ += gsl::narrow<size_t>(ret);
@@ -267,12 +269,12 @@ class DecompressTestController : public CompressDecompressionTestController{
   }
 };
 
-using CompressionFormat = minifi::processors::CompressContent::ExtendedCompressionFormat;
-using CompressionMode = minifi::processors::CompressContent::CompressionMode;
+using CompressionFormat = minifi::processors::compress_content::ExtendedCompressionFormat;
+using CompressionMode = minifi::processors::compress_content::CompressionMode;
 
 TEST_CASE_METHOD(CompressTestController, "CompressFileGZip", "[compressfiletest1]") {
-  context->setProperty(minifi::processors::CompressContent::CompressMode, toString(CompressionMode::Compress));
-  context->setProperty(minifi::processors::CompressContent::CompressFormat, toString(CompressionFormat::GZIP));
+  context->setProperty(minifi::processors::CompressContent::CompressMode, magic_enum::enum_name(CompressionMode::compress));
+  context->setProperty(minifi::processors::CompressContent::CompressFormat, magic_enum::enum_name(CompressionFormat::GZIP));
   context->setProperty(minifi::processors::CompressContent::CompressLevel, "9");
   context->setProperty(minifi::processors::CompressContent::UpdateFileName, "true");
 
@@ -303,8 +305,8 @@ TEST_CASE_METHOD(CompressTestController, "CompressFileGZip", "[compressfiletest1
 }
 
 TEST_CASE_METHOD(DecompressTestController, "DecompressFileGZip", "[compressfiletest2]") {
-  context->setProperty(minifi::processors::CompressContent::CompressMode, toString(CompressionMode::Decompress));
-  context->setProperty(minifi::processors::CompressContent::CompressFormat, toString(CompressionFormat::GZIP));
+  context->setProperty(minifi::processors::CompressContent::CompressMode, magic_enum::enum_name(CompressionMode::decompress));
+  context->setProperty(minifi::processors::CompressContent::CompressFormat, magic_enum::enum_name(CompressionFormat::GZIP));
   context->setProperty(minifi::processors::CompressContent::CompressLevel, "9");
   context->setProperty(minifi::processors::CompressContent::UpdateFileName, "true");
 
@@ -331,8 +333,8 @@ TEST_CASE_METHOD(DecompressTestController, "DecompressFileGZip", "[compressfilet
 }
 
 TEST_CASE_METHOD(CompressTestController, "CompressFileBZip", "[compressfiletest3]") {
-  context->setProperty(minifi::processors::CompressContent::CompressMode, toString(CompressionMode::Compress));
-  context->setProperty(minifi::processors::CompressContent::CompressFormat, toString(CompressionFormat::BZIP2));
+  context->setProperty(minifi::processors::CompressContent::CompressMode, magic_enum::enum_name(CompressionMode::compress));
+  context->setProperty(minifi::processors::CompressContent::CompressFormat, magic_enum::enum_name(CompressionFormat::BZIP2));
   context->setProperty(minifi::processors::CompressContent::CompressLevel, "9");
   context->setProperty(minifi::processors::CompressContent::UpdateFileName, "true");
 
@@ -360,8 +362,8 @@ TEST_CASE_METHOD(CompressTestController, "CompressFileBZip", "[compressfiletest3
 
 
 TEST_CASE_METHOD(DecompressTestController, "DecompressFileBZip", "[compressfiletest4]") {
-  context->setProperty(minifi::processors::CompressContent::CompressMode, toString(CompressionMode::Decompress));
-  context->setProperty(minifi::processors::CompressContent::CompressFormat, toString(CompressionFormat::BZIP2));
+  context->setProperty(minifi::processors::CompressContent::CompressMode, magic_enum::enum_name(CompressionMode::decompress));
+  context->setProperty(minifi::processors::CompressContent::CompressFormat, magic_enum::enum_name(CompressionFormat::BZIP2));
   context->setProperty(minifi::processors::CompressContent::CompressLevel, "9");
   context->setProperty(minifi::processors::CompressContent::UpdateFileName, "true");
 
@@ -385,8 +387,8 @@ TEST_CASE_METHOD(DecompressTestController, "DecompressFileBZip", "[compressfilet
 }
 
 TEST_CASE_METHOD(CompressTestController, "CompressFileLZMA", "[compressfiletest5]") {
-  context->setProperty(minifi::processors::CompressContent::CompressMode, toString(CompressionMode::Compress));
-  context->setProperty(minifi::processors::CompressContent::CompressFormat, toString(CompressionFormat::LZMA));
+  context->setProperty(minifi::processors::CompressContent::CompressMode, magic_enum::enum_name(CompressionMode::compress));
+  context->setProperty(minifi::processors::CompressContent::CompressFormat, magic_enum::enum_name(CompressionFormat::LZMA));
   context->setProperty(minifi::processors::CompressContent::CompressLevel, "9");
   context->setProperty(minifi::processors::CompressContent::UpdateFileName, "true");
 
@@ -420,8 +422,8 @@ TEST_CASE_METHOD(CompressTestController, "CompressFileLZMA", "[compressfiletest5
 
 
 TEST_CASE_METHOD(DecompressTestController, "DecompressFileLZMA", "[compressfiletest6]") {
-  context->setProperty(minifi::processors::CompressContent::CompressMode, toString(CompressionMode::Decompress));
-  context->setProperty(minifi::processors::CompressContent::CompressFormat, toString(CompressionFormat::USE_MIME_TYPE));
+  context->setProperty(minifi::processors::CompressContent::CompressMode, magic_enum::enum_name(CompressionMode::decompress));
+  context->setProperty(minifi::processors::CompressContent::CompressFormat, magic_enum::enum_name(CompressionFormat::USE_MIME_TYPE));
   context->setProperty(minifi::processors::CompressContent::CompressLevel, "9");
   context->setProperty(minifi::processors::CompressContent::UpdateFileName, "true");
 
@@ -451,8 +453,8 @@ TEST_CASE_METHOD(DecompressTestController, "DecompressFileLZMA", "[compressfilet
 }
 
 TEST_CASE_METHOD(CompressTestController, "CompressFileXYLZMA", "[compressfiletest7]") {
-  context->setProperty(minifi::processors::CompressContent::CompressMode, toString(CompressionMode::Compress));
-  context->setProperty(minifi::processors::CompressContent::CompressFormat, toString(CompressionFormat::XZ_LZMA2));
+  context->setProperty(minifi::processors::CompressContent::CompressMode, magic_enum::enum_name(CompressionMode::compress));
+  context->setProperty(minifi::processors::CompressContent::CompressFormat, magic_enum::enum_name(CompressionFormat::XZ_LZMA2));
   context->setProperty(minifi::processors::CompressContent::CompressLevel, "9");
   context->setProperty(minifi::processors::CompressContent::UpdateFileName, "true");
 
@@ -486,8 +488,8 @@ TEST_CASE_METHOD(CompressTestController, "CompressFileXYLZMA", "[compressfiletes
 
 
 TEST_CASE_METHOD(DecompressTestController, "DecompressFileXYLZMA", "[compressfiletest8]") {
-  context->setProperty(minifi::processors::CompressContent::CompressMode, toString(CompressionMode::Decompress));
-  context->setProperty(minifi::processors::CompressContent::CompressFormat, toString(CompressionFormat::USE_MIME_TYPE));
+  context->setProperty(minifi::processors::CompressContent::CompressMode, magic_enum::enum_name(CompressionMode::decompress));
+  context->setProperty(minifi::processors::CompressContent::CompressFormat, magic_enum::enum_name(CompressionFormat::USE_MIME_TYPE));
   context->setProperty(minifi::processors::CompressContent::CompressLevel, "9");
   context->setProperty(minifi::processors::CompressContent::UpdateFileName, "true");
 
@@ -559,25 +561,25 @@ TEST_CASE_METHOD(TestController, "RawGzipCompressionDecompression", "[compressfi
       true);
 
   // Configure GetFile processor
-  plan->setProperty(get_file, "Input Directory", src_dir.string());
+  plan->setProperty(get_file, minifi::processors::GetFile::Directory, src_dir.string());
 
   // Configure CompressContent processor for compression
-  plan->setProperty(compress_content, "Mode", toString(CompressionMode::Compress));
-  plan->setProperty(compress_content, "Compression Format", toString(CompressionFormat::GZIP));
-  plan->setProperty(compress_content, "Update Filename", "true");
-  plan->setProperty(compress_content, "Encapsulate in TAR", "false");
+  plan->setProperty(compress_content, minifi::processors::CompressContent::CompressMode, magic_enum::enum_name(CompressionMode::compress));
+  plan->setProperty(compress_content, minifi::processors::CompressContent::CompressFormat, magic_enum::enum_name(CompressionFormat::GZIP));
+  plan->setProperty(compress_content, minifi::processors::CompressContent::UpdateFileName, "true");
+  plan->setProperty(compress_content, minifi::processors::CompressContent::EncapsulateInTar, "false");
 
   // Configure first PutFile processor
-  plan->setProperty(put_compressed, "Directory", dst_dir.string());
+  plan->setProperty(put_compressed, minifi::processors::PutFile::Directory, dst_dir.string());
 
   // Configure CompressContent processor for decompression
-  plan->setProperty(decompress_content, "Mode", toString(CompressionMode::Decompress));
-  plan->setProperty(decompress_content, "Compression Format", toString(CompressionFormat::GZIP));
-  plan->setProperty(decompress_content, "Update Filename", "true");
-  plan->setProperty(decompress_content, "Encapsulate in TAR", "false");
+  plan->setProperty(decompress_content, minifi::processors::CompressContent::CompressMode, magic_enum::enum_name(CompressionMode::decompress));
+  plan->setProperty(decompress_content, minifi::processors::CompressContent::CompressFormat, magic_enum::enum_name(CompressionFormat::GZIP));
+  plan->setProperty(decompress_content, minifi::processors::CompressContent::UpdateFileName, "true");
+  plan->setProperty(decompress_content, minifi::processors::CompressContent::EncapsulateInTar, "false");
 
   // Configure second PutFile processor
-  plan->setProperty(put_decompressed, "Directory", dst_dir.string());
+  plan->setProperty(put_decompressed, minifi::processors::PutFile::Directory, dst_dir.string());
 
   // Create source file
   std::string content;
@@ -624,8 +626,8 @@ TEST_CASE_METHOD(CompressTestController, "Batch CompressFileGZip", "[compressFil
   };
   const std::size_t batchSize = 3;
 
-  context->setProperty(minifi::processors::CompressContent::CompressMode, toString(CompressionMode::Compress));
-  context->setProperty(minifi::processors::CompressContent::CompressFormat, toString(CompressionFormat::GZIP));
+  context->setProperty(minifi::processors::CompressContent::CompressMode, magic_enum::enum_name(CompressionMode::compress));
+  context->setProperty(minifi::processors::CompressContent::CompressFormat, magic_enum::enum_name(CompressionFormat::GZIP));
   context->setProperty(minifi::processors::CompressContent::CompressLevel, "9");
   context->setProperty(minifi::processors::CompressContent::UpdateFileName, "true");
   context->setProperty(minifi::processors::CompressContent::BatchSize, std::to_string(batchSize));
@@ -679,18 +681,18 @@ TEST_CASE_METHOD(CompressTestController, "Batch CompressFileGZip", "[compressFil
 }
 
 TEST_CASE_METHOD(DecompressTestController, "Invalid archive decompression", "[compressfiletest9]") {
-  context->setProperty(minifi::processors::CompressContent::CompressMode, toString(CompressionMode::Decompress));
+  context->setProperty(minifi::processors::CompressContent::CompressMode, magic_enum::enum_name(CompressionMode::decompress));
   SECTION("GZIP") {
-    context->setProperty(minifi::processors::CompressContent::CompressFormat, toString(CompressionFormat::GZIP));
+    context->setProperty(minifi::processors::CompressContent::CompressFormat, magic_enum::enum_name(CompressionFormat::GZIP));
   }
   SECTION("LZMA") {
-    context->setProperty(minifi::processors::CompressContent::CompressFormat, toString(CompressionFormat::LZMA));
+    context->setProperty(minifi::processors::CompressContent::CompressFormat, magic_enum::enum_name(CompressionFormat::LZMA));
   }
   SECTION("XZ_LZMA2") {
-    context->setProperty(minifi::processors::CompressContent::CompressFormat, toString(CompressionFormat::XZ_LZMA2));
+    context->setProperty(minifi::processors::CompressContent::CompressFormat, magic_enum::enum_name(CompressionFormat::XZ_LZMA2));
   }
   SECTION("BZIP2") {
-    context->setProperty(minifi::processors::CompressContent::CompressFormat, toString(CompressionFormat::BZIP2));
+    context->setProperty(minifi::processors::CompressContent::CompressFormat, magic_enum::enum_name(CompressionFormat::BZIP2));
   }
   context->setProperty(minifi::processors::CompressContent::CompressLevel, "9");
   context->setProperty(minifi::processors::CompressContent::UpdateFileName, "true");
