@@ -29,13 +29,21 @@
 #include "../unit/ProvenanceTestHelper.h"
 #include "../unit/ContentRepositoryDependentTests.h"
 
+class TestDatabaseContentRepository : public core::repository::DatabaseContentRepository {
+ public:
+  void invalidate() {
+    stop();
+    db_.reset();
+  }
+};
+
 TEST_CASE("Write Claim", "[TestDBCR1]") {
   TestController testController;
   auto dir = testController.createTempDirectory();
-  auto content_repo = std::make_shared<core::repository::DatabaseContentRepository>();
+  auto content_repo = std::make_shared<TestDatabaseContentRepository>();
 
   auto configuration = std::make_shared<org::apache::nifi::minifi::Configure>();
-  configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, dir);
+  configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, dir.string());
   REQUIRE(content_repo->initialize(configuration));
 
 
@@ -46,14 +54,14 @@ TEST_CASE("Write Claim", "[TestDBCR1]") {
 
   stream->close();
 
-  content_repo->stop();
+  content_repo->invalidate();
   // reclaim the memory
   content_repo = nullptr;
 
-  content_repo = std::make_shared<core::repository::DatabaseContentRepository>();
+  content_repo = std::make_shared<TestDatabaseContentRepository>();
 
   configuration = std::make_shared<org::apache::nifi::minifi::Configure>();
-  configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, dir);
+  configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, dir.string());
   REQUIRE(content_repo->initialize(configuration));
 
   auto read_stream = content_repo->read(*claim);
@@ -72,10 +80,10 @@ TEST_CASE("Write Claim", "[TestDBCR1]") {
 TEST_CASE("Delete Claim", "[TestDBCR2]") {
   TestController testController;
   auto dir = testController.createTempDirectory();
-  auto content_repo = std::make_shared<core::repository::DatabaseContentRepository>();
+  auto content_repo = std::make_shared<TestDatabaseContentRepository>();
 
   auto configuration = std::make_shared<org::apache::nifi::minifi::Configure>();
-  configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, dir);
+  configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, dir.string());
   REQUIRE(content_repo->initialize(configuration));
 
 
@@ -86,15 +94,15 @@ TEST_CASE("Delete Claim", "[TestDBCR2]") {
 
   stream->close();
 
-  content_repo->stop();
+  content_repo->invalidate();
 
   // reclaim the memory
   content_repo = nullptr;
 
-  content_repo = std::make_shared<core::repository::DatabaseContentRepository>();
+  content_repo = std::make_shared<TestDatabaseContentRepository>();
 
   configuration = std::make_shared<org::apache::nifi::minifi::Configure>();
-  configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, dir);
+  configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, dir.string());
   REQUIRE(content_repo->initialize(configuration));
 
   content_repo->remove(*claim);
@@ -110,10 +118,10 @@ TEST_CASE("Delete Claim", "[TestDBCR2]") {
 TEST_CASE("Test Empty Claim", "[TestDBCR3]") {
   TestController testController;
   auto dir = testController.createTempDirectory();
-  auto content_repo = std::make_shared<core::repository::DatabaseContentRepository>();
+  auto content_repo = std::make_shared<TestDatabaseContentRepository>();
 
   auto configuration = std::make_shared<org::apache::nifi::minifi::Configure>();
-  configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, dir);
+  configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, dir.string());
   REQUIRE(content_repo->initialize(configuration));
 
   auto claim = std::make_shared<minifi::ResourceClaim>(content_repo);
@@ -123,15 +131,15 @@ TEST_CASE("Test Empty Claim", "[TestDBCR3]") {
 
   stream->close();
 
-  content_repo->stop();
+  content_repo->invalidate();
 
   // reclaim the memory
   content_repo = nullptr;
 
-  content_repo = std::make_shared<core::repository::DatabaseContentRepository>();
+  content_repo = std::make_shared<TestDatabaseContentRepository>();
 
   configuration = std::make_shared<org::apache::nifi::minifi::Configure>();
-  configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, dir);
+  configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, dir.string());
   REQUIRE(content_repo->initialize(configuration));
 
   auto read_stream = content_repo->read(*claim);
@@ -145,10 +153,10 @@ TEST_CASE("Test Empty Claim", "[TestDBCR3]") {
 TEST_CASE("Delete NonExistent Claim", "[TestDBCR4]") {
   TestController testController;
   auto dir = testController.createTempDirectory();
-  auto content_repo = std::make_shared<core::repository::DatabaseContentRepository>();
+  auto content_repo = std::make_shared<TestDatabaseContentRepository>();
 
   auto configuration = std::make_shared<org::apache::nifi::minifi::Configure>();
-  configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, dir);
+  configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, dir.string());
   REQUIRE(content_repo->initialize(configuration));
 
   auto claim = std::make_shared<minifi::ResourceClaim>(content_repo);
@@ -159,15 +167,15 @@ TEST_CASE("Delete NonExistent Claim", "[TestDBCR4]") {
 
   stream->close();
 
-  content_repo->stop();
+  content_repo->invalidate();
 
   // reclaim the memory
   content_repo = nullptr;
 
-  content_repo = std::make_shared<core::repository::DatabaseContentRepository>();
+  content_repo = std::make_shared<TestDatabaseContentRepository>();
 
   configuration = std::make_shared<org::apache::nifi::minifi::Configure>();
-  configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, dir);
+  configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, dir.string());
   REQUIRE(content_repo->initialize(configuration));
 
   // we won't complain if it does not exist
@@ -185,10 +193,10 @@ TEST_CASE("Delete NonExistent Claim", "[TestDBCR4]") {
 TEST_CASE("Delete Remove Count Claim", "[TestDBCR5]") {
   TestController testController;
   auto dir = testController.createTempDirectory();
-  auto content_repo = std::make_shared<core::repository::DatabaseContentRepository>();
+  auto content_repo = std::make_shared<TestDatabaseContentRepository>();
 
   auto configuration = std::make_shared<org::apache::nifi::minifi::Configure>();
-  configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, dir);
+  configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, dir.string());
   REQUIRE(content_repo->initialize(configuration));
 
   auto claim = std::make_shared<minifi::ResourceClaim>(content_repo);
@@ -199,15 +207,15 @@ TEST_CASE("Delete Remove Count Claim", "[TestDBCR5]") {
 
   stream->close();
 
-  content_repo->stop();
+  content_repo->invalidate();
 
   // reclaim the memory
   content_repo = nullptr;
 
-  content_repo = std::make_shared<core::repository::DatabaseContentRepository>();
+  content_repo = std::make_shared<TestDatabaseContentRepository>();
 
   configuration = std::make_shared<org::apache::nifi::minifi::Configure>();
-  configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, dir);
+  configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, dir.string());
   REQUIRE(content_repo->initialize(configuration));
 
   // increment twice. verify we have 2 for the stream count
@@ -242,3 +250,42 @@ TEST_CASE("ProcessSession::append should append to the flowfile and set its size
 TEST_CASE("ProcessSession::read can read zero length flowfiles without crash (RocksDB)", "[zerolengthread]") {
   ContentRepositoryDependentTests::testReadFromZeroLengthFlowFile(std::make_shared<core::repository::DatabaseContentRepository>());
 }
+
+size_t getDbSize(const std::filesystem::path& dir) {
+  auto db = minifi::internal::RocksDatabase::create({}, {}, dir.string());
+  auto opendb = db->open();
+  REQUIRE(opendb);
+
+  size_t count = 0;
+  auto it = opendb->NewIterator({});
+  for (it->SeekToFirst(); it->Valid(); it->Next()) {
+    ++count;
+  }
+  return count;
+}
+
+TEST_CASE("DBContentRepository can clear orphan entries") {
+  TestController testController;
+  auto dir = testController.createTempDirectory();
+  auto configuration = std::make_shared<org::apache::nifi::minifi::Configure>();
+  configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, dir.string());
+  {
+    auto content_repo = std::make_shared<core::repository::DatabaseContentRepository>();
+    REQUIRE(content_repo->initialize(configuration));
+
+    minifi::ResourceClaim claim(content_repo);
+    content_repo->write(claim)->write("hi");
+    // ensure that the content is not deleted during resource claim destruction
+    content_repo->incrementStreamCount(claim);
+  }
+
+  REQUIRE(getDbSize(dir) == 1);
+
+  {
+    auto content_repo = std::make_shared<core::repository::DatabaseContentRepository>();
+    REQUIRE(content_repo->initialize(configuration));
+    content_repo->clearOrphans();
+  }
+
+  REQUIRE(getDbSize(dir) == 0);
+}
