@@ -21,7 +21,7 @@
 #include <string>
 #include <vector>
 
-#include <catch.hpp>
+#include "catch2/catch_test_macros.hpp"
 #include "core/Processor.h"
 #include "core/ProcessSession.h"
 #include "core/Resource.h"
