@@ -16,9 +16,9 @@
  * limitations under the License.
  */
 
+#include <iostream>
 #include <cstdlib>
 #include <fstream>
-#include <iostream>
 #include <string>
 #include <thread>
 #include <vector>
@@ -27,9 +27,7 @@
 #include "../Catch.h"
 #include "core/Core.h"
 #include "utils/file/FileUtils.h"
-#include "utils/file/PathUtils.h"
 #include "utils/gsl.h"
-#include "utils/Environment.h"
 #include "utils/TimeUtil.h"
 
 namespace FileUtils = org::apache::nifi::minifi::utils::file;
@@ -186,10 +184,9 @@ TEST_CASE("TestFileUtils::addFilesMatchingExtension", "[TestAddFilesMatchingExte
 
 TEST_CASE("FileUtils::last_write_time and last_write_time_point work", "[last_write_time][last_write_time_point]") {
   using namespace std::chrono;
-  namespace fs = std::filesystem;
 
-  fs::file_time_type time_before_write = file_clock::now();
-  time_point<file_clock, seconds> time_point_before_write = time_point_cast<seconds>(file_clock::now());
+  auto time_before_write = file_clock::now();
+  auto time_point_before_write = time_point_cast<seconds>(file_clock::now());
 
   TestController testController;
 
@@ -204,14 +201,14 @@ TEST_CASE("FileUtils::last_write_time and last_write_time_point work", "[last_wr
   test_file_stream << "foo\n";
   test_file_stream.flush();
 
-  fs::file_time_type time_after_first_write = file_clock::now();
-  time_point<file_clock, seconds> time_point_after_first_write = time_point_cast<seconds>(file_clock::now());
+  auto time_after_first_write = file_clock::now();
+  auto time_point_after_first_write = time_point_cast<seconds>(file_clock::now());
 
-  fs::file_time_type first_mtime = FileUtils::last_write_time(test_file).value();
+  auto first_mtime = FileUtils::last_write_time(test_file).value();
   REQUIRE(first_mtime >= time_before_write);
   REQUIRE(first_mtime <= time_after_first_write);
 
-  time_point<file_clock, seconds> first_mtime_time_point = FileUtils::last_write_time_point(test_file);
+  auto first_mtime_time_point = FileUtils::last_write_time_point(test_file);
   REQUIRE(first_mtime_time_point >= time_point_before_write);
   REQUIRE(first_mtime_time_point <= time_point_after_first_write);
 
@@ -219,15 +216,15 @@ TEST_CASE("FileUtils::last_write_time and last_write_time_point work", "[last_wr
   test_file_stream << "bar\n";
   test_file_stream.flush();
 
-  fs::file_time_type time_after_second_write = file_clock::now();
-  time_point<file_clock, seconds> time_point_after_second_write = time_point_cast<seconds>(file_clock::now());
+  auto time_after_second_write = file_clock::now();
+  auto time_point_after_second_write = time_point_cast<seconds>(file_clock::now());
 
-  fs::file_time_type second_mtime = FileUtils::last_write_time(test_file).value();
+  auto second_mtime = FileUtils::last_write_time(test_file).value();
   REQUIRE(second_mtime >= first_mtime);
   REQUIRE(second_mtime >= time_after_first_write);
   REQUIRE(second_mtime <= time_after_second_write);
 
-  time_point<file_clock, seconds> second_mtime_time_point = FileUtils::last_write_time_point(test_file);
+  auto second_mtime_time_point = FileUtils::last_write_time_point(test_file);
   REQUIRE(second_mtime_time_point >= first_mtime_time_point);
   REQUIRE(second_mtime_time_point >= time_point_after_first_write);
   REQUIRE(second_mtime_time_point <= time_point_after_second_write);
@@ -236,10 +233,10 @@ TEST_CASE("FileUtils::last_write_time and last_write_time_point work", "[last_wr
 
   // On Windows it would rarely occur that the last_write_time is off by 1 from the previous check
 #ifndef WIN32
-  fs::file_time_type third_mtime = FileUtils::last_write_time(test_file).value();
+  auto third_mtime = FileUtils::last_write_time(test_file).value();
   REQUIRE(third_mtime == second_mtime);
 
-  time_point<file_clock, seconds> third_mtime_time_point = FileUtils::last_write_time_point(test_file);
+  auto third_mtime_time_point = FileUtils::last_write_time_point(test_file);
   REQUIRE(third_mtime_time_point == second_mtime_time_point);
 #endif
 }
@@ -477,3 +474,81 @@ TEST_CASE("FileUtils::get_relative_path", "[TestGetRelativePath]") {
   REQUIRE(*FileUtils::get_relative_path(path, base_path / "") == std::filesystem::path("subdir") / "file.log");
   REQUIRE(*FileUtils::get_relative_path(base_path, base_path) == ".");
 }
+
+TEST_CASE("FileUtils::path_size", "[TestPathSize]") {
+  auto writeToFile = [](const std::filesystem::path& path) {
+    std::ofstream test_file_stream(path, std::ios::out | std::ios::binary);
+    test_file_stream << "foo\n";
+    test_file_stream.flush();
+  };
+
+  TestController test_controller;
+  REQUIRE(FileUtils::path_size({""}) == 0);
+  REQUIRE(FileUtils::path_size({"/random/non-existent/dir"}) == 0);
+
+  auto dir = test_controller.createTempDirectory();
+  REQUIRE(FileUtils::path_size(dir) == 0);
+
+  auto test_file = dir / "test_file.log";
+  writeToFile(test_file);
+
+  REQUIRE(FileUtils::path_size(test_file) == 4);
+  REQUIRE(FileUtils::path_size(dir) == 4);
+
+  auto subdir = dir / "subdir";
+  REQUIRE(utils::file::create_dir(subdir) == 0);
+
+  REQUIRE(FileUtils::path_size(dir) == 4);
+
+  auto subdir_test_file = subdir / "test_file2.log";
+  writeToFile(subdir_test_file);
+
+  REQUIRE(FileUtils::path_size(dir) == 8);
+
+  auto subsubdir = subdir / "subsubdir";
+  REQUIRE(utils::file::create_dir(subsubdir) == 0);
+
+  auto subsubdir_test_file = subsubdir / "test_file3.log";
+  writeToFile(subsubdir_test_file);
+
+  REQUIRE(FileUtils::path_size(dir) == 12);
+}
+
+TEST_CASE("file_clock to system_clock conversion tests") {
+  using namespace std::chrono;
+
+  static_assert(system_clock::period::num == file_clock::period::num);
+  constexpr auto lowest_den = std::min(file_clock::period::den, system_clock::period::den);
+  using LeastPreciseDurationType = duration<std::common_type_t<system_clock::duration::rep, file_clock::duration::rep>, std::ratio<system_clock::period::num, lowest_den>>;
+
+  {
+    system_clock::time_point system_now = system_clock::now();
+    file_clock::time_point converted_system_now = FileUtils::from_sys(system_now);
+    system_clock::time_point double_converted_system_now = FileUtils::to_sys(converted_system_now);
+
+    CHECK(time_point_cast<LeastPreciseDurationType>(system_now).time_since_epoch().count() == time_point_cast<LeastPreciseDurationType>(double_converted_system_now).time_since_epoch().count());
+  }
+
+  {
+    file_clock::time_point file_now = file_clock ::now();
+    system_clock::time_point converted_file_now = FileUtils::to_sys(file_now);
+    file_clock::time_point double_converted_file_now = FileUtils::from_sys(converted_file_now);
+
+    CHECK(time_point_cast<LeastPreciseDurationType>(file_now).time_since_epoch().count() == time_point_cast<LeastPreciseDurationType>(double_converted_file_now).time_since_epoch().count());
+  }
+
+  {
+    // t0 <= t1
+    auto sys_time_t0 = system_clock::now();
+    auto file_time_t1 = file_clock ::now();
+
+    auto file_time_from_t0 = FileUtils::from_sys(sys_time_t0);
+    auto sys_time_from_t1 = FileUtils::to_sys(file_time_t1);
+
+    CHECK(0ms <= sys_time_from_t1-sys_time_t0);
+    CHECK(sys_time_from_t1-sys_time_t0 < 10ms);
+
+    CHECK(0ms <= file_time_t1-file_time_from_t0);
+    CHECK(file_time_t1-file_time_from_t0 < 10ms);
+  }
+}
