@@ -58,7 +58,7 @@ TEST_CASE("TestStringUtils::split3", "[test split multiple delimiter]") {
 
 TEST_CASE("TestStringUtils::split4", "[test split classname]") {
   std::vector<std::string> expected = { "org", "apache", "nifi", "minifi", "utils", "StringUtils" };
-  REQUIRE(expected == StringUtils::split(org::apache::nifi::minifi::core::getClassName<org::apache::nifi::minifi::utils::StringUtils>(), "::"));
+  REQUIRE(expected == StringUtils::split(org::apache::nifi::minifi::core::className<org::apache::nifi::minifi::utils::StringUtils>(), "::"));
 }
 
 TEST_CASE("TestStringUtils::split5", "[test split with delimiter set to empty string]") {
@@ -369,34 +369,24 @@ TEST_CASE("TestStringUtils::testBase64Encode", "[test base64 encode]") {
   REQUIRE("b29vb28" == StringUtils::to_base64("ooooo", false /*url*/, false /*padded*/));
   REQUIRE("b29vb29v" == StringUtils::to_base64("oooooo", false /*url*/, false /*padded*/));
 
+  std::vector<uint8_t> message{
+      0x00, 0x10, 0x83, 0x10,
+      0x51, 0x87, 0x20, 0x92,
+      0x8b, 0x30, 0xd3, 0x8f,
+      0x41, 0x14, 0x93, 0x51,
+      0x55, 0x97, 0x61, 0x96,
+      0x9b, 0x71, 0xd7, 0x9f,
+      0x82, 0x18, 0xa3, 0x92,
+      0x59, 0xa7, 0xa2, 0x9a,
+      0xab, 0xb2, 0xdb, 0xaf,
+      0xc3, 0x1c, 0xb3, 0xd3,
+      0x5d, 0xb7, 0xe3, 0x9e,
+      0xbb, 0xf3, 0xdf, 0xbf};
+
   REQUIRE("ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/" ==
-      StringUtils::to_base64(gsl::make_span(std::vector<uint8_t>{
-          0x00, 0x10, 0x83, 0x10,
-          0x51, 0x87, 0x20, 0x92,
-          0x8b, 0x30, 0xd3, 0x8f,
-          0x41, 0x14, 0x93, 0x51,
-          0x55, 0x97, 0x61, 0x96,
-          0x9b, 0x71, 0xd7, 0x9f,
-          0x82, 0x18, 0xa3, 0x92,
-          0x59, 0xa7, 0xa2, 0x9a,
-          0xab, 0xb2, 0xdb, 0xaf,
-          0xc3, 0x1c, 0xb3, 0xd3,
-          0x5d, 0xb7, 0xe3, 0x9e,
-          0xbb, 0xf3, 0xdf, 0xbf}).as_span<const std::byte>()));
+      StringUtils::to_base64(as_bytes(std::span(message))));
   REQUIRE("ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-_" ==
-      StringUtils::to_base64(gsl::make_span(std::vector<uint8_t>{
-          0x00, 0x10, 0x83, 0x10,
-          0x51, 0x87, 0x20, 0x92,
-          0x8b, 0x30, 0xd3, 0x8f,
-          0x41, 0x14, 0x93, 0x51,
-          0x55, 0x97, 0x61, 0x96,
-          0x9b, 0x71, 0xd7, 0x9f,
-          0x82, 0x18, 0xa3, 0x92,
-          0x59, 0xa7, 0xa2, 0x9a,
-          0xab, 0xb2, 0xdb, 0xaf,
-          0xc3, 0x1c, 0xb3, 0xd3,
-          0x5d, 0xb7, 0xe3, 0x9e,
-          0xbb, 0xf3, 0xdf, 0xbf}).as_span<const std::byte>(), true /*url*/));
+      StringUtils::to_base64(as_bytes(std::span(message)), true /*url*/));
 }
 
 TEST_CASE("TestStringUtils::testBase64Decode", "[test base64 decode]") {
@@ -536,8 +526,8 @@ TEST_CASE("StringUtils::removeFramingCharacters works correctly", "[removeFramin
 
 // ignore terminating \0 character
 template<size_t N>
-gsl::span<const std::byte> from_cstring(const char (&str)[N]) {
-  return gsl::span<const char>(str, N-1).as_span<const std::byte>();
+std::span<const std::byte> from_cstring(const char (&str)[N]) {
+  return as_bytes(std::span<const char>(str, N-1));
 }
 
 TEST_CASE("StringUtils::escapeUnprintableBytes", "[escapeUnprintableBytes]") {
@@ -556,4 +546,57 @@ TEST_CASE("StringUtils::matchesSequence works correctly", "[matchesSequence]") {
   REQUIRE(!StringUtils::matchesSequence("xxxabcxxxdefxxx", {"abc", "abc", "def"}));
 }
 
+TEST_CASE("StringUtils::toLower and toUpper tests") {
+  CHECK(StringUtils::toUpper("Lorem ipsum dolor sit amet") == "LOREM IPSUM DOLOR SIT AMET");
+  CHECK(StringUtils::toLower("Lorem ipsum dolor sit amet") == "lorem ipsum dolor sit amet");
+
+  CHECK(StringUtils::toUpper("SuSpenDISse") == "SUSPENDISSE");
+  CHECK(StringUtils::toLower("SuSpenDISse") == "suspendisse");
+}
+
+TEST_CASE("StringUtils::splitToValueAndUnit tests") {
+  int64_t value;
+  std::string unit_str;
+  SECTION("Simple case") {
+    CHECK(StringUtils::splitToValueAndUnit("1 horse", value, unit_str));
+    CHECK(value == 1);
+    CHECK(unit_str == "horse");
+  }
+
+  SECTION("Without whitespace") {
+    CHECK(StringUtils::splitToValueAndUnit("112KiB", value, unit_str));
+    CHECK(value == 112);
+    CHECK(unit_str == "KiB");
+  }
+
+  SECTION("Additional whitespace in the middle") {
+    CHECK(StringUtils::splitToValueAndUnit("100    hOrSe", value, unit_str));
+    CHECK(value == 100);
+    CHECK(unit_str == "hOrSe");
+  }
+
+  SECTION("Invalid value") {
+    CHECK_FALSE(StringUtils::splitToValueAndUnit("one horse", value, unit_str));
+  }
+
+  SECTION("Empty string") {
+    CHECK_FALSE(StringUtils::splitToValueAndUnit("", value, unit_str));
+  }
+}
+
+TEST_CASE("StringUtils::parseCharacter tests") {
+  CHECK(StringUtils::parseCharacter("a") == 'a');
+  CHECK(StringUtils::parseCharacter("\\n") == '\n');
+  CHECK(StringUtils::parseCharacter("\\t") == '\t');
+  CHECK(StringUtils::parseCharacter("\\r") == '\r');
+  CHECK(StringUtils::parseCharacter("\\s") == 's');
+  CHECK(StringUtils::parseCharacter("\\'") == '\'');
+  CHECK(StringUtils::parseCharacter("\\") == '\\');
+  CHECK(StringUtils::parseCharacter("\\?") == '\?');
+
+  CHECK_FALSE(StringUtils::parseCharacter("abc").has_value());
+  CHECK_FALSE(StringUtils::parseCharacter("\\nd").has_value());
+  CHECK(StringUtils::parseCharacter("") == std::nullopt);
+}
+
 // NOLINTEND(readability-container-size-empty)
