@@ -62,6 +62,7 @@
 #include "utils/file/PathUtils.h"
 #include "utils/file/FileUtils.h"
 #include "utils/Environment.h"
+#include "utils/FileMutex.h"
 #include "FlowController.h"
 #include "AgentDocs.h"
 #include "MainHelper.h"
@@ -75,9 +76,8 @@ namespace minifi = org::apache::nifi::minifi;
 namespace core = minifi::core;
 namespace utils = minifi::utils;
 
- // Variables that allow us to avoid a timed wait.
-static sem_t *flow_controller_running;
-static sem_t *process_running;
+static std::atomic_flag flow_controller_running;
+static std::atomic_flag process_running;
 
 /**
  * Removed the stop command from the signal handler so that we could trigger
@@ -91,27 +91,26 @@ static sem_t *process_running;
 
 #ifdef WIN32
 BOOL WINAPI consoleSignalHandler(DWORD signal) {
-  if (!process_running) { exit(0); return TRUE; }
+  if (!process_running.test()) { exit(0); return TRUE; }
   if (signal == CTRL_C_EVENT || signal == CTRL_BREAK_EVENT) {
-    int ret = ETIMEDOUT;
-    while (ret == ETIMEDOUT) {
-      if (flow_controller_running) { sem_post(flow_controller_running); }
-      const struct timespec timeout_100ms { .tv_sec = 0, .tv_nsec = 100000000};
-      ret = sem_timedwait(process_running, &timeout_100ms);
-    }
+    flow_controller_running.clear();
+    flow_controller_running.notify_all();
+    process_running.wait(true);
     return TRUE;
   }
   return FALSE;
 }
 
 void SignalExitProcess() {
-  sem_post(flow_controller_running);
+  flow_controller_running.clear();
+  flow_controller_running.notify_all();
 }
 #endif
 
 void sigHandler(int signal) {
   if (signal == SIGINT || signal == SIGTERM) {
-    sem_post(flow_controller_running);
+    flow_controller_running.clear();
+    flow_controller_running.notify_all();
   }
 }
 
@@ -197,6 +196,14 @@ int main(int argc, char **argv) {
     // determineMinifiHome already logged everything we need
     return -1;
   }
+  utils::FileMutex minifi_home_mtx(minifiHome / "LOCK");
+  std::unique_lock minifi_home_lock(minifi_home_mtx, std::defer_lock);
+  try {
+    minifi_home_lock.lock();
+  } catch (const std::exception& ex) {
+    logger->log_error("Could not acquire LOCK for minifi home '%s', maybe another minifi instance is running: %s", minifiHome.string(), ex.what());
+    std::exit(1);
+  }
   // chdir to MINIFI_HOME
   std::error_code current_path_error;
   std::filesystem::current_path(minifiHome, current_path_error);
@@ -204,34 +211,21 @@ int main(int argc, char **argv) {
     logger->log_error("Failed to change working directory to MINIFI_HOME (%s)", minifiHome.string());
     return -1;
   }
-  const auto flow_controller_semaphore_path = "/MiNiFiMain";
-  const auto process_semaphore_path = "/MiNiFiProc";
 
-  process_running = sem_open(process_semaphore_path, O_CREAT, 0644, 0);
-  if (process_running == SEM_FAILED) {
-    logger->log_error("could not initialize process semaphore");
-    perror("sem_open");
-    return -1;
-  }
+  process_running.test_and_set();
 
   std::atomic<bool> restart_token{false};
   const auto request_restart = [&] {
     if (!restart_token.exchange(true)) {
-      // only do sem_post if a restart is not already in progress (the flag was unset before the exchange)
-      sem_post(flow_controller_running);
+      // only trigger if a restart is not already in progress (the flag was unset before the exchange)
+      flow_controller_running.clear();
+      flow_controller_running.notify_all();
       logger->log_info("Initiating restart...");
     }
   };
 
   do {
-    flow_controller_running = sem_open(flow_controller_semaphore_path, O_CREAT, 0644, 0);
-    if (flow_controller_running == SEM_FAILED) {
-      logger->log_error("could not initialize flow controller semaphore");
-      perror("sem_open");
-      return -1;
-    }
-
-    uint16_t stop_wait_time = STOP_WAIT_TIME_MS;
+    flow_controller_running.test_and_set();
 
     std::string graceful_shutdown_seconds;
     std::string prov_repo_class = "provenancerepository";
@@ -241,7 +235,8 @@ int main(int argc, char **argv) {
 
     auto log_properties = std::make_shared<core::logging::LoggerProperties>();
     log_properties->setHome(minifiHome);
-    log_properties->loadConfigureFile(DEFAULT_LOG_PROPERTIES_FILE);
+    log_properties->loadConfigureFile(DEFAULT_LOG_PROPERTIES_FILE, "nifi.log.");
+
     core::logging::LoggerConfiguration::getConfiguration().initialize(log_properties);
 
     std::shared_ptr<minifi::Properties> uid_properties = std::make_shared<minifi::Properties>("UID properties");
@@ -308,20 +303,10 @@ int main(int argc, char **argv) {
       std::exit(0);
     }
 
-    if (configure->get(minifi::Configure::nifi_graceful_shutdown_seconds, graceful_shutdown_seconds)) {
-      try {
-        stop_wait_time = std::stoi(graceful_shutdown_seconds);
-      }
-      catch (const std::out_of_range& e) {
-        logger->log_error("%s is out of range. %s", minifi::Configure::nifi_graceful_shutdown_seconds, e.what());
-      }
-      catch (const std::invalid_argument& e) {
-        logger->log_error("%s contains an invalid argument set. %s", minifi::Configure::nifi_graceful_shutdown_seconds, e.what());
-      }
-    } else {
-      logger->log_debug("%s not set, defaulting to %d", minifi::Configure::nifi_graceful_shutdown_seconds,
-          STOP_WAIT_TIME_MS);
-    }
+    std::chrono::milliseconds stop_wait_time = configure->get(minifi::Configure::nifi_graceful_shutdown_seconds)
+        | utils::flatMap(utils::timeutils::StringToDuration<std::chrono::milliseconds>)
+        | utils::valueOrElse([] { return std::chrono::milliseconds(STOP_WAIT_TIME_MS);});
+
 
     configure->get(minifi::Configure::nifi_provenance_repository_class_name, prov_repo_class);
     // Create repos for flow record and provenance
@@ -364,8 +349,6 @@ int main(int argc, char **argv) {
 
     configure->get(minifi::Configure::nifi_configuration_class_name, nifi_configuration_class_name);
 
-    std::shared_ptr<minifi::io::StreamFactory> stream_factory = minifi::io::StreamFactory::getInstance(configure);
-
     bool should_encrypt_flow_config = (configure->get(minifi::Configure::nifi_flow_configuration_encrypt)
         | utils::flatMap(utils::StringUtils::toBool)).value_or(false);
 
@@ -377,17 +360,20 @@ int main(int argc, char **argv) {
         core::ConfigurationContext{
           .flow_file_repo = flow_repo,
           .content_repo = content_repo,
-          .stream_factory = stream_factory,
           .configuration = configure,
           .path = configure->get(minifi::Configure::nifi_flow_configuration_file),
           .filesystem = filesystem}, nifi_configuration_class_name);
 
-    auto metrics_publisher_store = std::make_unique<minifi::state::MetricsPublisherStore>(configure, prov_repo, flow_repo, flow_configuration);
+    std::vector<std::shared_ptr<core::RepositoryMetricsSource>> repo_metric_sources{prov_repo, flow_repo, content_repo};
+    auto metrics_publisher_store = std::make_unique<minifi::state::MetricsPublisherStore>(configure, repo_metric_sources, flow_configuration);
 
     const auto controller = std::make_unique<minifi::FlowController>(
       prov_repo, flow_repo, configure, std::move(flow_configuration), content_repo, std::move(metrics_publisher_store), filesystem, request_restart);
 
-    const bool disk_space_watchdog_enable = (configure->get(minifi::Configure::minifi_disk_space_watchdog_enable) | utils::map([](const std::string& v) { return v == "true"; })).value_or(true);
+    const bool disk_space_watchdog_enable = configure->get(minifi::Configure::minifi_disk_space_watchdog_enable)
+        | utils::flatMap(utils::StringUtils::toBool)
+        | utils::valueOrElse([] { return true; });
+
     std::unique_ptr<utils::CallBackTimer> disk_space_watchdog;
     if (disk_space_watchdog_enable) {
       try {
@@ -460,21 +446,7 @@ int main(int argc, char **argv) {
 
     logger->log_info("MiNiFi started");
 
-    /**
-     * Sem wait provides us the ability to have a controlled
-     * yield without the need for a more complex construct and
-     * a spin lock
-     */
-    int ret_val;
-    while ((ret_val = sem_wait(flow_controller_running)) == -1 && errno == EINTR) {}
-    if (ret_val == -1) perror("sem_wait");
-
-    while ((ret_val = sem_close(flow_controller_running)) == -1 && errno == EINTR) {}
-    if (ret_val == -1) perror("sem_close");
-    flow_controller_running = nullptr;
-
-    while ((ret_val = sem_unlink(flow_controller_semaphore_path)) == -1 && errno == EINTR) {}
-    if (ret_val == -1) perror("sem_unlink");
+    flow_controller_running.wait(true);
 
     disk_space_watchdog = nullptr;
 
@@ -492,7 +464,8 @@ int main(int argc, char **argv) {
     return restart_token_temp;
   }());
 
-  if (process_running) { sem_post(process_running); }
+  process_running.clear();
+  process_running.notify_all();
   logger->log_info("MiNiFi exit");
   return 0;
 }
